@@ -16,7 +16,7 @@ from __future__ import print_function
 import ibm_watson_machine_learning._wrappers.requests as requests
 
 from ibm_watson_machine_learning.messages.messages import Messages
-from ibm_watson_machine_learning.utils import SPACES_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, MEMBER_DETAILS_TYPE,DATA_ASSETS_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv, str_type_conv, get_file_from_cos
+from ibm_watson_machine_learning.utils import DATA_ASSETS_DETAILS_TYPE
 from ibm_watson_machine_learning.metanames import AssetsMetaNames
 from ibm_watson_machine_learning.wml_resource import WMLResource
 from ibm_watson_machine_learning.wml_client_error import WMLClientError, ApiRequestFailure
@@ -26,9 +26,8 @@ _DEFAULT_LIST_LENGTH = 50
 
 
 class Assets(WMLResource):
-    """
-    Store and manage your data assets.
-    """
+    """Store and manage your data assets."""
+
     ConfigurationMetaNames = AssetsMetaNames()
     """MetaNames for Data Assets creation."""
 
@@ -36,55 +35,42 @@ class Assets(WMLResource):
         WMLResource.__init__(self, __name__, client)
         self._ICP = client.ICP
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_details(self, asset_uid=None):
-        """
-            Get data asset details. If no asset_uid is passed, details for all assets will be returned.
+        """Get data asset details. If no asset_uid is passed, details for all assets will be returned.
 
-            **Parameters**
+        :param asset_uid: Unique id of asset
+        :type asset_uid: str
 
-            .. important::
-                **returns**: Unique id  of asset\n
-                **return type**: str
+        :return: metadata of the stored data asset
+        :rtype: dict
 
-            **Output**
+        **Example**
 
-            .. important::
-                #. **asset_details**:  Metadata of the stored data asset\n
-                   **type**: dict\n
+        .. code-block:: python
 
-            **Example**
+            asset_details = client.data_assets.get_details(asset_uid)
 
-             >>> asset_details = client.data_assets.get_details(asset_uid)
         """
         return self._get_asset_based_resource(asset_uid, 'data_asset', self._get_required_element_from_response)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def create(self, name, file_path):
-        """
-                Creates a data asset and uploads content to it.
+        """Creates a data asset and uploads content to it.
 
-                **Parameters**
+        :param name:  name to be given to the data asset
+        :type name: str
 
-                .. important::
-                   #. **name**:  Name to be given to the data asset\n
+        :param file_path: path to the content file to be uploaded
+        :type file_path: str
 
-                      **type**: str\n
+        :return: metadata of the stored data asset
+        :rtype: dict
 
-                   #. **file_path**:  Path to the content file to be uploaded\n
+        **Example**
 
-                      **type**: str\n
+        .. code-block:: python
 
-                **Output**
+            asset_details = client.data_assets.create(name="sample_asset", file_path="/path/to/file")
 
-                .. important::
-
-                    **returns**: metadata of the stored data asset\n
-                    **return type**: dict\n
-
-                **Example**
-
-                 >>> asset_details = client.data_assets.create(name="sample_asset",file_path="/path/to/file")
         """
         # quick support for COS credentials instead of local path
         # TODO add error handling and cleaning (remove the file)
@@ -93,48 +79,54 @@ class Assets(WMLResource):
         Assets._validate_type(file_path, u'file_path', str, True)
         return self._create_asset(name, file_path)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def store(self, meta_props):
-        """
-                Creates a data asset and uploads content to it.
+        """Creates a data asset and uploads content to it.
 
-                **Parameters**
+        :param meta_props:  meta data of the space configuration. To see available meta names use:
 
-                .. important::
-                   #. **meta_props**:  meta data of the space configuration. To see available meta names use:\n
-                                    >>> client.data_assets.ConfigurationMetaNames.get()
+            .. code-block:: python
 
-                      **type**: dict\n
+                client.data_assets.ConfigurationMetaNames.get()
 
-                **Example**
-                    Example for data asset creation for files :
+        :type meta_props: dict
 
-                            >>> metadata = {
-                            >>>  client.data_assets.ConfigurationMetaNames.NAME: 'my data assets',
-                            >>>  client.data_assets.ConfigurationMetaNames.DESCRIPTION: 'sample description',
-                            >>>  client.data_assets.ConfigurationMetaNames.DATA_CONTENT_NAME: 'sample.csv'
-                            >>> }
-                            >>> asset_details = client.data_assets.store(meta_props=metadata)
+        **Example**
 
-                    Example of data asset creation using connection:
+        Example for data asset creation for files :
 
-                            >>> metadata = {
-                            >>>  client.data_assets.ConfigurationMetaNames.NAME: 'my data assets',
-                            >>>  client.data_assets.ConfigurationMetaNames.DESCRIPTION: 'sample description',
-                            >>>  client.data_assets.ConfigurationMetaNames.CONNECTION_ID: '39eaa1ee-9aa4-4651-b8fe-95d3ddae',
-                            >>>  client.data_assets.ConfigurationMetaNames.DATA_CONTENT_NAME: 't1/sample.csv'
-                            >>> }
-                            >>> asset_details = client.data_assets.store(meta_props=metadata)
+        .. code-block:: python
 
-                    Example for data asset creation with database sources type connection:
+            metadata = {
+                client.data_assets.ConfigurationMetaNames.NAME: 'my data assets',
+                client.data_assets.ConfigurationMetaNames.DESCRIPTION: 'sample description',
+                client.data_assets.ConfigurationMetaNames.DATA_CONTENT_NAME: 'sample.csv'
+            }
+            asset_details = client.data_assets.store(meta_props=metadata)
+
+        Example of data asset creation using connection:
+
+        .. code-block:: python
+
+            metadata = {
+                client.data_assets.ConfigurationMetaNames.NAME: 'my data assets',
+                client.data_assets.ConfigurationMetaNames.DESCRIPTION: 'sample description',
+                client.data_assets.ConfigurationMetaNames.CONNECTION_ID: '39eaa1ee-9aa4-4651-b8fe-95d3ddae',
+                client.data_assets.ConfigurationMetaNames.DATA_CONTENT_NAME: 't1/sample.csv'
+            }
+            asset_details = client.data_assets.store(meta_props=metadata)
+
+        Example for data asset creation with database sources type connection:
+
+        .. code-block:: python
+
+            metadata = {
+                client.data_assets.ConfigurationMetaNames.NAME: 'my data assets',
+                client.data_assets.ConfigurationMetaNames.DESCRIPTION: 'sample description',
+                client.data_assets.ConfigurationMetaNames.CONNECTION_ID: '23eaf1ee-96a4-4651-b8fe-95d3dadfe',
+                client.data_assets.ConfigurationMetaNames.DATA_CONTENT_NAME: 't1'
+            }
+            asset_details = client.data_assets.store(meta_props=metadata)
 
-                            >>> metadata = {
-                            >>>  client.data_assets.ConfigurationMetaNames.NAME: 'my data assets',
-                            >>>  client.data_assets.ConfigurationMetaNames.DESCRIPTION: 'sample description',
-                            >>>  client.data_assets.ConfigurationMetaNames.CONNECTION_ID: '23eaf1ee-96a4-4651-b8fe-95d3dadfe',
-                            >>>  client.data_assets.ConfigurationMetaNames.DATA_CONTENT_NAME: 't1'
-                            >>> }
-                            >>> asset_details = client.data_assets.store(meta_props=metadata)
         """
         ##For CP4D, check if either spce or project ID is set
         WMLResource._chk_and_block_create_update_for_python36(self)
@@ -279,24 +271,17 @@ class Assets(WMLResource):
                 raise WMLClientError(Messages.get_message(message_id="failed_while_creating_a_data_asset"))
 
     def list(self, limit=None):
-        """
-           List stored data assets. If limit is set to None there will be only first 50 records shown.
+        """Print stored data assets in a table format.
+        If limit is set to None there will be only first 50 records shown.
 
-           **Parameters**
+        :param limit:  limit number of fetched records
+        :type limit: int
 
-           .. important::
-                #. **limit**:  limit number of fetched records\n
-                   **type**: int\n
+        **Example**
 
-           **Output**
+        .. code-block:: python
 
-           .. important::
-                This method only prints the list of all data assets in a table format.\n
-                **return type**: None\n
-
-           **Example**
-
-            >>> client.data_assets.list()
+            client.data_assets.list()
         """
 
         Assets._validate_type(limit, u'limit', int, False)
@@ -317,32 +302,25 @@ class Assets(WMLResource):
 
         self._list(space_values, [u'NAME', u'ASSET_TYPE', u'SIZE', u'ASSET_ID'], limit, _DEFAULT_LIST_LENGTH)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def download(self, asset_uid, filename):
+        """Download and store the content of a data asset.
+
+        :param asset_uid: the Unique Id of the data asset to be downloaded
+        :type asset_uid: str
+
+        :param filename:  filename to be used for the downloaded file
+        :type filename: str
+
+        :return: normalized path to the downloaded asset content
+        :rtype: str
+
+        **Example**
+
+        .. code-block:: python
+
+            client.data_assets.download(asset_uid,"sample_asset.csv")
+
         """
-            Download and store the content of a data asset.
-
-            **Parameters**
-
-            .. important::
-
-                 #. **asset_uid**:  The Unique Id of the data asset to be downloaded\n
-                    **type**: str\n
-
-                 #. **filename**:  filename to be used for the downloaded file\n
-                    **type**: str\n
-
-            **Output**
-
-            .. important::
-
-                 **returns**: Normalized path to the downloaded asset content\n
-                 **return type**: str\n
-
-            **Example**
-
-             >>> client.data_assets.download(asset_uid,"sample_asset.csv")
-         """
         content = self.get_content(asset_uid)
         try:
             with open(filename, 'wb') as f:
@@ -353,30 +331,23 @@ class Assets(WMLResource):
             raise WMLClientError(
                 Messages.get_message(filename, message_id="saving_data_asset_to_local_file_failed"), e)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_content(self, asset_uid):
+        """Download the content of a data asset.
+
+        :param asset_uid: the Unique Id of the data asset to be downloaded
+        :type asset_uid: str
+
+        :return: the asset content
+        :rtype: binary
+
+        **Example**
+
+        .. code-block:: python
+
+            content = client.data_assets.get_content(asset_uid).decode('ascii')
+
         """
-            Download the content of a data asset.
-
-            **Parameters**
-
-            .. important::
-
-                 #. **asset_uid**:  The Unique Id of the data asset to be downloaded\n
-                    **type**: str\n
-
-            **Output**
-
-            .. important::
-
-                 **returns**: the asset content\n
-                 **return type**: binary\n
-
-            **Example**
-
-             >>> content = client.data_assets.get_content(asset_uid).decode('ascii')
-        """
-        Assets._validate_type(asset_uid, u'asset_uid', STR_TYPE, True)
+        Assets._validate_type(asset_uid, u'asset_uid', str, True)
 
         import urllib
         asset_response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_uid),
@@ -429,30 +400,23 @@ class Assets(WMLResource):
                 raise WMLClientError(Messages.get_message(message_id="failure_during_downloading_data_asset"))
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_uid(asset_details):
-        """
-                Get Unique Id  of stored data asset. Deprecated!! Use get_id(details) instead
+        """Get Unique Id of stored data asset.
 
-                **Parameters**
+        *Deprecated:* Use ``get_id(details)`` instead.
 
-                .. important::
+        :param asset_details: metadata of the stored data asset
+        :type asset_details: dict
 
-                   #. **asset_details**:  Metadata of the stored data asset\n
-                      **type**: dict\n
-                      **type**: dict\n
+        :return: Unique Id of stored asset
+        :rtype**: str
 
-                **Output**
+        **Example**
 
-                .. important::
+        .. code-block:: python
 
-                    **returns**: Unique Id of stored asset\n
-                    **return type**: str\n
+            asset_uid = client.data_assets.get_uid(asset_details)
 
-                **Example**
-
-
-                 >>> asset_uid = client.data_assets.get_uid(asset_details)
         """
         Assets._validate_type(asset_details, u'asset_details', object, True)
         Assets._validate_type_of_details(asset_details, DATA_ASSETS_DETAILS_TYPE)
@@ -462,84 +426,65 @@ class Assets(WMLResource):
 
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_id(asset_details):
-        """
-                Get Unique Id of stored script asset.
+        """Get Unique Id of stored data asset.
 
-                **Parameters**
+        :param asset_details: details of the stored data asset
+        :type asset_details: dict
 
-                .. important::
+        :return: Unique Id of stored data asset
+        :rtype: str
 
-                   #. **asset_details**:  Metadata of the stored script asset\n
-                      **type**: dict\n
+        **Example**
 
-                **Output**
+        .. code-block:: python
 
-                .. important::
-
-                    **returns**: Unique Id of stored data asset\n
-                    **return type**: str\n
-
-                **Example**
-
-                     >>> asset_id = client.data_assets.get_id(asset_details)
+            asset_id = client.data_assets.get_id(asset_details)
 
         """
 
         return Assets.get_uid(asset_details)
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_href(asset_details):
-        """
-            Get url of stored data asset.
+        """Get url of stored data asset.
 
-           **Parameters**
+        :param asset_details:  stored data asset details
+        :type asset_details: dict
 
-           .. important::
-                #. **asset_details**:  stored data asset details\n
-                   **type**: dict\n
+        :return: href of stored data asset
+        :rtype: str
 
-           **Output**
+        **Example**
 
-           .. important::
-                **returns**: href of stored data asset\n
-                **return type**: str\n
+        .. code-block:: python
 
-           **Example**
+            asset_details = client.data_assets.get_details(asset_uid)
+            asset_href = client.data_assets.get_href(asset_details)
 
-             >>> asset_details = client.data_assets.get_details(asset_uid)
-             >>> asset_href = client.data_assets.get_href(asset_details)
         """
         Assets._validate_type(asset_details, u'asset_details', object, True)
         Assets._validate_type_of_details(asset_details, DATA_ASSETS_DETAILS_TYPE)
 
         return WMLResource._get_required_element_from_dict(asset_details, u'asset_details', [u'metadata', u'href'])
 
-
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def delete(self, asset_uid):
+        """Delete a stored data asset.
+
+        :param asset_uid:  Unique Id of data asset
+        :type asset_uid: str
+
+        :return: status ("SUCCESS" or "FAILED")
+        :rtype: str
+
+        **Example**
+
+        .. code-block:: python
+
+            client.data_assets.delete(asset_uid)
+
         """
-            Delete a stored data asset.
-
-            **Parameters**
-
-            .. important::
-                #. **asset_uid**:  Unique Id of data asset\n
-                   **type**: str\n
-
-            **Output**
-
-            .. important::
-                **returns**: status ("SUCCESS" or "FAILED")\n
-                **return type**: str\n
-
-            **Example**
-
-             >>> client.data_assets.delete(asset_uid)
-        """
-        Assets._validate_type(asset_uid, u'asset_uid', STR_TYPE, True)
+        Assets._validate_type(asset_uid, u'asset_uid', str, True)
 
         response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
                                 headers=self._client._get_headers())
@@ -548,9 +493,8 @@ class Assets(WMLResource):
         else:
             return self._handle_response(204, u'delete assets', response)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def _delete(self, asset_uid):
-        Assets._validate_type(asset_uid, u'asset_uid', STR_TYPE, True)
+        Assets._validate_type(asset_uid, u'asset_uid', str, True)
 
         response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
                                    headers=self._client._get_headers())
@@ -561,8 +505,6 @@ class Assets(WMLResource):
         # else:
         #     return self._handle_response(204, u'delete assets', response)
 
-
-    # @docstring_parameter({'str_type': STR_TYPE_NAME})
     # def get_href(self, asset_uid):
     #     """
     #        Get metadata of stored space(s). If space UID is not specified, it returns all the spaces metadata.
@@ -592,7 +534,7 @@ class Assets(WMLResource):
     #     """
     #
     #
-    #     Assets._validate_type(asset_uid, u'asset_uid', STR_TYPE, True)
+    #     Assets._validate_type(asset_uid, u'asset_uid', str, True)
     #
     #     response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_uid), params=self._client._params(),
     #                             headers=self._client._get_headers())
