@@ -16,12 +16,9 @@ from __future__ import print_function
 import ibm_watson_machine_learning._wrappers.requests as requests
 
 from ibm_watson_machine_learning.messages.messages import Messages
-from ibm_watson_machine_learning.utils import SPACES_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, MEMBER_DETAILS_TYPE, \
-    DATA_ASSETS_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv, str_type_conv, \
-    get_file_from_cos
 from ibm_watson_machine_learning.metanames import ConnectionMetaNames
 from ibm_watson_machine_learning.wml_resource import WMLResource
-from ibm_watson_machine_learning.wml_client_error import WMLClientError, ApiRequestFailure
+from ibm_watson_machine_learning.wml_client_error import WMLClientError
 import os
 import json
 from urllib.parse import unquote, quote
@@ -30,9 +27,8 @@ _DEFAULT_LIST_LENGTH = 0
 
 
 class Connections(WMLResource):
-    """
-    Store and manage your Connections.
-    """
+    """Store and manage your Connections."""
+
     ConfigurationMetaNames = ConnectionMetaNames()
     """MetaNames for Connection creation."""
 
@@ -77,30 +73,26 @@ class Connections(WMLResource):
         except Exception as e:
             raise WMLClientError(Messages.get_message(response_data, message_id="failed_to_read_response_from_down_stream_service"))
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_details(self, connection_id=None):
-        """
-        Get connection details for the given unique Connection id. If no connection_id is passed, details for all connections will be returned.
+        """Get connection details for the given unique Connection id.
+        If no connection_id is passed, details for all connections will be returned.
 
-        **Parameters**
+        :param connection_id: Unique id of Connection
+        :type connection_id: str
 
-        .. important::
-            #. **connection_id**: Unique id of Connection\n
-                **type**: str\n
-
-        **Output**
-
-        .. important::
-            **returns**: Metadata of the stored Connection\n
-            **return type**: dict\n
+        :return: metadata of the stored Connection
+        :rtype: dict
 
         **Example**
 
-         >>> connection_details = client.connections.get_details(connection_id)
-         >>> connection_details = client.connections.get_details()
+        .. code-block:: python
+
+            connection_details = client.connections.get_details(connection_id)
+            connection_details = client.connections.get_details()
+
         """
         self._client._check_if_either_is_set()
-        Connections._validate_type(connection_id, u'connection_id', STR_TYPE, False)
+        Connections._validate_type(connection_id, u'connection_id', str, False)
 
         if self._client.WSD:
             header_param = self._client._get_headers(wsdconnection_api_req=True)
@@ -133,96 +125,104 @@ class Connections(WMLResource):
                 else:
                     return self._handle_response(200, u'get connection details', response)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def create(self, meta_props):
-        """
-                Creates a connection. Input to PROPERTIES field examples
+        """Creates a connection. Input to PROPERTIES field examples
 
-                1. MySQL
-                      >>> client.connections.ConfigurationMetaNames.PROPERTIES: {
-                      >>>   "database": "database",
-                      >>>   "password": "password",
-                      >>>   "port": "3306",
-                      >>>   "host": "host url",
-                      >>>   "ssl": "false",
-                      >>>   "username": "username"
-                      >>> }
+        1. MySQL
 
-                2. Google Big query
+            .. code-block:: python
 
-                   a. Method1: Use service account json. The service account json generated can be provided as
-                               input as-is. Provide actual values in json. Example is only indicative to show
-                               the fields. Refer to Google big query documents how to generate the service account json\n
+                client.connections.ConfigurationMetaNames.PROPERTIES: {
+                    "database": "database",
+                    "password": "password",
+                    "port": "3306",
+                    "host": "host url",
+                    "ssl": "false",
+                    "username": "username"
+                }
 
-                      >>> client.connections.ConfigurationMetaNames.PROPERTIES: {
-                      >>>     "type": "service_account",
-                      >>>     "project_id": "project_id",
-                      >>>     "private_key_id": "private_key_id",
-                      >>>     "private_key": "private key contents",
-                      >>>     "client_email": "client_email",
-                      >>>     "client_id": "client_id",
-                      >>>     "auth_uri": "https://accounts.google.com/o/oauth2/auth",
-                      >>>     "token_uri": "https://oauth2.googleapis.com/token",
-                      >>>     "auth_provider_x509_cert_url": "https://www.googleapis.com/oauth2/v1/certs",
-                      >>>     "client_x509_cert_url": "client_x509_cert_url"
-                      >>> }
+        2. Google Big query
 
-                   b. Method2: Using OAuth Method. Refer to Google big query documents how to generate OAuth token\n
+            a. Method1: Use service account json. The service account json generated can be provided as
+                input as-is. Provide actual values in json. Example is only indicative to show
+                the fields. Refer to Google big query documents how to generate the service account json.
 
-                       >>> client.connections.ConfigurationMetaNames.PROPERTIES: {
-                       >>>    "access_token": "access token generated for big query",
-                       >>>    "refresh_token": "refresh token",
-                       >>>    "project_id": "project_id",
-                       >>>    "client_secret": "This is your gmail account password",
-                       >>>   "client_id": "client_id"
-                       >>> }
+                .. code-block:: python
 
-                3. MS SQL
-                     >>> client.connections.ConfigurationMetaNames.PROPERTIES: {
-                     >>>      "database": "database",
-                     >>>      "password": "password",
-                     >>>      "port": "1433",
-                     >>>      "host": "host",
-                     >>>      "username": "username"
-                     >>> }
+                    client.connections.ConfigurationMetaNames.PROPERTIES: {
+                        "type": "service_account",
+                        "project_id": "project_id",
+                        "private_key_id": "private_key_id",
+                        "private_key": "private key contents",
+                        "client_email": "client_email",
+                        "client_id": "client_id",
+                        "auth_uri": "https://accounts.google.com/o/oauth2/auth",
+                        "token_uri": "https://oauth2.googleapis.com/token",
+                        "auth_provider_x509_cert_url": "https://www.googleapis.com/oauth2/v1/certs",
+                        "client_x509_cert_url": "client_x509_cert_url"
+                    }
 
-                4. Tera data
-                     >>> client.connections.ConfigurationMetaNames.PROPERTIES: {
-                     >>>      "database": "database",
-                     >>>      "password": "password",
-                     >>>      "port": "1433",
-                     >>>      "host": "host",
-                     >>>      "username": "username"
-                     >>> }
+            b. Method2: Using OAuth Method. Refer to Google big query documents how to generate OAuth token.
+
+                .. code-block:: python
+
+                    client.connections.ConfigurationMetaNames.PROPERTIES: {
+                        "access_token": "access token generated for big query",
+                        "refresh_token": "refresh token",
+                        "project_id": "project_id",
+                        "client_secret": "This is your gmail account password",
+                        "client_id": "client_id"
+                    }
+
+        3. MS SQL
+
+            .. code-block:: python
+
+                client.connections.ConfigurationMetaNames.PROPERTIES: {
+                    "database": "database",
+                    "password": "password",
+                    "port": "1433",
+                    "host": "host",
+                    "username": "username"
+                }
+
+        4. Tera data
+
+            .. code-block:: python
+
+                client.connections.ConfigurationMetaNames.PROPERTIES: {
+                    "database": "database",
+                    "password": "password",
+                    "port": "1433",
+                    "host": "host",
+                    "username": "username"
+                }
 
 
-                **Parameters**
+        :param meta_props:  meta data of the connection configuration. To see available meta names use:
+            .. code-block:: python
+                client.connections.ConfigurationMetaNames.get()
 
-                .. important::
-                   #. **meta_props**:  meta data of the connection configuration. To see available meta names use:\n
-                            >>> client.connections.ConfigurationMetaNames.get()
+        :type meta_props: dict
 
-                      **type**: dict\n
-                **Output**
+        :return: metadata of the stored connection
+        :rtype: dict
 
-                .. important::
+        **Example**
 
-                    **returns**: metadata of the stored connection\n
-                    **return type**: dict\n
+        .. code-block:: python
 
-                **Example**
-
-                 >>> sqlserver_data_source_type_id = client.connections.get_datasource_type_uid_by_name('sqlserver')
-                 >>> connections_details = client.connections.create({
-                 >>> client.connections.ConfigurationMetaNames.NAME: "sqlserver connection",
-                 >>> client.connections.ConfigurationMetaNames.DESCRIPTION: "connection description",
-                 >>> client.connections.ConfigurationMetaNames.DATASOURCE_TYPE: sqlserver_data_source_type_id,
-                 >>> client.connections.ConfigurationMetaNames.PROPERTIES: { "database": "database",
-                 >>>                                                         "password": "password",
-                 >>>                                                         "port": "1433",
-                 >>>                                                         "host": "host",
-                 >>>                                                         "username": "username"}
-                 >>> })
+            sqlserver_data_source_type_id = client.connections.get_datasource_type_uid_by_name('sqlserver')
+            connections_details = client.connections.create({
+                client.connections.ConfigurationMetaNames.NAME: "sqlserver connection",
+                client.connections.ConfigurationMetaNames.DESCRIPTION: "connection description",
+                client.connections.ConfigurationMetaNames.DATASOURCE_TYPE: sqlserver_data_source_type_id,
+                client.connections.ConfigurationMetaNames.PROPERTIES: { "database": "database",
+                                                                        "password": "password",
+                                                                        "port": "1433",
+                                                                        "host": "host",
+                                                                        "username": "username"}
+            })
 
         """
         WMLResource._chk_and_block_create_update_for_python36(self)
@@ -266,33 +266,26 @@ class Connections(WMLResource):
         else:
             raise WMLClientError(Messages.get_message(message_id="failed_while_creating_connections"))
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def delete(self, connection_id):
-        """
-            Delete a stored Connection.
+        """Delete a stored Connection.
 
-            **Parameters**
+        :param connection_id: Unique id of the connection to be deleted.
+        :type connection_id: str
 
-            .. important::
-                #. **connection_id**: Unique id of the connection to be deleted.\n
-                   **type**: str\n
+        :return: status ("SUCCESS" or "FAILED")
+        :rtype: str
 
-            **Output**
+        **Example**
 
-            .. important::
-                **returns**: status ("SUCCESS" or "FAILED")\n
-                **return type**: str\n
+        .. code-block:: python
 
-            **Example**
-
-             >>> client.connections.delete(connection_id)
+            client.connections.delete(connection_id)
 
         """
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
 
-        pipeline_uid = str_type_conv(connection_id)
-        Connections._validate_type(connection_id, u'connection_id', STR_TYPE, True)
+        Connections._validate_type(connection_id, u'connection_id', str, True)
         if self._client.WSD:
             header_param = self._client._get_headers(wsdconnection_api_req=True)
         else:
@@ -305,29 +298,20 @@ class Connections(WMLResource):
         return self._handle_response(204, u'connection deletion', response_delete, False)
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_uid(connection_details):
-        """
-                Get Unique Id of stored connection.
+        """Get Unique Id of stored connection.
 
-                **Parameters**
+        :param connection_details: metadata of the stored connection
+        :type connection_details: dict
 
-                .. important::
+        :return: Unique Id of stored connection
+        :rtype: str
 
-                   #. **connection_details**:  Metadata of the stored connection\n
-                      **type**: dict\n
+        **Example**
 
-                **Output**
+        .. code-block:: python
 
-                .. important::
-
-                    **returns**: Unique Id of stored connection\n
-                    **return type**: str\n
-
-                **Example**
-
-
-                 >>> connection_uid = client.connection.get_uid(connection_details)
+            connection_uid = client.connection.get_uid(connection_details)
 
         """
         Connections._validate_type(connection_details, u'connection_details', object, True)
@@ -336,19 +320,14 @@ class Connections(WMLResource):
                                                            [u'metadata', u'id'])
 
     def list_datasource_types(self):
-        """
-        List stored datasource types assets.
-
-
-        **Output**
-
-        .. important::
-            This method only prints the list of datasources type in a table format.\n
-            **return type**: None\n
+        """Print stored datasource types assets in a table format.
 
         **Example**
 
-         >>> client.connections.list_datasource_types()
+        .. code-block:: python
+
+            client.connections.list_datasource_types()
+
         """
 
         if self._client.WSD:
@@ -367,18 +346,13 @@ class Connections(WMLResource):
         self._list(space_values, [u'NAME', u'DATASOURCE_ID', u'TYPE', u'STATUS'], None, None)
 
     def list(self):
-        """
-           List all stored connections.
+        """Print all stored connections in a table format.
 
-           **Output**
+        **Example**
 
-           .. important::
-                This method only prints the list of all connections in a table format.\n
-                **return type**: None\n
+        .. code-block:: python
 
-           **Example**
-
-            >>> client.connections.list()
+            client.connections.list()
 
         """
         if self._client.WSD:
@@ -400,27 +374,22 @@ class Connections(WMLResource):
 
         self._list(space_values, [u'NAME', u'ID', u'CREATED', u'DATASOURCE_TYPE_ID', ], None, None)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def list_uploaded_db_drivers(self):
-        """
-           List uploaded db driver jars.
-           Supported for IBM Cloud Pak for Data only.
+        """Print uploaded db driver jars in table a format. Supported for IBM Cloud Pak for Data only.
 
-           **Output**
+        **Example**
 
-           .. important::
-                This method only prints the uploaded db driver jar names.\n
-                **return type**: Str\n
+        .. code-block:: python
 
-           **Example**
-
-            >>> client.connections.list_uploaded_db_drivers()
+            client.connections.list_uploaded_db_drivers()
 
         """
         if not self._client.ICP:
             raise WMLClientError('Not supported on this environment.')
 
         try:
+            if not self.get_uploaded_db_drivers():
+                raise Exception('List empty for new api')
             self._list_uploaded_db_drivers_new_api()
         except:
             response = requests.get(
@@ -432,7 +401,6 @@ class Connections(WMLResource):
 
             self._list(jars, [u'NAME'], None, None)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_uploaded_db_drivers(self): # TODO not yet documented
         # """
         #    Get uploaded db driver jar names and paths.
@@ -459,46 +427,36 @@ class Connections(WMLResource):
         result = self._handle_response(200, u'get uploaded db drivers', response)['resources']
         return dict([(el['fileName'], el['url']) for el in result])
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def _list_uploaded_db_drivers_new_api(self):
-        """
-           List uploaded db driver jars.
-           Supported for IBM Cloud Pak for Data only.
+        """List uploaded db driver jars. Supported for IBM Cloud Pak for Data only.
 
-           **Output**
+        .. important::
+            This method only prints the uploaded db driver jar names.
 
-           .. important::
-                This method only prints the uploaded db driver jar names.\n
-                **return type**: Str\n
+        **Example**
 
-           **Example**
+        .. code-clock:: python
 
-            >>> client.connections._list_uploaded_db_drivers_new_api()
+            client.connections._list_uploaded_db_drivers_new_api()
 
         """
         jars = [[name] for name in self.get_uploaded_db_drivers()]
         self._list(jars, [u'NAME'], None, None)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_datasource_type_uid_by_name(self, name):
-        """
-           Get stored datasource types id for the given datasource type name.
+        """Get stored datasource types id for the given datasource type name.
 
-           **Parameters**
+        :param name:  name of datasource type
+        :type name: int
 
-           .. important::
-                #. **name**:  name of datasource type\n
-                   **type**: int\n
+        :return: datasource Unique Id
+        :rtype: str
 
-           **Output**
+        **Example**
 
-           .. important::
-                This method only prints the id of given datasource type name.\n
-                **return type**: Str\n
+        .. code-block:: python
 
-           **Example**
-
-            >>> client.connections.get_datasource_type_uid_by_name('cloudobjectstorage')
+            client.connections.get_datasource_type_uid_by_name('cloudobjectstorage')
 
         """
         Connections._validate_type(name, u'name', str, True)
@@ -520,21 +478,17 @@ class Connections(WMLResource):
                 datasource_id = ds_resource['metadata']['asset_id']
         return datasource_id
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def upload_db_driver(self, path: str):
-        """
-           Upload db driver jar.
-           Supported for IBM Cloud Pak for Data only, version 4.0.4 and above.
+        """Upload db driver jar. Supported for IBM Cloud Pak for Data only, version 4.0.4 and above.
 
-           **Parameters**
+        :param path:  path to db driver jar
+        :type path: str
 
-           .. important::
-                #. **path**:  path to db driver jar\n
-                   **type**: str\n
+        **Example**
 
-           **Example**
+        .. code-block:: python
 
-            >>> client.connections.upload_db_driver('example/path/db2jcc4.jar')
+            client.connections.upload_db_driver('example/path/db2jcc4.jar')
 
         """
         if not self._client.ICP:
@@ -557,21 +511,17 @@ class Connections(WMLResource):
 
                 self._client.repository._handle_response(201, 'uploading db driver jar', response)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def _upload_db_driver_new_api(self, path: str):
-        """
-           Upload db driver jar.
-           Supported for IBM Cloud Pak for Data only, version 4.6.1 and above.
+        """Upload db driver jar. Supported for IBM Cloud Pak for Data only, version 4.6.1 and above.
 
-           **Parameters**
+        :param path:  path to db driver jar
+        :type path: str
 
-           .. important::
-                #. **path**:  path to db driver jar\n
-                   **type**: str\n
+        **Example**
 
-           **Example**
+        .. code-block:: python
 
-            >>> client.connections._upload_db_driver_new_api('example/path/db2jcc4.jar')
+            client.connections._upload_db_driver_new_api('example/path/db2jcc4.jar')
 
         """
         if not self._client.ICP:
@@ -592,21 +542,19 @@ class Connections(WMLResource):
 
             self._client.repository._handle_response(200, 'uploading db driver jar', response, json_response=False)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_db_driver_url(self, name: str): # TODO not document yet
         # """
-        #    Get signed db driver jar url to be used during creating of JDBC generic connection. The jar name passed as argument needs to be uploaded into system first.
-        #    Supported for IBM Cloud Pak for Data only, version 4.6.1 and above..
+        # Get signed db driver jar url to be used during creating of JDBC generic connection. The jar name passed as argument needs to be uploaded into system first.
+        # Supported for IBM Cloud Pak for Data only, version 4.6.1 and above.
         #
-        #    **Parameters**
+        # :param name:  db driver jar name
+        # :type name: str
         #
-        #    .. important::
-        #         #. **jar_name**:  db driver jar name\n
-        #            **type**: str\n
+        # **Example**
         #
-        #    **Example**
+        # .. code-block:: python
         #
-        #     >>> client.connections.get_db_driver_url('db2jcc4.jar')
+        #     client.connections.get_db_driver_url('db2jcc4.jar')
         #
         # """
         if not self._client.ICP:
@@ -619,21 +567,22 @@ class Connections(WMLResource):
         except:
             raise WMLClientError(f"Driver jar with name {name} not found.")
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def sign_db_driver_url(self, jar_name: str):
-        """
-           Get signed db driver jar url to be used during creating of JDBC generic connection. The jar name passed as argument needs to be uploaded into system first.
-           Supported for IBM Cloud Pak for Data only, version 4.0.4 and above..
+        """Get signed db driver jar url to be used during creating of JDBC generic connection.
+        The jar name passed as argument needs to be uploaded into system first.
+        Supported for IBM Cloud Pak for Data only, version 4.0.4 and above.
 
-           **Parameters**
+        :param jar_name:  db driver jar name
+        :type jar_name: str
 
-           .. important::
-                #. **jar_name**:  db driver jar name\n
-                   **type**: str\n
+        :return: signed db driver url
+        :rtype: str
 
-           **Example**
+        **Example**
 
-            >>> client.connections.sign_db_driver_url('db2jcc4.jar')
+        .. code-block:: python
+
+            jar_uri = client.connections.sign_db_driver_url('db2jcc4.jar')
 
         """
         try:
