@@ -64,17 +64,12 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
         """
 
         columns = ['timestamp', 'run_id', 'state', 'auto_pipeline_optimizer name']
-        wml_pipelines_names = []
-        wml_pipelines_types = []
 
         # note: download all runs details
-        runs_details = self._wml_engine._wml_client.training.get_details(limit=50, _internal=True)
+        runs_details = self._wml_engine._wml_client.training.get_details(get_all=True if self.auto_pipeline_optimizer_name else False,
+                                                                         limit=None if self.auto_pipeline_optimizer_name else 50,
+                                                                         _internal=True)
         data = runs_details.get('resources', [])
-        run_details_generator = NextRunDetailsGenerator(wml_client=self._wml_engine._wml_client,
-                                                        href=runs_details.get('next', {'href': None}).get('href'))
-        for entry in run_details_generator:
-            data.extend(entry)
-        # --- end note
 
         # note: some of the pending experiments do not have these information (checking with if statement)
         runs_pipeline_ids = [run['entity']['pipeline']['id'] for run in data if
@@ -84,44 +79,37 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
         data = [run for run in data if run['entity'].get('pipeline', {}).get('id')]
         # --- end note
 
-        for wml_pipeline_id in runs_pipeline_ids:
-            try:
-                pipeline_details = self._wml_engine._wml_client.pipelines.get_details(
-                    pipeline_uid=wml_pipeline_id)
+        def get_value(wml_pipeline_id, timestamp, run):
+            if not self.auto_pipeline_optimizer_name or self.auto_pipeline_optimizer_name in run['metadata'].get('description', {}):
+                try:
+                    pipeline_details = self._wml_engine._wml_client.pipelines.get_details(
+                        pipeline_uid=wml_pipeline_id)
+                except ApiRequestFailure:
+                    pipeline_details = {'metadata': {'name': 'Experiment data is missing...'}}
+            else:
+                return None
 
-            except ApiRequestFailure:
-                pipeline_details = {'metadata': {'name': 'Experiment data is missing...'}}
+            if self.auto_pipeline_optimizer_name and pipeline_details['metadata']['name'] != self.auto_pipeline_optimizer_name:
+                return None
 
-            wml_pipeline_type = ('autoai' if 'automl' in str(pipeline_details) and
-                                             'hybrid' in str(pipeline_details) else 'other')
+            if not ('automl' in str(pipeline_details) or 'autoai-ts' in str(pipeline_details)) or not 'hybrid' in str(pipeline_details):
+                return None
 
             wml_pipeline_name = pipeline_details['metadata'].get('name', 'Unknown')
 
-            wml_pipelines_names.append(wml_pipeline_name)
-            wml_pipelines_types.append(wml_pipeline_type)
+            return [timestamp, run['metadata'].get('id', run['metadata'].get('guid')), run['entity']['status']['state'],
+                 wml_pipeline_name]
 
-        if self.auto_pipeline_optimizer_name is not None:
-            values = [
-                [timestamp, run['metadata'].get('id', run['metadata'].get('guid')), run['entity']['status']['state'],
-                 wml_pipeline_name] for
-                timestamp, run, wml_pipeline_name, wml_pipeline_type in zip(runs_timestamps,
-                                                                            data,
-                                                                            wml_pipelines_names,
-                                                                            wml_pipelines_types)
-                if wml_pipeline_name == self.auto_pipeline_optimizer_name and wml_pipeline_type == 'autoai']
-
-        else:
-            values = [
-                [timestamp, run['metadata'].get('id', run['metadata'].get('guid')), run['entity']['status']['state'],
-                 wml_pipeline_name] for
-                timestamp, run, wml_pipeline_name, wml_pipeline_type in zip(runs_timestamps,
-                                                                            data,
-                                                                            wml_pipelines_names,
-                                                                            wml_pipelines_types)
-                if wml_pipeline_type == 'autoai']
+        values = []
+        for wml_pipeline_id, timestamp, run in zip(runs_pipeline_ids, runs_timestamps, data):
+            v = get_value(wml_pipeline_id, timestamp, run)
+            if v:
+                values.append(v)
+            if len(values) >= 50:
+                break
 
         runs = DataFrame(data=values, columns=columns)
-        return runs.sort_values(by=["timestamp"], ascending=False)
+        return runs.sort_values(by=["timestamp"], ascending=False)[:50]
 
     def get_params(self, run_id: str = None) -> dict:
         """
