@@ -22,18 +22,15 @@ from ibm_watson_machine_learning.wml_client_error import MissingValue, WMLClient
 from ibm_watson_machine_learning.href_definitions import is_uid
 from ibm_watson_machine_learning.wml_resource import WMLResource
 from multiprocessing import Pool
-from ibm_watson_machine_learning.utils import print_text_header_h1, print_text_header_h2, EXPERIMENT_DETAILS_TYPE,  format_metrics, STR_TYPE, STR_TYPE_NAME, docstring_parameter, group_metrics, str_type_conv, meta_props_str_conv
+from ibm_watson_machine_learning.utils import EXPERIMENT_DETAILS_TYPE
 from ibm_watson_machine_learning.hpo import HPOParameter, HPOMethodParam
 from ibm_watson_machine_learning.metanames import ExperimentMetaNames
-from ibm_watson_machine_learning.href_definitions import API_VERSION, SPACES,PIPELINES, LIBRARIES, EXPERIMENTS, RUNTIMES, DEPLOYMENTS
+from ibm_watson_machine_learning.href_definitions import API_VERSION, SPACES, PIPELINES, LIBRARIES, EXPERIMENTS, RUNTIMES, DEPLOYMENTS
 
 _DEFAULT_LIST_LENGTH = 50
 
 class Experiments(WMLResource):
-    """
-       Run new experiment.
-
-    """
+    """Run new experiment."""
 
     ConfigurationMetaNames = ExperimentMetaNames()
     """MetaNames for experiments creation."""
@@ -51,42 +48,33 @@ class Experiments(WMLResource):
         self._experiments_uids_cache = {}
 
     def store(self, meta_props):
-        """
-                Create an experiment.
+        """Create an experiment.
 
-                **Parameters**
+        :param meta_props: meta data of the experiment configuration. To see available meta names use:
 
-                .. important::
+            .. code-block:: python
 
-                       #. **meta_props**:  meta data of the experiment configuration. To see available meta names use:\n
-                                           >>> client.experiments.ConfigurationMetaNames.get()
+                client.experiments.ConfigurationMetaNames.get()
 
-                          **type**: dict\n
+        :type meta_props: dict
 
-                **Output**
+        :return: stored experiment metadata
+        :rtype: dict
 
-                .. important::
+        **Example**
 
-                       **returns**: stored experiment metadata\n
-                       **return type**: dict\n
+        .. code-block:: python
 
-                **Example**
-
-                    >>> metadata = {
-                    >>>  client.experiments.ConfigurationMetaNames.NAME: 'my_experiment',
-                    >>>  client.experiments.ConfigurationMetaNames.EVALUATION_METRICS: ['accuracy'],
-                    >>>  client.experiments.ConfigurationMetaNames.TRAINING_REFERENCES: [
-                    >>>      {
-                    >>>        'pipeline': {'href': pipeline_href_1}
-                    >>>
-                    >>>      },
-                    >>>      {
-                    >>>        'pipeline': {'href':pipeline_href_2}
-                    >>>      },
-                    >>>   ]
-                    >>> }
-                    >>> experiment_details = client.experiments.store(meta_props=metadata)
-                    >>> experiment_href = client.experiments.get_href(experiment_details)
+            metadata = {
+                client.experiments.ConfigurationMetaNames.NAME: 'my_experiment',
+                client.experiments.ConfigurationMetaNames.EVALUATION_METRICS: ['accuracy'],
+                client.experiments.ConfigurationMetaNames.TRAINING_REFERENCES: [
+                    {'pipeline': {'href': pipeline_href_1}},
+                    {'pipeline': {'href':pipeline_href_2}}
+                ]
+            }
+            experiment_details = client.experiments.store(meta_props=metadata)
+            experiment_href = client.experiments.get_href(experiment_details)
 
         """
         WMLResource._chk_and_block_create_update_for_python36(self)
@@ -111,7 +99,7 @@ class Experiments(WMLResource):
             else:
                 raise WMLClientError(
                     "It is mandatory to set the space/project id. Use client.set.default_space(<SPACE_UID>)/client.set.default_project(<PROJECT_UID>) to proceed.")
-            self._validate_meta_prop(meta_props, self.ConfigurationMetaNames.NAME, STR_TYPE, True)
+            self._validate_meta_prop(meta_props, self.ConfigurationMetaNames.NAME, str, True)
         else:
             self.ConfigurationMetaNames._validate(meta_props)
 
@@ -131,42 +119,33 @@ class Experiments(WMLResource):
 
         return self._handle_response(201, u'saving experiment', response_experiment_post)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def update(self, experiment_uid, changes):
-        """
-                Updates existing experiment metadata.
+        """Updates existing experiment metadata.
 
-                **Parameters**
+        :param experiment_uid: UID of experiment which definition should be updated
+        :type experiment_uid: str
+        :param changes: elements which should be changed, where keys are ConfigurationMetaNames
+        :type changes: dict
 
-                .. important::
-                    #. **experiment_uid**:  UID of experiment which definition should be updated\n
-                       **type**: str\n
-                    #. **changes**:  elements which should be changed, where keys are ConfigurationMetaNames\n
-                       **type**: dict\n
+        :return: metadata of updated experiment
+        :rtype: dict
 
-                **Output**
+        **Example**
 
-                .. important::
+        .. code-block:: python
 
-                     **returns**: metadata of updated experiment\n
-                     **return type**: dict\n
-
-                **Example**
-
-                 >>> metadata = {
-                 >>> client.experiments.ConfigurationMetaNames.NAME:"updated_exp"
-                 >>> }
-                 >>> exp_details = client.experiments.update(experiment_uid, changes=metadata)
+            metadata = {
+                client.experiments.ConfigurationMetaNames.NAME: "updated_exp"
+            }
+            exp_details = client.experiments.update(experiment_uid, changes=metadata)
 
         """
         WMLResource._chk_and_block_create_update_for_python36(self)
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
 
-        experiment_uid = str_type_conv(experiment_uid)
-        self._validate_type(experiment_uid, u'experiment_uid', STR_TYPE, True)
+        self._validate_type(experiment_uid, u'experiment_uid', str, True)
         self._validate_type(changes, u'changes', dict, True)
-        meta_props_str_conv(changes)
 
         details = self._client.repository.get_details(experiment_uid)
 
@@ -178,51 +157,36 @@ class Experiments(WMLResource):
 
         return updated_details
 
-
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_details(self, experiment_uid=None, limit=None, asynchronous=False, get_all=False):
-        """
-                Get metadata of experiment(s). If no experiment UID is specified all experiments metadata is returned.
+        """Get metadata of experiment(s). If no experiment UID is specified all experiments metadata is returned.
 
-                **Parameters**
+        :param experiment_uid:  UID of experiment
+        :type experiment_uid: str, optional
+        :param limit: limit number of fetched records
+        :type limit: int, optional
+        :param asynchronous: if `True`, it will work as a generator
+        :type asynchronous: bool, optional
+        :param get_all: if `True`, it will get all entries in 'limited' chunks
+        :type get_all: bool, optional
 
-                .. important::
+        :return: experiment(s) metadata
+        :rtype: dict (if UID is not None) or {"resources": [dict]} (if UID is None)
 
-                       #. **experiment_uid**:  UID of experiment (optional)\n
-                          **type**: str\n
-                       #. **limit**:  limit number of fetched records (optional)\n
-                          **type**: int\n
-                       #. **asynchronous**:  if True, it will work as a generator (optional)\n
-                          **type**: bool\n
-                       #. **get_all**:  if True, it will get all entries in 'limited' chunks (optional)\n
-                          **type**: bool\n
+        **Example**
 
-                **Output**
+        .. code-block:: python
 
-                .. important::
-
-                    **returns**: experiment(s) metadata\n
-                    **return type**: dict\n
-                    dict (if UID is not None) or {"resources": [dict]} (if UID is None)\n
-
-                .. note::
-
-                   If UID is not specified, all experiments metadata is fetched\n
-
-                **Example**
-
-                     >>> experiment_details = client.experiments.get_details(experiment_uid)
-                     >>> experiment_details = client.experiments.get_details()
-                     >>> experiment_details = client.experiments.get_details(limit=100)
-                     >>> experiment_details = client.experiments.get_details(limit=100, get_all=True)
-                     >>> experiment_details = []
-                     >>> for entry in client.experiments.get_details(limit=100, asynchronous=True, get_all=True):
-                     >>>    experiment_details.extend(entry)
+            experiment_details = client.experiments.get_details(experiment_uid)
+            experiment_details = client.experiments.get_details()
+            experiment_details = client.experiments.get_details(limit=100)
+            experiment_details = client.experiments.get_details(limit=100, get_all=True)
+            experiment_details = []
+            for entry in client.experiments.get_details(limit=100, asynchronous=True, get_all=True):
+                experiment_details.extend(entry)
 
          """
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
-        experiment_uid = str_type_conv(experiment_uid)
         url = self._client.service_instance._href_definitions.get_experiments_href()
 
         if experiment_uid is None:
@@ -233,29 +197,21 @@ class Experiments(WMLResource):
             return self._get_artifact_details(url, experiment_uid, limit, 'experiment')
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_uid(experiment_details):
-        """
-                Get Unique Id of stored experiment.
+        """Get Unique Id of stored experiment.
 
-                **Parameters**
+        :param experiment_details: metadata of the stored experiment
+        :type experiment_details: dict
 
-                .. important::
+        :return: Unique Id of stored experiment
+        :rtype: str
 
-                    #. **experiment_details**:  Metadata of the stored experiment\n
-                       **type**: dict\n
+        **Example**
 
-                **Output**
+        .. code-block:: python
 
-                .. important::
-
-                        **returns**: Unique Id of stored experiment\n
-                        **return type**: str\n
-
-                **Example**
-
-                     >>> experiment_details = client.experiments.get_detailsf(experiment_uid)
-                     >>> experiment_uid = client.experiments.get_uid(experiment_details)
+            experiment_details = client.experiments.get_details(experiment_uid)
+            experiment_uid = client.experiments.get_uid(experiment_details)
 
         """
         Experiments._validate_type(experiment_details, u'experiment_details', object, True)
@@ -266,29 +222,21 @@ class Experiments(WMLResource):
                                                            [u'metadata', u'id'])
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_id(experiment_details):
-        """
-                Get Unique Id of stored experiment.
+        """Get Unique Id of stored experiment.
 
-                **Parameters**
+        :param experiment_details: metadata of the stored experiment
+        :type experiment_details: dict
 
-                .. important::
+        :return: Unique Id of stored experiment
+        :rtype: str
 
-                    #. **experiment_details**:  Metadata of the stored experiment\n
-                       **type**: dict\n
+        **Example**
 
-                **Output**
+        .. code-block:: python
 
-                .. important::
-
-                        **returns**: Unique Id of stored experiment\n
-                        **return type**: str\n
-
-                **Example**
-
-                     >>> experiment_details = client.experiments.get_detailsf(experiment_id)
-                     >>> experiment_uid = client.experiments.get_id(experiment_details)
+            experiment_details = client.experiments.get_details(experiment_id)
+            experiment_uid = client.experiments.get_id(experiment_details)
 
         """
         Experiments._validate_type(experiment_details, u'experiment_details', object, True)
@@ -299,29 +247,21 @@ class Experiments(WMLResource):
                                                            [u'metadata', u'id'])
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_href(experiment_details):
-        """
-                Get href of stored experiment.
+        """Get href of stored experiment.
 
-                **Parameters**
+        :param experiment_details: metadata of the stored experiment
+        :type experiment_details: dict
 
-                .. important::
+        :return: href of stored experiment
+        :rtype: str
 
-                      #. **experiment_details**:  Metadata of the stored experiment\n
-                         **type**: dict\n
+        **Example**
 
-                **Output**
+        .. code-block:: python
 
-                .. important::
-
-                     **returns**: href of stored experiment\n
-                     **return type**: str\n
-
-                **Example**
-
-                 >>> experiment_details = client.experiments.get_detailsf(experiment_uid)
-                 >>> experiment_href = client.experiments.get_href(experiment_details)
+            experiment_details = client.experiments.get_details(experiment_uid)
+            experiment_href = client.experiments.get_href(experiment_details)
 
         """
         Experiments._validate_type(experiment_details, u'experiment_details', object, True)
@@ -335,59 +275,43 @@ class Experiments(WMLResource):
                                                                      [u'metadata', u'id'])
             return "/ml/v4/experiments/" + experiment_id
 
-
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def delete(self, experiment_uid):
-        """
-            Delete a stored experiment.
+        """Delete a stored experiment.
 
-            **Parameters**
+        :param experiment_uid: Unique Id of the stored experiment
+        :type experiment_uid: str
 
-            .. important::
-                #. **experiment_uid**:  Unique Id of the stored experiment\n
-                   **type**: str\n
+        :return: status ("SUCCESS" or "FAILED")
+        :rtype: str
 
-            **Output**
+        **Example**
 
-            .. important::
-                **returns**: status ("SUCCESS" or "FAILED")\n
-                **return type**: str\n
+        .. code-block:: python
 
-            **Example**
-
-                >>> client.experiments.delete(experiment_uid)
+            client.experiments.delete(experiment_uid)
 
         """
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
-        experiment_uid = str_type_conv(experiment_uid)
-        Experiments._validate_type(experiment_uid, u'experiment_uid', STR_TYPE, True)
+        Experiments._validate_type(experiment_uid, u'experiment_uid', str, True)
 
         url = self._client.service_instance._href_definitions.get_experiment_href(experiment_uid)
         response = requests.delete(url, params = self._client._params(),headers=self._client._get_headers())
 
         return self._handle_response(204, u'experiment deletion', response, False)
 
-
     def list(self, limit=None):
-        """
-           List stored experiments. If limit is set to None there will be only first 50 records shown.
+        """Print stored experiments in a table format.
+        If limit is set to None there will be only first 50 records shown.
 
-           **Parameters**
+        :param limit: limit number of fetched records
+        :type limit: int, optional
 
-           .. important::
-                #. **limit**:  limit number of fetched records\n
-                   **type**: int\n
+        **Example**
 
-           **Output**
+        .. code-block:: python
 
-           .. important::
-                This method only prints the list of all experiments in a table format.\n
-                **return type**: None\n
-
-           **Example**
-
-                >>> client.experiments.list()
+            client.experiments.list()
 
         """
         ##For CP4D, check if either spce or project ID is set
@@ -404,23 +328,27 @@ class Experiments(WMLResource):
 
         self._list(experiment_values, header_list, limit, _DEFAULT_LIST_LENGTH)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def create_revision(self, experiment_id):
-        """
-        Creates a new experiment revision.
-        :param experiment_id:
-        :return:  stored experiment new revision details
-        Example:
+        """Creates a new experiment revision.
 
-           >>> experiment_revision_artifact = client.experiments.create_revision(experiment_id)
+        :param experiment_id: Unique Id of the stored experiment
+        :type experiment_id: str
+
+        :return: stored experiment new revision details
+        :rtype: dict
+
+        **Example**
+
+        .. code-block:: python
+
+            experiment_revision_artifact = client.experiments.create_revision(experiment_id)
 
         """
         WMLResource._chk_and_block_create_update_for_python36(self)
 
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
-        experiment_id = str_type_conv(experiment_id)
-        Experiments._validate_type(experiment_id, u'experiment_id', STR_TYPE, True)
+        Experiments._validate_type(experiment_id, u'experiment_id', str, True)
 
         if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(
@@ -429,28 +357,27 @@ class Experiments(WMLResource):
             url =self._client.service_instance._href_definitions.get_experiments_href()
             return self._create_revision_artifact(url, experiment_id, 'experiments')
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_revision_details(self, experiment_uid, rev_uid):
-        """
-            Get metadata of stored experiments revisions.
+        """Get metadata of stored experiments revisions.
 
-            :param experiment_uid: stored experiment UID (optional)
-            :type experiment_uid: {str_type}
+        :param experiment_uid: stored experiment UID
+        :type experiment_uid: str
 
-            :param rev_id: rev_id number of experiment
-            :type rev_id: int
+        :param rev_uid: rev_id number of experiment
+        :type rev_uid: int
 
-            :returns: stored experiment revision metadata
-            :rtype: dict
+        :return: stored experiment revision metadata
+        :rtype: dict
 
-            Example:
+        Example:
 
-            >>> experiment_details = client.repository.get_revision_details(experiment_uid,rev_id)
+        .. code-block:: python
+
+            experiment_details = client.experiments.get_revision_details(experiment_uid, rev_id)
 
          """
         self._client._check_if_either_is_set()
-        model_uid = str_type_conv(experiment_uid)
-        Experiments._validate_type(experiment_uid, u'experiment_uid', STR_TYPE, True)
+        Experiments._validate_type(experiment_uid, u'experiment_uid', str, True)
         Experiments._validate_type(rev_uid, u'rev_uid', int, True)
         if not self._client.ICP_30 and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(
@@ -460,27 +387,26 @@ class Experiments(WMLResource):
             return self._get_with_or_without_limit(url, limit=None, op_name="experiments",
                                                    summary=None, pre_defined=None, revision=rev_uid)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def list_revisions(self, experiment_uid, limit=None):
-        """
-           List all revision for the given experiment uid.
+        """Print all revision for the given experiment uid in a table format.
 
-           :param experiment_uid: Unique id of stored experiment.
-           :type experiment_uid: {str_type}
+        :param experiment_uid: Unique id of stored experiment
+        :type experiment_uid: str
 
-           :param limit: limit number of fetched records (optional)
-           :type limit: int
+        :param limit: limit number of fetched records
+        :type limit: int, optional
 
-           :returns: stored experiment revisions details
-           :rtype: table
+        **Example**
+
+        .. code-block:: python
+
+            client.experiments.list_revisions(experiment_uid)
 
-           >>> client.experiments.list_revisions(experiment_uid)
         """
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
-        experiment_uid = str_type_conv(experiment_uid)
 
-        Experiments._validate_type(experiment_uid, u'experiment_uid', STR_TYPE, True)
+        Experiments._validate_type(experiment_uid, u'experiment_uid', str, True)
 
         if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(
@@ -494,60 +420,46 @@ class Experiments(WMLResource):
 
             self._list(experiment_values, [u'GUID', u'NAME', u'CREATED'], limit, _DEFAULT_LIST_LENGTH)
 
-
     def clone(self, experiment_uid, space_id=None, action="copy", rev_id=None):
+        """Creates a new experiment identical with the given experiment either in the same space or in a new space.
+        All dependent assets will be cloned too.
+
+        :param experiment_uid:  Unique Id of the experiment to be cloned
+        :type experiment_uid: str
+
+        :param space_id: Unique Id of the space to which the experiment needs to be cloned
+        :type space_id: str, optional
+
+        :param action: action specifying "copy" or "move"
+        :type action: str, optional
+
+        :param rev_id: revision ID of the experiment
+        :type rev_id: str, optional
+
+        :return: metadata of the experiment cloned
+        :rtype: dict
+
+        **Example**
+
+        .. code-block:: python
+
+            client.experiments.clone(experiment_uid=artifact_id,space_id=space_uid,action="copy")
+
+        .. note::
+
+            * If revision id is not specified, all revisions of the artifact are cloned.
+
+            * Space id is mandatory for move action.
+
         """
-            Creates a new experiment identical with the given experiment either in the same space or in a new space. All dependent assets will be cloned too.
-
-            **Parameters**
-
-            .. important::
-                #. **model_id**:  Guid of the experiment to be cloned:\n
-
-                   **type**: str\n
-
-                #. **space_id**: Guid of the space to which the experiment needs to be cloned. (optional)
-
-                   **type**: str\n
-
-                #. **action**: Action specifying "copy" or "move". (optional)
-
-                   **type**: str\n
-
-                #. **rev_id**: Revision ID of the experiment. (optional)
-
-                   **type**: str\n
-
-            **Output**
-
-            .. important::
-
-                    **returns**: Metadata of the experiment cloned.\n
-                    **return type**: dict\n
-
-            **Example**
-             >>> client.experiments.clone(experiment_uid=artifact_id,space_id=space_uid,action="copy")
-
-            .. note::
-                * If revision id is not specified, all revisions of the artifact are cloned\n
-
-                * Default value of the parameter action is copy\n
-
-                * Space id is mandatory for move action\n
-
-            """
-        artifact = str_type_conv(experiment_uid)
-        Experiments._validate_type(artifact, 'experiment_uid', STR_TYPE, True)
-        space = str_type_conv(space_id)
-        rev = str_type_conv(rev_id)
-        action = str_type_conv(action)
+        Experiments._validate_type(experiment_uid, 'experiment_uid', str, True)
         clone_meta = {}
-        if space is not None:
-            clone_meta["space"] = {"href": API_VERSION + SPACES + "/" + space}
+        if space_id is not None:
+            clone_meta["space"] = {"href": API_VERSION + SPACES + "/" + space_id}
         if action is not None:
             clone_meta["action"] = action
-        if rev is not None:
-            clone_meta["rev"] = rev
+        if rev_id is not None:
+            clone_meta["rev"] = rev_id
 
         url = self._client.service_instance._href_definitions.get_experiment_href(experiment_uid)
         response_post = requests.post(url, json=clone_meta,
