@@ -15,19 +15,15 @@
 from __future__ import print_function
 import ibm_watson_machine_learning._wrappers.requests as requests
 import json
-from ibm_watson_machine_learning.utils import DEPLOYMENT_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, print_text_header_h1, \
-    print_text_header_h2, STR_TYPE, STR_TYPE_NAME, docstring_parameter, str_type_conv, \
-    StatusLogger, meta_props_str_conv, convert_metadata_to_parameters
+from ibm_watson_machine_learning.utils import INSTANCE_DETAILS_TYPE, print_text_header_h2
 from ibm_watson_machine_learning.wml_client_error import WMLClientError, WrongMetaProps
 from ibm_watson_machine_learning.wml_resource import WMLResource
 from .metanames import FactsheetsMetaNames
 
 
 class Factsheets(WMLResource):
-    """
-        Link WML Model to Model Entry
+    """Link WML Model to Model Entry."""
 
-    """
     cloud_platform_spaces = False
     icp_platform_spaces = False
 
@@ -45,51 +41,48 @@ class Factsheets(WMLResource):
         if client.ICP_PLATFORM_SPACES:
             Factsheets.icp_platform_spaces = True
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def register_model_entry(self, model_id, meta_props, catalog_id=None):
+        """Link WML Model to Model Entry
+
+        :param model_id: published model/asset ID
+        :type model_id: str
+
+        :param meta_props: metaprops, to see the available list of metanames use:
+
+            .. code-block:: python
+
+                client.factsheets.ConfigurationMetaNames.get()
+
+        :type meta_props: dict
+
+        :param catalog_id: catalog ID where you want to register model
+        :type catalog_id: str, optional
+
+        :return: metadata of the registration
+        :rtype: dict
+
+        **Example**
+
+        .. code-block:: python
+
+            meta_props = {
+                wml_client.factsheets.ConfigurationMetaNames.ASSET_ID: '83a53931-a8c0-4c2f-8319-c793155e7517'}
+
+            registration_details = client.factsheets.register_model_entry(model_id, catalog_id, meta_props)
+
+        or
+
+        .. code-block:: python
+
+            meta_props = {
+                wml_client.factsheets.ConfigurationMetaNames.NAME: "New model entry",
+                wml_client.factsheets.ConfigurationMetaNames.DESCRIPTION: "New model entry"}
+
+            registration_details = client.factsheets.register_model_entry(model_id, meta_props)
+
         """
-            Link WML Model to Model Entry
-
-            **Parameters**
-
-            .. important::
-
-                #. **model_id**:  Published model/asset ID\n
-                   **type**: str\n
-
-                #. **catalog_id**:  Catalog ID where you want to register model\n
-                   **type**: str\n
-
-                #. **meta_props**: metaprops. To see the available list of metanames use:\n
-                                   >>> client.factsheets.ConfigurationMetaNames.get()
-
-                   **type**: dict\n
-
-            **Output**
-
-            .. important::
-
-                **returns**: metadata of the registration\n
-                **return type**: dict\n
-
-            **Example**
-
-             >>> meta_props = {
-             >>> wml_client.factsheets.ConfigurationMetaNames.ASSET_ID: '83a53931-a8c0-4c2f-8319-c793155e7517'
-             >>> }
-             >>> registration_details = client.factsheets.register_model_entry(model_id, catalog_id, meta_props)
-
-             or
-
-             >>> meta_props = {
-             >>> wml_client.factsheets.ConfigurationMetaNames.NAME: "New model entry",
-             >>> wml_client.factsheets.ConfigurationMetaNames.DESCRIPTION: "New model entry"
-             >>> }
-             >>> registration_details = client.factsheets.register_model_entry(model_id, meta_props)
-
-         """
-        Factsheets._validate_type(model_id, u'model_id', STR_TYPE, True)
-        Factsheets._validate_type(catalog_id, u'catalog_id', STR_TYPE, False)
+        Factsheets._validate_type(model_id, u'model_id', str, True)
+        Factsheets._validate_type(catalog_id, u'catalog_id', str, False)
         metaProps = self.ConfigurationMetaNames._generate_resource_metadata(meta_props)
 
         params = self._client._params()
@@ -144,32 +137,24 @@ class Factsheets(WMLResource):
 
         return response.json()
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def list_model_entries(self, catalog_id=None):
+        """Returns all WKC Model Entry assets for a catalog.
+
+        :param catalog_id: catalog ID where you want to register model, if None list from all catalogs
+        :type catalog_id: str, optional
+
+        :return: all WKC Model Entry assets for a catalog
+        :rtype: dict
+
+        **Example**
+
+        .. code-block:: python
+
+            model_entries = client.factsheets.list_model_entries(catalog_id)
+
         """
-            Returns all WKC Model Entry assets for a catalog
-
-            **Parameters**
-
-            .. important::
-
-                #. **catalog_id**:  Catalog ID where you want to register model, if None list from all catalogs.\n
-                   **type**: str\n
-
-            **Output**
-
-            .. important::
-
-                **returns**: all WKC Model Entry assets for a catalog\n
-                **return type**: dict\n
-
-            **Example**
-
-             >>> model_entries = client.factsheets.list_model_entries(catalog_id)
-
-         """
         if catalog_id is not None:
-            Factsheets._validate_type(catalog_id, u'catalog_id', STR_TYPE, True)
+            Factsheets._validate_type(catalog_id, u'catalog_id', str, True)
             url = self._client.service_instance._href_definitions.get_wkc_model_list_from_catalog_href(catalog_id)
 
         else:
@@ -195,34 +180,32 @@ class Factsheets(WMLResource):
             print_text_header_h2(error_msg)
             raise WMLClientError(error_msg + '. Error: ' + str(response.status_code) + '. ' + reason)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def unregister_model_entry(self, asset_id, catalog_id: str = None):
+        """Unregister WKC Model Entry
+
+        :param asset_id:  WKC model entry id
+        :type asset_id: str
+
+        :param catalog_id: catalog ID where asset is stored, when not provided,
+            default client space or project will be taken
+        :type catalog_id: str, optional
+
+        **Example**
+
+        .. code-block:: python
+
+            model_entries = client.factsheets.unregister_model_entry(asset_id='83a53931-a8c0-4c2f-8319-c793155e7517',
+                                                                     catalog_id='34553931-a8c0-4c2f-8319-c793155e7517')
+        or
+
+        .. code-block:: python
+
+            client.set.default_space('98f53931-a8c0-4c2f-8319-c793155e7517')
+            model_entries = client.factsheets.unregister_model_entry(asset_id='83a53931-a8c0-4c2f-8319-c793155e7517')
+
         """
-            Unregister WKC Model Entry
-
-            **Parameters**
-
-            .. important::
-
-                #. **asset_id**:  WKC model entry id\n
-                   **type**: str\n
-
-                #. **catalog_id**:  Catalog ID where asset is stored, optional, when not provided,
-                                    default client space or project will be taken.\n
-                   **type**: str\n
-
-            **Example**
-
-             >>> model_entries = client.factsheets.unregister_model_entry(asset_id='83a53931-a8c0-4c2f-8319-c793155e7517',
-             >>>    catalog_id='34553931-a8c0-4c2f-8319-c793155e7517')
-             or
-
-             >>> client.set.default_space('98f53931-a8c0-4c2f-8319-c793155e7517')
-             >>> model_entries = client.factsheets.unregister_model_entry(asset_id='83a53931-a8c0-4c2f-8319-c793155e7517')
-
-         """
-        Factsheets._validate_type(asset_id, u'asset_id', STR_TYPE, True)
-        Factsheets._validate_type(catalog_id, u'catalog_id', STR_TYPE, False)
+        Factsheets._validate_type(asset_id, u'asset_id', str, True)
+        Factsheets._validate_type(catalog_id, u'catalog_id', str, False)
         url = self._client.service_instance._href_definitions.get_wkc_model_delete_href(asset_id)
 
         params = self._client._params()
