@@ -14,7 +14,7 @@
 
 from __future__ import print_function
 import ibm_watson_machine_learning._wrappers.requests as requests
-from ibm_watson_machine_learning.utils import INSTANCE_DETAILS_TYPE, FUNCTION_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, str_type_conv, is_of_python_basic_type, meta_props_str_conv
+from ibm_watson_machine_learning.utils import INSTANCE_DETAILS_TYPE, FUNCTION_DETAILS_TYPE, is_of_python_basic_type
 from ibm_watson_machine_learning.metanames import FunctionMetaNames, FunctionNewMetaNames
 import os
 import json
@@ -25,11 +25,10 @@ _DEFAULT_LIST_LENGTH = 50
 
 
 class Functions(WMLResource):
-    """
-    Store and manage your functions.
-    """
+    """Store and manage your functions."""
+
     # ConfigurationMetaNames = FunctionMetaNames()
-    """MetaNames for python functions creation."""
+    #"""MetaNames for python functions creation."""
 
     def __init__(self, client):
         WMLResource.__init__(self, __name__, client)
@@ -44,65 +43,65 @@ class Functions(WMLResource):
         else:
             self.ConfigurationMetaNames = FunctionMetaNames()
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def store(self, function, meta_props):
+        """Create a function.
+
+        As a 'function' may be used one of the following:
+            - filepath to gz file
+            - 'score' function reference, where the function is the function which will be deployed
+            - generator function, which takes no argument or arguments which all have primitive python default values
+              and as result return 'score' function
+
+        :param function: path to file with archived function content or function (as described above)
+        :type function: str or function
+        :param meta_props: meta data or name of the function, to see available meta names
+            use ``client._functions.ConfigurationMetaNames.show()``
+        :type meta_props: str or dict
+
+        :return: stored function metadata
+        :rtype: dict
+
+        **Examples**
+
+        The most simple use is (using `score` function):
+
+        .. code-block:: python
+
+            meta_props = {
+                client._functions.ConfigurationMetaNames.NAME: "function",
+                client._functions.ConfigurationMetaNames.DESCRIPTION: "This is ai function",
+                client._functions.ConfigurationMetaNames.SOFTWARE_SPEC_UID: "53dc4cf1-252f-424b-b52d-5cdd9814987f"}
+
+            def score(payload):
+                values = [[row[0]*row[1]] for row in payload['values']]
+                return {'fields': ['multiplication'], 'values': values}
+
+            stored_function_details = client._functions.store(score, meta_props)
+
+        Other, more interesting example is using generator function.
+        In this situation it is possible to pass some variables:
+
+        .. code-block:: python
+
+            wml_creds = {...}
+
+            def gen_function(wml_credentials=wml_creds, x=2):
+                def f(payload):
+                    values = [[row[0]*row[1]*x] for row in payload['values']]
+                    return {'fields': ['multiplication'], 'values': values}
+                return f
+
+            stored_function_details = client._functions.store(gen_function, meta_props)
+
         """
-            Create a function.
-
-            As a 'function' may be used one of the following:
-             - filepath to gz file
-             - 'score' function reference, where the function is the function which will be deployed
-             - generator function, which takes no argument or arguments which all have primitive python default values and as result return 'score' function
-
-           **Parameters**
-
-           .. important::
-                #. **meta_props**:  meta data or name of the function. To see available meta names use **client._functions.ConfigurationMetaNames.show()\n
-                   **type**: str or dict\n
-                #. **function**:  path to file with archived function content or function (as described above)\n
-                   **type**: str or function\n
-
-           **Output**
-
-           .. important::
-                **returns**: stored function metadata\n
-                **return type**: dict\n
-
-           **Example**
-
-            The most simple use is (using `score` function):
-
-             >>> meta_props = {
-             >>>    client._functions.ConfigurationMetaNames.NAME: "function",
-             >>>    client._functions.ConfigurationMetaNames.DESCRIPTION: "This is ai function",
-             >>>    client._functions.ConfigurationMetaNames.SOFTWARE_SPEC_UID: "53dc4cf1-252f-424b-b52d-5cdd9814987f"}
-
-             >>> def score(payload):
-             >>>      values = [[row[0]*row[1]] for row in payload['values']]
-             >>>      return {'fields': ['multiplication'], 'values': values}
-             >>> stored_function_details = client._functions.store(score, meta_props)
-
-             Other, more interesting example is using generator function.
-             In this situation it is possible to pass some variables:
-
-                >>> wml_creds = {...}
-                >>> def gen_function(wml_credentials=wml_creds, x=2):
-                        def f(payload):
-                            values = [[row[0]*row[1]*x] for row in payload['values']]
-                            return {'fields': ['multiplication'], 'values': values}
-                        return f
-                >>> stored_function_details = client._functions.store(gen_function, meta_props)
-            """
         WMLResource._chk_and_block_create_update_for_python36(self)
         self._client._check_if_either_is_set()
 
-        function = str_type_conv(function)
         import types
-        Functions._validate_type(function, u'function', [STR_TYPE, types.FunctionType], True)
-        meta_props = str_type_conv(meta_props)  # meta_props may be str, in this situation for py2 it will be converted to unicode
-        Functions._validate_type(meta_props, u'meta_props', [dict, STR_TYPE], True)
+        Functions._validate_type(function, u'function', [str, types.FunctionType], True)
+        Functions._validate_type(meta_props, u'meta_props', [dict, str], True)
 
-        if type(meta_props) is STR_TYPE:
+        if type(meta_props) is str:
             meta_props = {
                 self.ConfigurationMetaNames.NAME: meta_props
             }
@@ -285,24 +284,25 @@ class Functions(WMLResource):
         return details
 
     def update(self, function_uid, changes, update_function=None):
-        """
-        Updates existing function metadata.
+        """Updates existing function metadata.
 
-        **Parameters**
-
-        .. important::
-           #. **function_uid**:  UID of function which define what should be updated\n
-              **type**: str\n
-           #. **changes**:  elements which should be changed, where keys are ConfigurationMetaNames\n
-              **type**: dict\n
-           #. **update_function**:  path to file with archived function content or function which should be changed for specific function_uid\n.This parameters is valid only for CP4D 3.0.0.
-              **type**: str or function\n
+        :param function_uid: UID of function which define what should be updated
+        :type function_uid: str
+        :param changes: elements which should be changed, where keys are ConfigurationMetaNames
+        :type changes: dict
+        :param update_function: path to file with archived function content or function which should be changed
+            for specific function_uid, this parameter is valid only for CP4D 3.0.0
+        :type update_function: str or function, optional
 
         **Example**
-         >>> metadata = {
-         >>> client._functions.ConfigurationMetaNames.NAME:"updated_function"
-         >>> }
-         >>> function_details = client._functions.update(function_uid, changes=metadata)
+
+        .. code-block:: python
+
+            metadata = {
+                client._functions.ConfigurationMetaNames.NAME: "updated_function"
+            }
+
+            function_details = client._functions.update(function_uid, changes=metadata)
 
         """
         WMLResource._chk_and_block_create_update_for_python36(self)
@@ -313,10 +313,8 @@ class Functions(WMLResource):
 
         self._client._check_if_either_is_set()
 
-        function_uid = str_type_conv(function_uid)
-        self._validate_type(function_uid, u'function_uid', STR_TYPE, True)
+        self._validate_type(function_uid, u'function_uid', str, True)
         self._validate_type(changes, u'changes', dict, True)
-        meta_props_str_conv(changes)
 
         details = self.get_details(function_uid)
 
@@ -334,12 +332,10 @@ class Functions(WMLResource):
         return updated_details
 
     def _update_function_content(self, function_uid, updated_function):
-
-        function = str_type_conv(updated_function)
         import types
-        Functions._validate_type(function, u'function', [STR_TYPE, types.FunctionType], True)
+        Functions._validate_type(updated_function, u'function', [str, types.FunctionType], True)
 
-        content_path, user_content_file, archive_name = self._prepare_function_content(function)
+        content_path, user_content_file, archive_name = self._prepare_function_content(updated_function)
 
         try:
             if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
@@ -361,34 +357,24 @@ class Functions(WMLResource):
             except:
                 pass
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def download(self, function_uid, filename='downloaded_function.gz', rev_uid=None):
-        """
-            Download function content from Watson Machine Learning repository to local file.
+        """Download function content from Watson Machine Learning repository to local file.
 
-            **Parameters**
-
-            .. important::
-                #. **function_uid**:  stored function UID\n
-                   **type**: str\n
-                #. **filename**:  name of local file to create (optional) Example: function_content.gz\n
-                   **default value**: downloaded_function.gz\n
-                   **type**: str\n
+        :param function_uid: stored function UID
+        :type function: str
+        :param filename: name of local file to create, example: function_content.gz
+        :type filename: str, optional
 
 
-            **Output**
+        :return: path to the downloaded function content
+        :rtype: str
 
-            .. important::
+        **Example**
 
-               **returns**: Path to the downloaded function content\n
-               **return type**: str\n
+        .. code-block:: python
 
-            .. note::
-               If filename is not specified, the default filename is "downloaded_function.gz".\n
+            client._functions.download(function_uid, 'my_func.tar.gz')
 
-            **Example**
-
-             >>> client._functions.download(function_uid, 'my_func.tar.gz')
         """
         self._client._check_if_either_is_set()
 
@@ -397,12 +383,10 @@ class Functions(WMLResource):
         if rev_uid is not None and self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(u'Not applicable for this release')
 
-        artifact_uid = str_type_conv(function_uid)
-        Functions._validate_type(artifact_uid, u'artifact_uid', STR_TYPE, True)
-        filename = str_type_conv(filename)
-        Functions._validate_type(filename, u'filename', STR_TYPE, True)
+        Functions._validate_type(function_uid, u'function_uid', str, True)
+        Functions._validate_type(filename, u'filename', str, True)
 
-        artifact_url = self._client.service_instance._href_definitions.get_function_href(artifact_uid)
+        artifact_url = self._client.service_instance._href_definitions.get_function_href(function_uid)
         if self._client.WSD:
             import urllib
             function_get_response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(function_uid),
@@ -416,9 +400,9 @@ class Functions(WMLResource):
                                    urllib.parse.quote('wml_function/' + attachment_url, safe='')
         else:
             if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
-                artifact_content_url = self._client.service_instance._href_definitions.get_function_href(artifact_uid) + '/code'
+                artifact_content_url = self._client.service_instance._href_definitions.get_function_href(function_uid) + '/code'
             else:
-                artifact_content_url = self._client.service_instance._href_definitions.get_function_latest_revision_content_href(artifact_uid)
+                artifact_content_url = self._client.service_instance._href_definitions.get_function_latest_revision_content_href(function_uid)
 
         try:
             if not self._ICP and not self._client.WSD:
@@ -464,31 +448,24 @@ class Functions(WMLResource):
         except IOError as e:
             raise WMLClientError(u'Saving function content with artifact_url: \'{}\' failed.'.format(filename), e)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def delete(self, function_uid):
-        """
-            Delete a stored function.
+        """Delete a stored function.
 
-            **Parameters**
+        :param function_uid: stored function UID
+        :type function_uid: str
 
-            .. important::
-                #. **function_uid**:  stored function UID\n
-                   **type**: str\n
+        :return: status ("SUCCESS" or "FAILED")
+        :rtype: str
 
-            **Output**
+        **Example**
 
-            .. important::
-                **returns**: status ("SUCCESS" or "FAILED")\n
-                **return type**: str\n
+        .. code-block:: python
 
-            **Example**
-
-             >>> client._functions.delete(function_uid)
+            client._functions.delete(function_uid)
         """
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
-        function_uid = str_type_conv(function_uid)
-        Functions._validate_type(function_uid, u'function_uid', STR_TYPE, True)
+        Functions._validate_type(function_uid, u'function_uid', str, True)
         if (self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES) and \
                 self._if_deployment_exist_for_asset(function_uid):
             raise WMLClientError(
@@ -518,13 +495,11 @@ class Functions(WMLResource):
             response_delete = requests.delete(function_endpoint, params = self._client._params(), headers=self._client._get_headers())
         return self._handle_response(204, u'function deletion', response_delete, False)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def _delete(self, function_uid):
 
         ##For CP4D, check if either spce or project ID is set
 
-        function_uid = str_type_conv(function_uid)
-        Functions._validate_type(function_uid, u'function_uid', STR_TYPE, True)
+        Functions._validate_type(function_uid, u'function_uid', str, True)
         ##TODO_V4 Uncomment this after deployments is ready
         # Delete associated deployments, so there will be no orphans
         if self._client.WSD:
@@ -551,47 +526,36 @@ class Functions(WMLResource):
                                               headers=self._client._get_headers())
         response_delete
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_details(self, function_uid=None, limit=None, asynchronous=False, get_all=False):
+        """Get metadata of function(s). If no function UID is specified all functions metadata is returned.
+
+        :param function_uid: UID of function
+        :type: str, optional
+        :param limit: limit number of fetched records
+        :type limit: int, optional
+        :param asynchronous: if `True`, it will work as a generator
+        :type asynchronous: bool, optional
+        :param get_all: if `True`, it will get all entries in 'limited' chunks
+        :type get_all: bool, optional
+
+        :return: function(s) metadata
+        :rtype: dict (if UID is not None) or {"resources": [dict]} (if UID is None)
+
+        **Example**
+
+        .. code-block:: python
+
+            function_details = client._functions.get_details(function_uid)
+            function_details = client._functions.get_details()
+            function_details = client._functions.get_details(limit=100)
+            function_details = client._functions.get_details(limit=100, get_all=True)
+            function_details = []
+            for entry in client._functions.get_details(limit=100, asynchronous=True, get_all=True):
+                function_details.extend(entry)
         """
-            Get metadata of function(s). If no function UID is specified all functions metadata is returned.
-
-           **Parameters**
-
-           .. important::
-                #. **function_uid**:  UID of function (optional)\n
-                   **type**: str\n
-                #. **limit**:  limit number of fetched records (optional)\n
-                   **type**: int\n
-                #. **asynchronous**:  if True, it will work as a generator (optional)\n
-                   **type**: bool\n
-                #. **get_all**:  if True, it will get all entries in 'limited' chunks (optional)\n
-                   **type**: bool\n
-
-           **Output**
-
-           .. important::
-                **returns**: function(s) metadata\n
-                **return type**: dict\n
-                dict (if UID is not None) or {"resources": [dict]} (if UID is None)\n
-
-           .. note::
-                If UID is not specified, all functions metadata is fetched\n
-
-           **Example**
-
-             >>> function_details = client._functions.get_details(function_uid)
-             >>> function_details = client._functions.get_details()
-             >>> function_details = client._functions.get_details(limit=100)
-             >>> function_details = client._functions.get_details(limit=100, get_all=True)
-             >>> function_details = []
-             >>> for entry in client._functions.get_details(limit=100, asynchronous=True, get_all=True):
-             >>>    function_details.extend(entry)
-         """
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
-        function_uid = str_type_conv(function_uid)
-        Functions._validate_type(function_uid, u'function_uid', STR_TYPE, False)
+        Functions._validate_type(function_uid, u'function_uid', str, False)
         Functions._validate_type(limit, u'limit', int, False)
         if self._client.WSD:
             url = self._client.service_instance._href_definitions.get_model_definition_assets_href()
@@ -607,57 +571,43 @@ class Functions(WMLResource):
             return self._get_artifact_details(url, function_uid, limit, 'functions')
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_id(function_details):
-        """
-                Get ID of stored function.
+        """Get ID of stored function.
 
-                **Parameters**
+        :param function_details: metadata of the stored function
+        :type function_details: dict
 
-                .. important::
+        :return: ID of stored function
+        :rtype: str
 
-                   #. **function_details**:  Metadata of the stored function\n
-                      **type**: dict\n
+        **Example**
 
-                **Output**
+        .. code-block:: python
 
-                .. important::
-
-                    **returns**: ID of stored function\n
-                    **return type**: str\n
-
-                **Example**
-
-                 >>> function_details = client.repository.get_function_details(function_uid)
-                 >>> function_id = client._functions.get_id(function_details)
+            function_details = client.repository.get_function_details(function_uid)
+            function_id = client._functions.get_id(function_details)
         """
 
         return Functions.get_uid(function_details)
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_uid(function_details):
-        """
-                Get UID of stored function. Deprecate!! Use get_id(function_details) instead
+        """Get UID of stored function.
 
-                **Parameters**
+        *Deprecated:* Use get_id(function_details) instead.
 
-                .. important::
+        :param function_details: metadata of the stored function
+        :type function_details: dict
 
-                   #. **function_details**:  Metadata of the stored function\n
-                      **type**: dict\n
+        :return: UID of stored function
+        :rtype: str
 
-                **Output**
+        **Example**
 
-                .. important::
+        .. code-block:: python
 
-                    **returns**: UID of stored function\n
-                    **return type**: str\n
-
-                **Example**
-
-                 >>> function_details = client.repository.get_function_detailsf(function_uid)
-                 >>> function_uid = client._functions.get_uid(function_details)
+            function_details = client.repository.get_function_details(function_uid)
+            function_uid = client._functions.get_uid(function_details)
         """
         Functions._validate_type(function_details, u'function_details', object, True)
         if 'asset_id' in function_details['metadata']:
@@ -673,27 +623,21 @@ class Functions(WMLResource):
                                                                    [u'metadata', u'id'])
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_href(function_details):
-        """
-            Get url of stored function.
+        """Get url of stored function.
 
-           **Parameters**
+        :param function_details: stored function details
+        :type function_details: dict
 
-           .. important::
-                #. **function_details**:  stored function details\n
-                   **type**: dict\n
+        :return: href of stored function
+        :rtype: str
 
-           **Output**
+        **Example**
 
-           .. important::
-                **returns**: href of stored function\n
-                **return type**: str\n
+        .. code-block:: python
 
-           **Example**
-
-             >>> function_details = client.repository.get_function_detailsf(function_uid)
-             >>> function_url = client._functions.get_href(function_details)
+            function_details = client.repository.get_function_details(function_uid)
+            function_url = client._functions.get_href(function_details)
         """
         Functions._validate_type(function_details, u'function_details', object, True)
         if 'asset_type' in function_details['metadata']:
@@ -710,24 +654,16 @@ class Functions(WMLResource):
                 return "/ml/v4/functions/{}".format(function_details[u'metadata'][u'id'])
 
     def list(self, limit=None):
-        """
-            List stored functions. If limit is set to None there will be only first 50 records shown.
+        """Print stored functions in a table format. If limit is set to None there will be only first 50 records shown.
 
-           **Parameters**
+        :param limit: limit number of fetched records
+        :type limit: int, optional
 
-           .. important::
-                #. **limit**:  limit number of fetched records\n
-                   **type**: int\n
+        **Example**
 
-           **Output**
+        .. code-block:: python
 
-           .. important::
-                This method only prints the list of all functions in a table format.\n
-                **return type**: None\n
-
-           **Example**
-
-            >>> client._functions.list()
+            client._functions.list()
         """
         ##For CP4D, check if either spce or project ID is set
 
@@ -753,44 +689,34 @@ class Functions(WMLResource):
             self._list(function_values, [u'GUID', u'NAME', u'CREATED', u'TYPE'], limit, _DEFAULT_LIST_LENGTH)
 
     def clone(self, function_uid, space_id=None, action="copy", rev_id=None):
-        """
-                Creates a new function identical with the given function either in the same space or in a new space. All dependent assets will be cloned too.
+        """Creates a new function identical with the given function either in the same space or in a new space.
+        All dependent assets will be cloned too.
 
-                **Parameters**
+        :param function_uid: UID of the function to be cloned
+        :type function_uid: str
 
-                .. important::
-                    #. **model_id**:  Guid of the function to be cloned:\n
+        :param space_id: UID of the space to which the function needs to be cloned
+        :type space_id: str, optional
 
-                       **type**: str\n
+        :param action: action specifying "copy" or "move"
+        :type action: str, optional
 
-                    #. **space_id**: Guid of the space to which the function needs to be cloned. (optional)
+        :param rev_id: revision ID of the function
+        :type rev_id: str, optional
 
-                       **type**: str\n
+        :return: metadata of the function cloned
+        :rtype: dict
 
-                    #. **action**: Action specifying "copy" or "move". (optional)
+        **Example**
 
-                       **type**: str\n
+        .. code-block:: python
 
-                    #. **rev_id**: Revision ID of the function. (optional)
+            client._functions.clone(function_uid=artifact_id,space_id=space_uid,action="copy")
 
-                       **type**: str\n
+        .. note::
 
-                **Output**
-
-                .. important::
-
-                        **returns**: Metadata of the function cloned.\n
-                        **return type**: dict\n
-
-                **Example**
-                 >>> client._functions.clone(function_uid=artifact_id,space_id=space_uid,action="copy")
-
-                .. note::
-                    * If revision id is not specified, all revisions of the artifact are cloned\n
-
-                    * Default value of the parameter action is copy\n
-
-                    * Space guid is mandatory for move action\n
+            * Default value of the parameter action is copy
+            * Space guid is mandatory for move action
 
         """
         # if self._client.WSD or self._client.ICP_PLATFORM_SPACES or :
@@ -798,18 +724,14 @@ class Functions(WMLResource):
 
         raise WMLClientError("Not supported")
 
-        artifact = str_type_conv(function_uid)
-        Functions._validate_type(artifact, 'function_uid', STR_TYPE, True)
-        space = str_type_conv(space_id)
-        rev = str_type_conv(rev_id)
-        action = str_type_conv(action)
+        Functions._validate_type(function_uid, 'function_uid', str, True)
         clone_meta = {}
-        if space is not None:
-            clone_meta["space"] = {"href": API_VERSION + SPACES + "/" + space}
+        if space_id is not None:
+            clone_meta["space"] = {"href": API_VERSION + SPACES + "/" + space_id}
         if action is not None:
             clone_meta["action"] = action
-        if rev is not None:
-            clone_meta["rev"] = rev
+        if rev_id is not None:
+            clone_meta["rev"] = rev_id
 
         url = self._client.service_instance._href_definitions.get_function_href(function_uid)
         response_post = requests.post(url, json=clone_meta,
@@ -820,21 +742,23 @@ class Functions(WMLResource):
 
         return details
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def create_revision(self, function_uid):
-        """
-            Create a new functions revision.
+        """Create a new functions revision.
 
-            :param function_uid: Unique function ID
-            :type function_uid: {str_type}
+        :param function_uid: Unique function ID
+        :type function_uid: str
 
-            Example:
+        :return: stored function revision metadata
+        :rtype: dict
 
-            >>> client._functions.create_revision(pipeline_uid)
+        **Example**
+
+        .. code-block:: python
+
+            client._functions.create_revision(pipeline_uid)
         """
         WMLResource._chk_and_block_create_update_for_python36(self)
-        function_uid = str_type_conv(function_uid)
-        Functions._validate_type(function_uid, u'pipeline_uid', STR_TYPE, False)
+        Functions._validate_type(function_uid, u'pipeline_uid', str, False)
 
         if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(
@@ -844,25 +768,26 @@ class Functions(WMLResource):
             return self._create_revision_artifact(url, function_uid, 'functions')
 
     def get_revision_details(self, function_uid, rev_uid):
-        """
-           Get metadata of specific revision of stored functions
+        """Get metadata of specific revision of stored functions.
 
-           :param function_uid: stored functions, definition
-           :type function_uid: {str_type}
+        :param function_uid: stored functions, definition
+        :type function_uid: str
 
-           :param rev_uid: Unique id of the function revision.
-           :type rev_id : int
+        :param rev_uid: Unique id of the function revision
+        :type rev_uid : int
 
-           :returns: stored function revision metadata
-           :rtype: dict
+        :returns: stored function revision metadata
+        :rtype: dict
 
-           Example:
+        **Example**
+
+        .. code-block:: python
+
+            function_revision_details = client._functions.get_revision_details(function_uid, rev_uid)
 
-           >>> function_revision_details = client._functions.get_details(function_uid, rev_uid)
         """
         self._client._check_if_either_is_set()
-        model_uid = str_type_conv(function_uid)
-        Functions._validate_type(function_uid, u'function_uid', STR_TYPE, True)
+        Functions._validate_type(function_uid, u'function_uid', str, True)
         Functions._validate_type(rev_uid, u'rev_uid', int, True)
 
         if not self._client.ICP_30 and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
@@ -873,26 +798,25 @@ class Functions(WMLResource):
             return self._get_with_or_without_limit(url, limit=None, op_name="function",
                                                    summary=None, pre_defined=None, revision=rev_uid)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def list_revisions(self, function_uid, limit=None):
-        """
-           List all revision for the given function uid.
+        """Print all revision for the given function uid in a table format.
 
-           :param function_uid: Unique id of stored function.
-           :type function_uid: {str_type}
+        :param function_uid: Unique id of stored function
+        :type function_uid: str
 
-           :param limit: limit number of fetched records (optional)
-           :type limit: int
+        :param limit: limit number of fetched records
+        :type limit: int, optional
 
-           :returns:   list all function revisions details.
-           :rtype: table
+        **Example**
+
+        .. code-block:: python
+
+            client._functions.list_revisions(function_uid)
 
-           >>> details = client._functions.list_revisions(function_uid)
         """
         self._client._check_if_either_is_set()
-        function_uid = str_type_conv(function_uid)
 
-        Functions._validate_type(function_uid, u'function_uid', STR_TYPE, True)
+        Functions._validate_type(function_uid, u'function_uid', str, True)
 
         if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(u'Revision support is not there in this release.')
@@ -928,7 +852,7 @@ class Functions(WMLResource):
         user_content_file = False
         archive_name = None
 
-        if type(function) is STR_TYPE:
+        if type(function) is str:
             content_path = function
             user_content_file = True
         else:
