@@ -906,6 +906,15 @@ class DataConnection(BaseDataConnection):
                                                                    total_nrows_limit=total_nrows_limit,
                                                                    total_percentage_limit=total_percentage_limit)
 
+        if getattr(self._wml_client, '_internal', False):
+            pass  # don't remove additional params if client is used internally
+        else:
+            # note: remove additional params and inline credentials added by _check_if_connection_asset_is_s3:
+            [delattr(self.connection, attr) for attr in
+             ['secret_access_key', 'access_key_id', 'endpoint_url', 'cos_type'] if
+             hasattr(self.connection, attr)]
+            # end note
+
         # create data statistics if data were not downloaded with flight:
         if not isinstance(data, tuple) and _return_subsampling_stats:
             data = (data, {"data_batch_size": sys.getsizeof(data),
