@@ -393,45 +393,56 @@ class FlightConnection:
             else:
                 raise ConnectionError(f"Cannot connect to the Flight service. Error: {e}")
 
-        try:
+        count = 0
+        retry = True
+        while retry:
+            try:
+                retry = False
+                count += 1
+                for source_command in self._select_source_command():
+                    info = self.flight_client.get_flight_info(
+                        flight.FlightDescriptor.for_command(source_command)
+                    )
 
-            for source_command in self._select_source_command():
-                info = self.flight_client.get_flight_info(
-                    flight.FlightDescriptor.for_command(source_command)
-                )
+                    yield info.endpoints
 
-                yield info.endpoints
+            except flight.FlightInternalError as e:
+                logger.debug(f"Caught FlightInternalError in get_endpoints: {str(e)}")
+                if 'CDICO2034E' in str(e):
+                    if 'The property [infer_as_varchar] is not supported.' in str(e):
+                        # Don't sent infer_as_varchar in flight command and try again.
+                        self.infer_as_varchar = None
+                        retry = True
+                    elif 'The property [quote_character]' in str(e):
+                        # Don't sent quote_character in flight command if it is not yet supported and try again.
+                        self.params['quote_character'] = None
+                        retry = True
+                    else:
+                        raise WrongLocationProperty(reason=str(e))
 
-        except flight.FlightInternalError as e:
-            logger.debug(f"Caught FlightInternalError in get_endpoints: {str(e)}")
-            if 'CDICO2034E' in str(e):
-                if 'The property [infer_as_varchar] is not supported.' in str(e):
-                    # Don't sent infer_as_varchar in flight command and try again.
-                    self.infer_as_varchar = None
-                    for source_command in self._select_source_command():
-                        info = self.flight_client.get_flight_info(
-                            flight.FlightDescriptor.for_command(source_command)
-                        )
-                        yield info.endpoints
-                elif 'The property [quote_character]' in str(e):
-                    # Don't sent quote_character in flight command if it is not yet supported and try again.
-                    self.params['quote_character'] = None
-                    for source_command in self._select_source_command():
-                        info = self.flight_client.get_flight_info(
-                            flight.FlightDescriptor.for_command(source_command)
-                        )
-                        yield info.endpoints
+                    if count > 1:
+                        logger.debug(f"Reached the max retry times ${count}")
+                        raise e
 
-                else:
+                elif 'CDICO2015E' in str(e):
+                    raise WrongFileLocation(reason=str(e))
+
+                elif 'CDICO9999E' in str(e):
                     raise WrongLocationProperty(reason=str(e))
-
-            elif 'CDICO2015E' in str(e):
-                raise WrongFileLocation(reason=str(e))
-
-            elif 'CDICO9999E' in str(e):
-                raise WrongLocationProperty(reason=str(e))
-            else:
-                raise e
+                else:
+                    raise e
+            except pa.lib.ArrowInvalid as e:
+                logger.debug(f"Caught ArrowInvalid in get_endpoints: {str(e)}")
+                if 'No asset found with the id' in str(e):
+                    retry = True
+                    if count < 3:
+                        logger.debug(f"Retry to get the endpoints of flight service at the ${count} time")
+                        time.sleep(1)
+                    else:
+                        logger.debug(f"Reached the max retry times ${count}")
+                        raise e
+                else:
+                    raise e
 
     def _get_data(self,
                   thread_number: int,
