@@ -14,7 +14,6 @@
 
 from ibm_watson_machine_learning.wml_client_error import WMLClientError, UnexpectedType
 from ibm_watson_machine_learning.wml_resource import WMLResource
-from ibm_watson_machine_learning.utils import docstring_parameter, STR_TYPE_NAME
 
 
 class BothValuesAndRangePassed(WMLClientError):
@@ -36,42 +35,42 @@ class MissingElementOfRange(WMLClientError):
     def __init__(self, el):
         WMLClientError.__init__(self, "Missing element of range: {}".format(el))
 
-
-@docstring_parameter({'str_type': STR_TYPE_NAME})
 def HPOParameter(name, values=None, max=None, min=None, step=None):
-    """
-    Prepares dict element describing hyper parameter. Hyper parameter may be contructed in two ways:
+    """Prepares dict element describing hyper parameter. Hyper parameter may be contructed in two ways:
 
-    >>> HPOParameter('name', values=['val1', 'val2'])   # values
-    >>> HPOParameter('name', min=0.5, max=10, step=0.1) # range
+    * ``HPOParameter('name', values=['val1', 'val2'])   # values``
+    * ``HPOParameter('name', min=0.5, max=10, step=0.1) # range``
 
     In range description `min` and `step` are optional (by default `min` is set to 0 and `step` is set to 1).
 
     :param name: name of parameter
-    :type name: {str_type}
-    :param values: if parameter should have only values provided by user, this param should contain these values (optional)
-    :type values: list of str or list of int or list of float
-    :param max: if parameter should contain numbers from range, this will be maximal value of this range (optional)
-    :type max: int or float
-    :param min: if parameter should contain numbers from range, this will be minimal value of this range (optional)
-    :type min: int or float
-    :param step: if parameter should contain numbers from range, this will be step between elements from range (optional)
-    :type step: int or float
+    :type name: str
+    :param values: if parameter should have only values provided by user, this param should contain these values
+    :type values: list[str] or list[int] or list[float], optional
+    :param max: if parameter should contain numbers from range, this will be maximal value of this range
+    :type max: int or float, optional
+    :param min: if parameter should contain numbers from range, this will be minimal value of this range
+    :type min: int or float, optional
+    :param step: if parameter should contain numbers from range, this will be step between elements from range
+    :type step: int or float, optional
 
     :return: description of HPO parameter
     :rtype: dict
 
-    A way you might use me is:
+    **Example**
+
+    .. code-block:: python
+
+        HPOParameter('param1', values=['a', 'b', 'c']),
+        HPOParameter('param2', values=[0, 1, 9]),
+        HPOParameter('param3', values=[0.1, 0.5, 0.8]),
+        HPOParameter('param4', max=10),
+        HPOParameter('param5', min=2, max=10),
+        HPOParameter('param6', max=10, step=2),
+        HPOParameter('param7', max=10.0),
+        HPOParameter('param8', min=0.1, max=10),
+        HPOParameter('param9', min=0.5, max=10, step=0.1)
 
-    >>> HPOParameter('param1', values=['a', 'b', 'c']),
-    >>> HPOParameter('param2', values=[0, 1, 9]),
-    >>> HPOParameter('param3', values=[0.1, 0.5, 0.8]),
-    >>> HPOParameter('param4', max=10),
-    >>> HPOParameter('param5', min=2, max=10),
-    >>> HPOParameter('param6', max=10, step=2),
-    >>> HPOParameter('param7', max=10.0),
-    >>> HPOParameter('param8', min=0.1, max=10),
-    >>> HPOParameter('param9', min=0.5, max=10, step=0.1)
     """
     WMLResource._validate_type(name, "name", str, True)
     WMLResource._validate_type(values, "values", list, False)
