@@ -14,7 +14,7 @@
 
 from __future__ import print_function
 import ibm_watson_machine_learning._wrappers.requests as requests
-from ibm_watson_machine_learning.utils import SPACES_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, MEMBER_DETAILS_TYPE,HW_SPEC_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv, str_type_conv, get_file_from_cos
+from ibm_watson_machine_learning.utils import HW_SPEC_DETAILS_TYPE
 from ibm_watson_machine_learning.metanames import HwSpecMetaNames
 from ibm_watson_machine_learning.wml_resource import WMLResource
 from ibm_watson_machine_learning.wml_client_error import WMLClientError, ApiRequestFailure
@@ -24,9 +24,8 @@ _DEFAULT_LIST_LENGTH = 50
 
 
 class HwSpec(WMLResource):
-    """
-    Store and manage your hardware specs.
-    """
+    """Store and manage your hardware specs."""
+
     ConfigurationMetaNames = HwSpecMetaNames()
     """MetaNames for Hardware Specification."""
 
@@ -34,29 +33,23 @@ class HwSpec(WMLResource):
         WMLResource.__init__(self, __name__, client)
         self._ICP = client.ICP
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_details(self, hw_spec_uid):
-        """
-            Get hardware specification details.
+        """Get hardware specification details.
 
-            **Parameters**
+        :param hw_spec_uid: Unique id of the hardware spec
+        :type hw_spec_uid: str
 
-            .. important::
-                **hw_spec_uid** : Unique id of the hardware spec
-                ** type**: str
+        :return: metadata of the hardware specifications
+        :rtype: dict
 
-            **Output**
+        **Example**
 
-            .. important::
-                **returns**: Metadata of the hardware specifications\n
-                **return type**: dict\n
+        .. code-block:: python
 
-            **Example**
-
-                 >>> hw_spec_details = client.hardware_specifications.get_details(hw_spec_uid)
+            hw_spec_details = client.hardware_specifications.get_details(hw_spec_uid)
 
         """
-        HwSpec._validate_type(hw_spec_uid, u'hw_spec_uid', STR_TYPE, True)
+        HwSpec._validate_type(hw_spec_uid, u'hw_spec_uid', str, True)
         if not self._ICP or self._client.ICP_PLATFORM_SPACES:
             response = requests.get(self._client.service_instance._href_definitions.get_hw_spec_href(hw_spec_uid), params=self._client._params(skip_space_project_chk=True),
                                     headers=self._client._get_headers())
@@ -70,7 +63,6 @@ class HwSpec(WMLResource):
             return self._handle_response(200, u'get hardware spec details', response)
 
     # Creation of new hardware specs is not required at the moment because WML does not support it
-    # @docstring_parameter({'str_type': STR_TYPE_NAME})
     # def store(self, meta_props):
     #     """
     #             Create a space.
@@ -117,26 +109,17 @@ class HwSpec(WMLResource):
     #
     #     return hw_spec_details
 
-
     def list(self, name=None):
-        """
-           List hardware specifications.
+        """Print hardware specifications in a table format.
 
-           **Parameters**
+        :param name: Unique id of the hardware spec
+        :type name: str, optional
 
-           .. important::
-                **name** : Unique id of the hardware spec
-                ** type**: str
+        **Example**
 
-           **Output**
+        .. code-block:: python
 
-           .. important::
-                This method only prints the list of all assets in a table format.\n
-                **return type**: None\n
-
-           **Example**
-
-            >>> client.hardware_specifications.list()
+            client.hardware_specifications.list()
 
         """
 
@@ -158,56 +141,42 @@ class HwSpec(WMLResource):
         self._list(hw_spec_values, [u'NAME', u"ID", u'DESCRIPTION'], None, _DEFAULT_LIST_LENGTH)
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_id(hw_spec_details):
-        """
-                Get ID of hardware specifications asset.
+        """Get ID of hardware specifications asset.
 
-                **Parameters**
+        :param hw_spec_details: metadata of the hardware specifications
+        :type hw_spec_details: dict
 
-                .. important::
+        :return: Unique Id of hardware specifications
+        :rtype: str
 
-                   #. **asset_details**:  Metadata of the hardware specifications \n
-                      **type**: dict\n
+        **Example**
 
-                **Output**
+        .. code-block:: python
 
-                .. important::
-
-                    **returns**: Unique Id of hardware specifications\n
-                    **return type**: str\n
-
-                **Example**
-
-                 >>> asset_uid = client.hardware_specifications.get_id(hw_spec_details)
+            asset_uid = client.hardware_specifications.get_id(hw_spec_details)
 
         """
 
         return HwSpec.get_uid(hw_spec_details)
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_uid(hw_spec_details):
-        """
-                Get UID of hardware specifications asset. Deprecated!! Use get_id(hw_spec_details) instead
+        """Get UID of hardware specifications asset.
 
-                **Parameters**
+        *Deprecated:* Use ``get_id(hw_spec_details)`` instead.
 
-                .. important::
+        :param hw_spec_details: metadata of the hardware specifications
+        :type hw_spec_details: dict
 
-                   #. **asset_details**:  Metadata of the hardware specifications \n
-                      **type**: dict\n
+        :return: Unique Id of hardware specifications
+        :rtype: str
 
-                **Output**
+        **Example**
 
-                .. important::
+        .. code-block:: python
 
-                    **returns**: Unique Id of hardware specifications\n
-                    **return type**: str\n
-
-                **Example**
-
-                 >>> asset_uid = client.hardware_specifications.get_uid(hw_spec_details)
+            asset_uid = client.hardware_specifications.get_uid(hw_spec_details)
 
         """
         HwSpec._validate_type(hw_spec_details, u'hw_spec_details', object, True)
@@ -218,27 +187,21 @@ class HwSpec(WMLResource):
 
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_href(hw_spec_details):
-        """
-            Get url of hardware specifications.
+        """Get url of hardware specifications.
 
-           **Parameters**
+        :param hw_spec_details: hardware specifications details
+        :type hw_spec_details: dict
 
-           .. important::
-                #. **hw_spec_details**:  hardware specifications details\n
-                   **type**: dict\n
+        :return: href of hardware specifications
+        :rtype: str
 
-           **Output**
+        **Example**
 
-           .. important::
-                **returns**: href of hardware specifications\n
-                **return type**: str\n
+        .. code-block:: python
 
-           **Example**
-
-             >>> hw_spec_details = client.hw_spec.get_details(hw_spec_uid)
-             >>> hw_spec_href = client.hw_spec.get_href(hw_spec_details)
+            hw_spec_details = client.hw_spec.get_details(hw_spec_uid)
+            hw_spec_href = client.hw_spec.get_href(hw_spec_details)
 
         """
         HwSpec._validate_type(hw_spec_details, u'hw_spec_details', object, True)
@@ -246,59 +209,44 @@ class HwSpec(WMLResource):
 
         return WMLResource._get_required_element_from_dict(hw_spec_details, u'hw_spec_details', [u'metadata', u'href'])
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_id_by_name(self, hw_spec_name):
-        """
-                Get Unique Id of hardware specification for the given name.
+        """Get Unique Id of hardware specification for the given name.
 
-                **Parameters**
+        :param hw_spec_name: name of the hardware spec
+        :type hw_spec_name: str
 
-                .. important::
+        :return: Unique Id of hardware specification
+        :rtype: str
 
-                   #. **hw_spec_name**:  name of the hardware spec \n
-                      **type**: str\n
+        **Example**
 
-                **Output**
+        .. code-block:: python
 
-                .. important::
-
-                    **returns**: Unique Id of hardware specification \n
-                    **return type**: str\n
-
-                **Example**
-
-                 >>> asset_uid = client.hardware_specifications.get_id_by_name(hw_spec_name)
+            asset_uid = client.hardware_specifications.get_id_by_name(hw_spec_name)
 
         """
 
         return HwSpec.get_uid_by_name(self, hw_spec_name)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_uid_by_name(self, hw_spec_name):
-        """
-                Get Unique Id of hardware specification for the given name. Deprecated!!
-                Use get_id_by_name(self, hw_spec_name) instead
+        """Get Unique Id of hardware specification for the given name.
 
-                **Parameters**
+        *Deprecated:* Use ``get_id_by_name(hw_spec_name)`` instead.
 
-                .. important::
+        :param hw_spec_name:  name of the hardware spec
+        :type hw_spec_name: str
 
-                   #. **hw_spec_name**:  name of the hardware spec \n
-                      **type**: str\n
+        :return: Unique Id of hardware specification
+        :rtype: str
 
-                **Output**
+        **Example**
 
-                .. important::
+        .. code-block:: python
 
-                    **returns**: Unique Id of hardware specification \n
-                    **return type**: str\n
-
-                **Example**
-
-                 >>> asset_uid = client.hardware_specifications.get_uid_by_name(hw_spec_name)
+            asset_uid = client.hardware_specifications.get_uid_by_name(hw_spec_name)
 
         """
-        HwSpec._validate_type(hw_spec_name, u'hw_spec_name', STR_TYPE, True)
+        HwSpec._validate_type(hw_spec_name, u'hw_spec_name', str, True)
         parameters = self._client._params(skip_space_project_chk=True)
         parameters.update(name=hw_spec_name)
 
@@ -314,7 +262,6 @@ class HwSpec(WMLResource):
             else:
                 return "Not Found"
 
-    # @docstring_parameter({'str_type': STR_TYPE_NAME})
     # def delete(self, hw_spec_uid):
     #     """
     #         Delete a hardware specifications.
@@ -335,7 +282,7 @@ class HwSpec(WMLResource):
     #
     #          >>> client.hw_spec.delete(hw_spec_uid)
     #     """
-    #     HwSpec._validate_type(hw_spec_uid, u'hw_spec_uid', STR_TYPE, True)
+    #     HwSpec._validate_type(hw_spec_uid, u'hw_spec_uid', str, True)
     #
     #     response = requests.delete(self._client.service_instance._href_definitions.get_hw_spec_href(hw_spec_uid), params=self._client._params(),
     #                             headers=self._client._get_headers())
