@@ -22,9 +22,8 @@ from ibm_watson_machine_learning.href_definitions import HrefDefinitions
 
 
 class ServiceInstance:
-    """
-        Connect, get details and check usage of your Watson Machine Learning service instance.
-    """
+    """Connect, get details and check usage of your Watson Machine Learning service instance."""
+
     def __init__(self, client):
         self._logger = logging.getLogger(__name__)
         self._client = client
@@ -43,103 +42,86 @@ class ServiceInstance:
         self.details = None
 
     def get_instance_id(self):
-        """
-             Get instance id of your Watson Machine Learning service.
-             
-             **Output**
-             
-             .. important::
-             
-                **returns**: instance id\n
-                **return type**: str
-             
-             **Example**
-             
-             >>> instance_details = client.service_instance.get_instance_id()
+        """Get instance id of your Watson Machine Learning service.
+
+        :return: instance id
+        :rtype: str
+
+        **Example**
+
+        .. code-block:: python
+
+            instance_details = client.service_instance.get_instance_id()
         """
         return self._wml_credentials['instance_id']
 
     def get_api_key(self):
-        """
-            Get api_key  of Watson Machine Learning service.
+        """Get api key of Watson Machine Learning service.
 
-            **Output**
+        :return: api key
+        :rtype: str
 
-            .. important::
-                **returns** api_key\n
-                **return type**: str\n
+        **Example**
 
-            **Example**
+        .. code-block:: python
 
-                >>> instance_details = client.service_instance.get_api_key()
+            instance_details = client.service_instance.get_api_key()
         """
         return self._wml_credentials['apikey']
 
     def get_url(self):
-        """
-             Get instance url of your Watson Machine Learning service.
+        """Get instance url of your Watson Machine Learning service.
              
-             **Output**
-             
-             .. important::
-             
-                **returns**: instance url\n
-                **return type**: str
+        :return: instance url
+        :rtype: str
 
-             **Example**
+        **Example**
 
-             >>> instance_details = client.service_instance.get_url()
+        .. code-block:: python
+
+            instance_details = client.service_instance.get_url()
         """
         return self._wml_credentials['url']
 
     def get_username(self):
-        """
-             Get username for your Watson Machine Learning service.
+        """Get username for your Watson Machine Learning service.
              
-             **Output**
+        :return: username
+        :rtype: str
              
-             .. important::
+        **Example**
+
+        .. code-block:: python
              
-                **returns**: username\n
-                **return type**: str
-             
-             **Example**
-             
-             >>> instance_details = client.service_instance.get_username()
+            instance_details = client.service_instance.get_username()
         """
         return self._wml_credentials['username']
 
     def get_password(self):
-        """
-             Get password for your Watson Machine Learning service.
+        """Get password for your Watson Machine Learning service.
              
-             **Output**
-             
-             .. important::
-             
-                **returns**: password\n
-                **return type**: str
+        :return: password
+        :rtype: str
 
-             **Example**
+        **Example**
 
-             >>> instance_details = client.service_instance.get_password()
+        .. code-block:: python
+
+            instance_details = client.service_instance.get_password()
         """
         return self._wml_credentials['password']
 
     def get_details(self):
-        """
-             Get information about your Watson Machine Learning instance.
+        """Get information about your Watson Machine Learning instance.
              
-             **Output**
-            
-             .. important::
+        :return: metadata of service instance
+        :rtype: dict
 
-                **returns**: metadata of service instance\n
-                **return type**: dict
+        **Example**
 
-             **Example**
+        .. code-block:: python
 
-             >>> instance_details = client.service_instance.get_details()
+            instance_details = client.service_instance.get_details()
         """
         if not self._ICP:
             if self._wml_credentials is not None:
@@ -276,10 +258,7 @@ class ServiceInstance:
 
     def _create_zen_token(self):
         token_url = self._wml_credentials['url'] + '/icp4d-api/v1/authorize'
-        headers = {
-            'Content-type' :'application/json',
-            'cache-control': 'no-cache'
-        }
+
         response = requests.post(token_url, auth=(self.get_username(), self.get_password()))
         if response.status_code == 200:
             print(response)
