@@ -23,9 +23,7 @@ from ibm_watson_machine_learning.href_definitions import HrefDefinitions
 
 
 class ServiceInstanceNewPlan:
-    """
-        Connect, get details and check usage of your Watson Machine Learning service instance.
-    """
+    """Connect, get details and check usage of your Watson Machine Learning service instance."""
 
     def __init__(self, client):
         self._logger = logging.getLogger(__name__)
@@ -54,19 +52,16 @@ class ServiceInstanceNewPlan:
         self.details = None
 
     def get_instance_id(self):
-        """
-             Get instance id of your Watson Machine Learning service.
+        """Get instance id of your Watson Machine Learning service.
 
-             **Output**
+        :return: instance id
+        :rtype: str
 
-             .. important::
+        **Example**
 
-                **returns**: instance id\n
-                **return type**: str
+        .. code-block:: python
 
-             **Example**
-
-             >>> instance_details = client.service_instance.get_instance_id()
+            instance_details = client.service_instance.get_instance_id()
         """
         if self._wml_credentials['instance_id'] == 'invalid':
             raise WMLClientError('instance_id for this plan is picked up from the space with which'
@@ -75,46 +70,44 @@ class ServiceInstanceNewPlan:
         return self._wml_credentials['instance_id']
 
     def get_api_key(self):
-        """
-             Get api_key  of Watson Machine Learning service.
-             :returns: api_key
-             :rtype: str
-             A way you might use me is:
-             >>> instance_details = client.service_instance.get_api_key()
+        """Get api key of Watson Machine Learning service.
+
+        :return: api key
+        :rtype: str
+
+        **Example**
+
+        .. code-block:: python
+
+            instance_details = client.service_instance.get_api_key()
         """
         return self._wml_credentials['apikey']
 
     def get_url(self):
-        """
-             Get instance url of your Watson Machine Learning service.
+        """Get instance url of your Watson Machine Learning service.
 
-             **Output**
+        :return: instance url
+        :rtype: str
 
-             .. important::
+        **Example**
 
-                **returns**: instance url\n
-                **return type**: str
+        .. code-block:: python
 
-             **Example**
-
-             >>> instance_details = client.service_instance.get_url()
+            instance_details = client.service_instance.get_url()
         """
         return self._wml_credentials['url']
 
     def get_username(self):
-        """
-             Get username for your Watson Machine Learning service. Applicable only for IBM Cloud Pak® for Data
+        """Get username for your Watson Machine Learning service. Applicable only for IBM Cloud Pak® for Data.
 
-             **Output**
+        :return: username
+        :rtype: str
 
-             .. important::
+        **Example**
 
-                **returns**: username\n
-                **return type**: str
+        .. code-block:: python
 
-             **Example**
-
-             >>> instance_details = client.service_instance.get_username()
+            instance_details = client.service_instance.get_username()
         """
         if self._client.ICP_PLATFORM_SPACES:
             try:
@@ -125,19 +118,16 @@ class ServiceInstanceNewPlan:
             raise WMLClientError("Not applicable for Cloud")
 
     def get_password(self):
-        """
-             Get password for your Watson Machine Learning service. Applicable only for IBM Cloud Pak® for Data
+        """Get password for your Watson Machine Learning service. Applicable only for IBM Cloud Pak® for Data.
 
-             **Output**
+        :return: password
+        :rtype: str
 
-             .. important::
+        **Example**
 
-                **returns**: password\n
-                **return type**: str
+        .. code-block:: python
 
-             **Example**
-
-             >>> instance_details = client.service_instance.get_password()
+            instance_details = client.service_instance.get_password()
         """
         if self._client.ICP_PLATFORM_SPACES:
             try:
@@ -148,19 +138,16 @@ class ServiceInstanceNewPlan:
             raise WMLClientError("Not applicable for Cloud")
 
     def get_details(self):
-        """
-             Get information about your Watson Machine Learning instance.
+        """Get information about your Watson Machine Learning instance.
 
-             **Output**
+        :return: metadata of service instance
+        :rtype: dict
 
-             .. important::
+        **Example**
 
-                **returns**: metadata of service instance\n
-                **return type**: dict
+        .. code-block:: python
 
-             **Example**
-
-             >>> instance_details = client.service_instance.get_details()
+            instance_details = client.service_instance.get_details()
         """
 
         if not self._client.ICP:
@@ -284,14 +271,12 @@ class ServiceInstanceNewPlan:
         return token
 
     def _is_token_refresh_possible(self):
-        """
-        Checks if necessary credentials were passed for token refresh.
+        """Checks if necessary credentials were passed for token refresh.
         For CP4D we need (username & password)/(username & api_key).
         For Cloud we need api_key.
 
-        **Output**
-            **returns**: True is token refresh can be performed False otherwise.
-            **return type**: bool
+        :return: `True` if token refresh can be performed `False` otherwise
+        :rtype: bool
         """
         if self._client._is_IAM():
             return 'apikey' in self._wml_credentials
@@ -300,29 +285,22 @@ class ServiceInstanceNewPlan:
                     'password' in self._wml_credentials or 'apikey' in self._wml_credentials)
 
     def _get_cpd_auth_pair(self):
-        """
-        Get pair of credentials required for generation of token.
+        """Get a pair of credentials required for generation of token.
 
-        **Output**
-
-            **returns**: String representing a dictionary of authentication credentials
-                         (username & password) or (username & api_key).\n
-            **return type**: str
+        :return: string representing a dictionary of authentication credentials
+                         (username & password) or (username & api_key).
+        :rtype: str
         """
         if "apikey" in self._wml_credentials:
             return f'{{\"username\": \"{self.get_username()}\", \"api_key\": \"{self.get_api_key()}\"}}'
         else:
             return f'{{\"username\": \"{self.get_username()}\", \"password\": \"{self.get_password()}\"}}'
 
-
     def _get_cpd_bedrock_auth_data(self):
-        """
-        Get data required for generation of token.
+        """Get data required for generation of token.
 
-        **Output**
-
-            **returns**: String representing a dictionary of authentication credentials\n
-            **return type**: str
+        :return: string representing a dictionary of authentication credentials
+        :rtype: str
         """
         return f'grant_type=password&username={self.get_username()}&password={self.get_password()}&scope=openid'
 
@@ -368,12 +346,10 @@ class ServiceInstanceNewPlan:
             raise WMLClientError(u'Error refreshing the token.', response)
 
     def _get_cpd_token_from_request(self):
-        """
-        Send a request for token on CPD.
+        """Send a request for token on CPD.
 
-        **Output**
-            **returns**: Newly created token if returned if no errors occurred.\n
-            **return type**: str\n
+        :return: newly created token is returned if no errors occurred
+        :rtype: str
         """
         if (self._client.ICP_40 or self._client.ICP_45 or self._client.ICP_46) and 'bedrock_url' in self._client.wml_credentials and 'password' in self._client.wml_credentials:
             try:
