@@ -15,7 +15,7 @@
 from __future__ import print_function
 import ibm_watson_machine_learning._wrappers.requests as requests
 import json
-from ibm_watson_machine_learning.utils import STR_TYPE, get_url, docstring_parameter, STR_TYPE_NAME, print_text_header_h2, print_text_header_h1, str_type_conv, meta_props_str_conv, StatusLogger
+from ibm_watson_machine_learning.utils import get_url, print_text_header_h2, print_text_header_h1, StatusLogger
 from ibm_watson_machine_learning.metanames import LearningSystemMetaNames
 import base64
 from ibm_watson_machine_learning.wml_resource import WMLResource
@@ -24,9 +24,7 @@ from ibm_watson_machine_learning.wml_client_error import MissingValue, WMLClient
 
 
 class LearningSystem(WMLResource):
-    """
-       Continuous Learning System.
-    """
+    """Continuous Learning System."""
 
     def __init__(self, client):
         WMLResource.__init__(self, __name__, client)
@@ -60,27 +58,25 @@ class LearningSystem(WMLResource):
 
         return self._run_uid_to_model_uid_mapping[run_uid]
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def setup(self, model_uid, meta_props):
+        """Setup continuous learning system for stored model.
+
+        :param model_uid: ID of stored model
+        :type model_uid: str
+        :param meta_props: learning system configuration meta data
+        :type meta_props: dict
+
+        :return: learning system configuration details
+        :rtype: dict
+
+        **Example**
+
+        .. code-block:: python
+
+            learning_system = client.learning_system.create(model_uid, meta_props=configuration)
         """
-            Setup continuous learning system for stored model.
-
-            :param model_uid: ID of stored model
-            :type model_uid: {str_type}
-            :param meta_props: learning system configuration meta data
-            :type meta_props: dict
-
-            :return: learning system configuration details
-            :rtype: dict
-
-            A way you might use me is
-
-            >>> learning_system = client.learning_system.create(model_uid, meta_props=configuration)
-        """
-        model_uid = str_type_conv(model_uid)
-        self._validate_type(model_uid, u'model_uid', STR_TYPE, True)
+        self._validate_type(model_uid, u'model_uid', str, True)
         self._validate_type(meta_props, u'meta_props', dict, True)
-        meta_props_str_conv(meta_props)
         self.ConfigurationMetaNames._validate(meta_props)
 
         model_details_response = requests.get(
@@ -133,8 +129,7 @@ class LearningSystem(WMLResource):
         return self._handle_response(200, u'creating learning system', response, True)
 
     def update(self, model_uid, changes):
-        """
-        Updates existing learning system metadata.
+        """Updates existing learning system metadata.
 
         :param model_uid: UID of model which learning system should be updated
         :type model_uid: str
@@ -145,10 +140,8 @@ class LearningSystem(WMLResource):
         :return: metadata of updated learning system
         :rtype: dict
         """
-        model_uid = str_type_conv(model_uid)
-        self._validate_type(model_uid, u'model_uid', STR_TYPE, True)
+        self._validate_type(model_uid, u'model_uid', str, True)
         self._validate_type(changes, u'changes', dict, True)
-        meta_props_str_conv(changes)
 
         details = self.get_details(model_uid)
 
@@ -162,18 +155,18 @@ class LearningSystem(WMLResource):
         return updated_details
 
     def get_details(self, model_uid):
+        """Get details of learning system.
+
+        :param model_uid: ID of model for this learning system
+        :type model_uid: str
+
+        **Example**
+
+        .. code-block:: python
+
+            learning_system_details = client.learning_system.get_details(model_uid)
         """
-            Get details of learning system.
-
-            :param model_uid: ID of model for this learning system
-            :type model_uid: str
-
-            A way you might use me is
-
-            >>> learning_system_details = client.learning_system.get_details(model_uid)
-        """
-        model_uid = str_type_conv(model_uid)
-        self._validate_type(model_uid, u'model_uid', STR_TYPE, True)
+        self._validate_type(model_uid, u'model_uid', str, True)
 
         response = requests.get(
             self._client.service_instance._href_definitions.get_published_model_href(model_uid),
@@ -185,12 +178,13 @@ class LearningSystem(WMLResource):
         return details[u'entity'][u'learning_configuration']
 
     def list(self):
-        """
-            List existing learning systems.
+        """Print existing learning systems in a table format.
 
-            A way you might use me is
+        **Example**
 
-            >>> client.learning_system.list()
+        .. code-block:: python
+
+            client.learning_system.list()
         """
         from tabulate import tabulate
 
@@ -202,22 +196,22 @@ class LearningSystem(WMLResource):
         print(tabulate([['MODEL GUID', 'MODEL NAME', 'FRAMEWORK', 'RETRAIN', 'REDEPLOY', 'MIN FEEDBACK ROWS']] + values))
 
     def run(self, model_uid, asynchronous=True):
+        """Run learning iterations.
+
+        :param model_uid: ID of stored model
+        :type model_uid: str
+
+        :param asynchronous: if the run should be asynchronous
+        :type asynchronous: bool, optional
+
+        **Example**
+
+        .. code-block:: python
+
+            client.learning_system.run(model_uid)
+            client.learning_system.run(model_uid, asynchronous=False)
         """
-            Run learning iterations.
-
-            :param model_uid: ID of stored model
-            :type model_uid: str
-
-            :param asynchronous: if the run should be asynchronous (optional)
-            :type asynchronous: bool
-
-            A way you might use me is
-
-            >>> client.learning_system.run(model_uid)
-            >>> client.learning_system.run(model_uid, asynchronous=False)
-        """
-        model_uid = str_type_conv(model_uid)
-        self._validate_type(model_uid, u'model_uid', STR_TYPE, True)
+        self._validate_type(model_uid, u'model_uid', str, True)
         self._validate_type(asynchronous, u'asynchronous', bool, True)
 
         response = requests.post(
@@ -277,18 +271,19 @@ class LearningSystem(WMLResource):
                     raise WMLClientError(u'Run failed.')
 
     def get_run_uid(self, run_details):
-        """
-            Get uid of run (learning iteration).
+        """Get uid of run (learning iteration).
 
-            :param run_details: details of run
-            :type run_details: dict
+        :param run_details: details of run
+        :type run_details: dict
 
-            :return: run uid
-            :rtype: str
+        :return: run uid
+        :rtype: str
 
-            A way you might use me is
+        **Example**
 
-            >>> run_uid = client.learning_system.get_run_uid(run_details)
+        .. code-block:: python
+
+            run_uid = client.learning_system.get_run_uid(run_details)
         """
         self._validate_type(run_details, u'run_details', dict, True)
 
@@ -303,18 +298,19 @@ class LearningSystem(WMLResource):
         return uid
 
     def get_run_href(self, run_details):
-        """
-            Get href of run (learning iteration).
+        """Get href of run (learning iteration).
 
-            :param run_details: details of run
-            :type run_details: dict
+        :param run_details: details of run
+        :type run_details: dict
 
-            :return: run href
-            :rtype: str
+        :return: run href
+        :rtype: str
 
-            A way you might use me is
+        **Example**
 
-            >>> run_uid = client.learning_system.get_run_href(run_details)
+        .. code-block:: python
+
+            client.learning_system.get_run_href(run_details)
         """
         self._validate_type(run_details, u'run_details', dict, True)
 
@@ -329,18 +325,18 @@ class LearningSystem(WMLResource):
         return uid
 
     def get_runs(self, model_uid):
+        """Get learning iterations (runs).
+
+        :param model_uid: ID of stored model
+        :type model_uid: str
+
+        **Example**
+
+        .. code-block:: python
+
+            runs_details = client.learning_system.get_runs(model_uid)
         """
-            Get learning iterations (runs).
-
-            :param model_uid: ID of stored model
-            :type model_uid: str
-
-            A way you might use me is
-
-            >>> runs_details = client.learning_system.get_runs(model_uid)
-        """
-        model_uid = str_type_conv(model_uid)
-        self._validate_type(model_uid, u'model_uid', STR_TYPE, True)
+        self._validate_type(model_uid, u'model_uid', str, True)
 
         response = requests.get(
             self._client.service_instance._href_definitions.get_learning_iterations_href(model_uid),
@@ -355,18 +351,18 @@ class LearningSystem(WMLResource):
         return details
 
     def get_metrics(self, model_uid):
+        """Get evaluation metrics.
+
+        :param model_uid: ID of stored model
+        :type model_uid: str
+
+        **Example**
+
+        .. code-block:: python
+
+            runs_details = client.learning_system.get_metrics(model_uid)
         """
-            Get evaluation metrics.
-
-            :param model_uid: ID of stored model
-            :type model_uid: str
-
-            A way you might use me is
-
-            >>> runs_details = client.learning_system.get_metrics(model_uid)
-        """
-        model_uid = str_type_conv(model_uid)
-        self._validate_type(model_uid, u'model_uid', STR_TYPE, True)
+        self._validate_type(model_uid, u'model_uid', str, True)
 
         response = requests.get(
             self._client.service_instance._href_definitions.get_evaluation_metrics_href(model_uid),
@@ -376,18 +372,18 @@ class LearningSystem(WMLResource):
         return self._handle_response(200, u'getting evaluation metrics', response, True)
 
     def list_metrics(self, model_uid):
+        """Print evaluation metrics in a table format.
+
+        :param model_uid: ID of stored model
+        :type model_uid: str
+
+        **Example**
+
+        .. code-block:: python
+
+            runs_details = client.learning_system.get_metrics(model_uid)
         """
-            Get evaluation metrics.
-
-            :param model_uid: ID of stored model
-            :type model_uid: str
-
-            A way you might use me is
-
-            >>> runs_details = client.learning_system.get_metrics(model_uid)
-        """
-        model_uid = str_type_conv(model_uid)
-        self._validate_type(model_uid, u'model_uid', STR_TYPE, True)
+        self._validate_type(model_uid, u'model_uid', str, True)
 
         from tabulate import tabulate
 
@@ -407,18 +403,18 @@ class LearningSystem(WMLResource):
         print(tabulate([['PHASE', 'TIMESTAMP', 'METRIC NAME', 'METRIC VALUE', 'METRIC THRESH.', 'VERSION']] + values))
 
     def list_runs(self, model_uid=None):
+        """Print learning iterations in a table format.
+
+        :param model_uid: ID of stored model
+        :type model_uid: str, optional
+
+        **Example**
+
+        .. code-block:: python
+
+            client.learning_system.list_runs()
         """
-           List learning iterations.
-
-           :param model_uid: ID of stored model (optional)
-           :type model_uid: str
-
-           A way you might use me is
-
-           >>> client.learning_system.list_runs()
-        """
-        model_uid = str_type_conv(model_uid)
-        self._validate_type(model_uid, u'model_uid', STR_TYPE, False)
+        self._validate_type(model_uid, u'model_uid', str, False)
 
         from tabulate import tabulate
 
@@ -465,18 +461,18 @@ class LearningSystem(WMLResource):
             print(table)
 
     def get_run_details(self, run_uid):
+        """Get run details.
+
+        :param run_uid: ID of learning iteration run
+        :type run_uid: str
+
+        **Example**
+
+        .. code-block:: python
+
+            run_details = client.learning_system.get_run_details(run_uid)
         """
-            Get run details.
-
-            :param run_uid: ID of learning iteration run
-            :type run_uid: str
-
-            A way you might use me is
-
-            >>> run_details = client.learning_system.get_run_details(run_uid)
-        """
-        run_uid = str_type_conv(run_uid)
-        self._validate_type(run_uid, u'run_uid', STR_TYPE, True)
+        self._validate_type(run_uid, u'run_uid', str, True)
 
         model_uid = self._get_model_uid_by_run_uid(run_uid)
 
@@ -488,22 +484,22 @@ class LearningSystem(WMLResource):
         return self._handle_response(200, u'getting learning iteration details', response, True)
 
     def send_feedback(self, model_uid, feedback_data, fields=None):
+        """Send feedback data to learning system.
+
+        :param model_uid: ID of model
+        :type model_uid: str
+        :param feedback_data: rows of feedback data to be send
+        :type feedback_data: list of rows
+        :param fields: list of fields
+        :type fields: list of strings, optional
+
+        **Example**
+
+        .. code-block:: python
+
+            client.learning_system.send_feedback(model_uid, [["a1", 1, 1.0], ["a2", 2, 3.4]])
+            client.learning_system.send_feedback(model_uid, [["a1", 1.0], ["a2", 3.4]], fields=["id", "value"])
         """
-            Send feedback data to learning system.
-
-            :param model_uid: ID of model
-            :type model_uid: str
-            :param feedback_data: rows of feedback data to be send
-            :type feedback_data: list of rows
-            :param fields: list of fields (optional)
-            :type fields: list of strings
-
-            A way you might use me is
-
-            >>> client.learning_system.send_feedback(model_uid, [["a1", 1, 1.0], ["a2", 2, 3.4]])
-            >>> client.learning_system.send_feedback(model_uid, [["a1", 1.0], ["a2", 3.4]], fields=["id", "value"])
-        """
-        model_uid = str_type_conv(model_uid)
         self._validate_type(model_uid, "model_uid", str, True)
         self._validate_type(feedback_data, "feedback_data", list, True)
         self._validate_type(fields, "fields", list, False)
