@@ -194,7 +194,7 @@ class SWSReceiver(FLReceiver):
         while not self.stopped:
             try:
                 logger.debug("SWSReceiver.establish_websocket_connection ATTEMPT async websockets.connect")
-                async with websockets.connect(uri, ping_interval=20, ping_timeout=None, max_size=2 ** 29, read_limit=2 ** 29, write_limit=2**29, ssl=self.ssl_context, loop=loop, extra_headers=headers) as websocket:
+                async with websockets.connect(uri, open_timeout=30, ping_interval=20, ping_timeout=None, max_size=2 ** 29, read_limit=2 ** 29, write_limit=2**29, ssl=self.ssl_context, loop=loop, extra_headers=headers) as websocket:
                     logger.info("Received Heartbeat from Aggregator")
                     apikey_header = websocket.response_headers.get("apikey", None)
                     if apikey_header is not None:
@@ -236,7 +236,8 @@ class SWSReceiver(FLReceiver):
 
             except Exception as ex:
                 logger.info("Exception encountered.")
-                logger.error(str(ex))
+                logger.error(repr(ex))
+                logger.exception(ex)
                 break
 
     async def websocket_message_loop(self, websocket):
