@@ -413,7 +413,7 @@ class TensorFlowFLModel(FLModel):
                 logger.error('An acceptable compiled model should be of type '
                              'tensorflow.keras.models!')
         except Exception as ex:
-            logger.error(str(ex))
+            logger.error(repr(ex))
             raise FLException('Unable to load the provided uncompiled model!')
 
             # Load weights from provided path
