@@ -14,7 +14,6 @@
 
 from __future__ import print_function
 import ibm_watson_machine_learning._wrappers.requests as requests
-from ibm_watson_machine_learning.utils import STR_TYPE, STR_TYPE_NAME, docstring_parameter
 from ibm_watson_machine_learning.metanames import Migrationv4GACloudMetaNames
 import os
 import json
@@ -25,12 +24,10 @@ _DEFAULT_LIST_LENGTH = 50
 
 
 class Migrationv4GACloud(WMLResource):
-    """
-    Migration APIs for v4 GA Cloud. This will be applicable only till the migration period
+    """Migration APIs for v4 GA Cloud. This will be applicable only till the migration period.
     Refer to the documentation at 'https://dataplatform.cloud.ibm.com/docs/content/wsj/analyze-data/wml-ai.html'
-    for details on migration
+    for details on migration.
     """
-    """MetaNames for python functions creation."""
 
     def __init__(self, client):
         WMLResource.__init__(self, __name__, client)
@@ -43,47 +40,41 @@ class Migrationv4GACloud(WMLResource):
         "the documentation at 'https://dataplatform.cloud.ibm.com/docs/content/wsj/analyze-data/wml-ai.html' for "\
         "details on new plans and features.\n"
 
-
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def start(self, meta_props):
-        """
-        Migration APIs for v4 GA Cloud to migrate assets from v3 or v4 beta. This will be applicable only till the
-        migration period. Refer to the documentation at 'https://dataplatform.cloud.ibm.com/docs/content/wsj/analyze-data/wml-ai.html'
-        for details on migration.
+        """Migration APIs for v4 GA Cloud to migrate assets from v3 or v4 beta. This will be applicable only till the
+        migration period. Refer to the documentation at
+        'https://dataplatform.cloud.ibm.com/docs/content/wsj/analyze-data/wml-ai.html' for details on migration.
 
-        You will need to have a space or project created before you start migration of assets to that space or project
-        You should have read access to the instance from which migration is required
+        You will need to have a space or project created before you start migration of assets to that space or project.
+        You should have read access to the instance from which migration is required.
         You should have 'editor' or 'admin' access on the target 'space'/'project'
 
-        SKIP_MIGRATED_ASSETS meta prop: If this is True (the default) and if the target assets still exist and if
+        SKIP_MIGRATED_ASSETS meta prop: If this is `True` (the default) and if the target assets still exist and if
         there are completed jobs (that were not deleted) then any assets that were already migrated will be skipped
-        and the details will be returned in the skipped collection in the response. If this is False then it is
-        possible that duplicate assets will be created in the target space or project if the asset was already migrated
+        and the details will be returned in the skipped collection in the response. If this is `False` then it is
+        possible that duplicate assets will be created in the target space or project if the asset was already migrated.
 
-        **Parameters**
+        :param meta_props: meta data, to see available meta names use
+            ``client.v4ga_cloud_migration.ConfigurationMetaNames.get()`
+        :type meta_props: str or dict
 
-        .. important::
-            #. **meta_props**:  meta data. To see available meta names use **client.v4ga_cloud_migration.ConfigurationMetaNames.get()\n
-               **type**: str or dict\n
-
-        **Output**
-
-        .. important::
-            **returns**: Initial state of migration\n
-            **return type**: dict\n
+        :return: initial state of migration
+        :rtype: dict
 
         **Example**
 
-         >>> metadata = {
-         >>>    client.v4ga_cloud_migration.MigrationMetaNames.DESCRIPTION: "Migration of assets from v3 to v4ga",
-         >>>    client.v4ga_cloud_migration.MigrationMetaNames.OLD_INSTANCE_ID: "df40cf1-252f-424b-b52d-5cdd98143aec",
-         >>>    client.v4ga_cloud_migration.MigrationMetaNames.SPACE_ID: "3fc54cf1-252f-424b-b52d-5cdd9814987f",
-         >>>    client.v4ga_cloud_migration.MigrationMetaNames.FUNCTION_IDS: ["all"],
-         >>>    client.v4ga_cloud_migration.MigrationMetaNames.MODEL_IDS: ["afaecb4-254f-689f-4548-9b4298243291"],
-         >>>    client.v4ga_cloud_migration.MigrationMetaNames.MAPPING: {"dfaecf1-252f-424b-b52d-5cdd98143481": "4fbc211-252f-424b-b52d-5cdd98df310a"}
-         >>>    client.v4ga_cloud_migration.MigrationMetaNames.SKIP_MIGRATED_ASSETS: True
-         >>> }
-         >>> details = client.v4ga_cloud_migration.start(meta_props=metadata)
+        .. code-block:: python
+
+            metadata = {
+                client.v4ga_cloud_migration.MigrationMetaNames.DESCRIPTION: "Migration of assets from v3 to v4ga",
+                client.v4ga_cloud_migration.MigrationMetaNames.OLD_INSTANCE_ID: "df40cf1-252f-424b-b52d-5cdd98143aec",
+                client.v4ga_cloud_migration.MigrationMetaNames.SPACE_ID: "3fc54cf1-252f-424b-b52d-5cdd9814987f",
+                client.v4ga_cloud_migration.MigrationMetaNames.FUNCTION_IDS: ["all"],
+                client.v4ga_cloud_migration.MigrationMetaNames.MODEL_IDS: ["afaecb4-254f-689f-4548-9b4298243291"],
+                client.v4ga_cloud_migration.MigrationMetaNames.MAPPING: {"dfaecf1-252f-424b-b52d-5cdd98143481": "4fbc211-252f-424b-b52d-5cdd98df310a"}
+                client.v4ga_cloud_migration.MigrationMetaNames.SKIP_MIGRATED_ASSETS: True
+            }
+            details = client.v4ga_cloud_migration.start(meta_props=metadata)
         """
 
         print(self.notification_msg)
@@ -147,38 +138,33 @@ class Migrationv4GACloud(WMLResource):
             raise WMLClientError("PIPELINE_IDS is provided but empty. Provide pipeline id(s) to be migrated or "
                                  "'all' to migrate all pipelines")
 
-
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def cancel(self, migration_id, space_id=None, project_id=None):
-        """
-            Cancel a migration job. 'migration_id' and 'space_id'( or 'project_id' has to be provided )
-            Note: To delete a migratin job, use delete() api
+        """Cancel a migration job. `space_id` or `project_id` has to be provided.
 
-            **Parameters**
+        .. note::
+            To delete a migration job, use delete() api.
 
-            .. important::
-                #. **migration_id**:  Migration identifier\n
-                   **type**: str\n
-                #. **space_id**:  Space identifier\n
-                   **type**: str\n
-                #. **project_id**:  Project identifier\n
-                   **type**: str\n
+        :param migration_id: migration identifier
+        :type migration_id: str
+        :param space_id: space identifier
+        :type space_id: str, optional
+        :param project_id: project identifier
+        :type project_id: str, optional
 
-            **Output**
+        :return: status ("SUCCESS" or "FAILED")
+        :rtype: str
 
-            .. important::
-                **returns**: status ("SUCCESS" or "FAILED")\n
-                **return type**: str\n
+        **Example**
 
-            **Example**
+        .. code-block:: python
 
-             >>> client.v4ga_cloud_migration.cancel(migration_id='6213cf1-252f-424b-b52d-5cdd9814956c',
-             >>>                                    space_id='3421cf1-252f-424b-b52d-5cdd981495fe')
+            client.v4ga_cloud_migration.cancel(migration_id='6213cf1-252f-424b-b52d-5cdd9814956c',
+                                               space_id='3421cf1-252f-424b-b52d-5cdd981495fe')
         """
 
         print(self.notification_msg)
 
-        Migrationv4GACloud._validate_type(migration_id, u'migration_id', STR_TYPE, True)
+        Migrationv4GACloud._validate_type(migration_id, u'migration_id', str, True)
 
         if space_id is None and project_id is None:
             raise WMLClientError("Its mandatory to provide space_id or project_id")
@@ -203,36 +189,29 @@ class Migrationv4GACloud(WMLResource):
         if "SUCCESS" == details:
             print("Migration job cancelled")
 
-
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def delete(self, migration_id, space_id=None, project_id=None):
-        """
-            Deletes a migration job. 'migration_id' and 'space_id'( or 'project_id' has to be provided )
+        """Deletes a migration job. `space_id` or `project_id` has to be provided.
 
-            **Parameters**
+        :param migration_id: migration identifier
+        :type migration_id: str
+        :param space_id: space identifier
+        :type space_id: str, optional
+        :param project_id: project identifier
+        :type project_id: str, optional
 
-            .. important::
-                #. **migration_id**:  Migration identifier\n
-                   **type**: str\n
-                #. **space_id**:  Space identifier\n
-                   **type**: str\n
-                #. **project_id**:  Project identifier\n
-                   **type**: str\n
+        :return: status ("SUCCESS" or "FAILED")
+        :rtype: str
 
-            **Output**
+        **Example**
 
-            .. important::
-                **returns**: status ("SUCCESS" or "FAILED")\n
-                **return type**: str\n
+        .. code-block:: python
 
-            **Example**
-
-             >>> client.v4ga_cloud_migration.delete(migration_id='6213cf1-252f-424b-b52d-5cdd9814956c',
-             >>>                                    space_id='3421cf1-252f-424b-b52d-5cdd981495fe')
+            client.v4ga_cloud_migration.delete(migration_id='6213cf1-252f-424b-b52d-5cdd9814956c',
+                                               space_id='3421cf1-252f-424b-b52d-5cdd981495fe')
         """
         print(self.notification_msg)
 
-        Migrationv4GACloud._validate_type(migration_id, u'migration_id', STR_TYPE, True)
+        Migrationv4GACloud._validate_type(migration_id, u'migration_id', str, True)
 
         if space_id is None and project_id is None:
             raise WMLClientError("Its mandatory to provide space_id or project_id")
@@ -257,50 +236,43 @@ class Migrationv4GACloud(WMLResource):
         if "SUCCESS" == details:
             print("Migration job deleted")
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_details(self, migration_id=None, space_id=None, project_id=None, limit=None, asynchronous=False, get_all=False):
-        """
-        Get metadata of of the migration job function(s). If no migration_id is specified all migration jobs
+        """Get metadata of the migration job function(s). If no `migration_id` is specified all migration jobs
         metadata is returned.
 
-        **Parameters**
+        :param migration_id: migration identifier
+        :type migration_id: str, optional
+        :param space_id: space identifier
+        :type space_id: str, optional
+        :param project_id: project identifier
+        :type project_id: str, optional
+        :param limit: limit number of fetched records
+        :type limit: int, optional
+        :param asynchronous: if `True`, it will work as a generator
+        :type asynchronous: bool, optional
+        :param get_all: if `True`, it will get all entries in 'limited' chunks
+        :type get_all: bool, optional
 
-        .. important::
-            #. **migration_id**:  Migration identifier\n
-                **type**: str\n
-            #. **space_id**:  Space identifier\n
-                **type**: str\n
-            #. **project_id**:  Project identifier\n
-                **type**: str\n
-            #. **limit**:  limit number of fetched records (optional)\n
-                **type**: int\n
-            #. **asynchronous**:  if True, it will work as a generator (optional)\n
-               **type**: bool\n
-            #. **get_all**:  if True, it will get all entries in 'limited' chunks (optional)\n
-               **type**: bool\n
-
-        **Output**
-
-        .. important::
-            **returns**: migration(s) metadata\n
-            **return type**: dict\n
-            dict (if migration_id is not None) or {"resources": [dict]} (if migration_id is None)\n
+        :return: migration(s) metadata
+        :rtype: dict (if migration_id is not None) or {"resources": [dict]} (if migration_id is None)\n
 
         **Example**
 
-         >>> migration_details = client.v4ga_cloud_migration.get_details(migration_id='6213cf1-252f-424b-b52d-5cdd9814956c',
-         >>>                                                             space_id='3421cf1-252f-424b-b52d-5cdd981495fe')
-         >>> migration_details = client.v4ga_cloud_migration.get_details(limit=100)
-         >>> migration_details = client.v4ga_cloud_migration.get_details(limit=100, get_all=True)
-         >>> migration_details = []
-         >>> for entry in client.v4ga_cloud_migration.get_details(limit=100, asynchronous=True, get_all=True):
-         >>>    migration_details.extend(entry)
+        .. code-block:: python
+
+            migration_details = client.v4ga_cloud_migration.get_details(migration_id='6213cf1-252f-424b-b52d-5cdd9814956c',
+                                                                        space_id='3421cf1-252f-424b-b52d-5cdd981495fe')
+            migration_details = client.v4ga_cloud_migration.get_details(limit=100)
+            migration_details = client.v4ga_cloud_migration.get_details(limit=100, get_all=True)
+            migration_details = []
+            for entry in client.v4ga_cloud_migration.get_details(limit=100, asynchronous=True, get_all=True):
+                migration_details.extend(entry)
         """
 
         if self.skip_msg is False:
             print(self.notification_msg)
 
-        Migrationv4GACloud._validate_type(migration_id, u'migration_id', STR_TYPE, False)
+        Migrationv4GACloud._validate_type(migration_id, u'migration_id', str, False)
 
         query_params = {}
 
@@ -322,24 +294,21 @@ class Migrationv4GACloud(WMLResource):
             return self._get_artifact_details(href, migration_id, limit, 'migration', query_params=query_params)
 
     def list(self, space_id=None, project_id=None, limit=None):
-        """
-        List the migration jobs. If limit is set to None there will be only first 50 records shown.
+        """Print the migration jobs in a table format. If limit is set to None there will be only
+        first 50 records shown.
 
-        **Parameters**
-
-        .. important::
-            #. **limit**:  limit number of fetched records\n
-               **type**: int\n
-
-        **Output**
-
-        .. important::
-            This method only prints the list of all migration jobs in a table format.\n
-            **return type**: None\n
+        :param space_id: space identifier
+        :type space_id: str, optional
+        :param project_id: project identifier
+        :type project_id: str, optional
+        :param limit: limit number of fetched records
+        :type limit: int, optional
 
         **Example**
 
-         >>> client.v4ga_cloud_migration.list()
+        .. code-block:: python
+
+            client.v4ga_cloud_migration.list()
         """
 
         print(self.notification_msg)
