@@ -14,8 +14,7 @@
 
 from __future__ import print_function
 import ibm_watson_machine_learning._wrappers.requests as requests
-from ibm_watson_machine_learning.utils import SPACES_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, MEMBER_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv, str_type_conv, get_file_from_cos
-from ibm_watson_machine_learning.metanames import ModelDefinitionMetaNames, MetaNamesBase,  MetaNames
+from ibm_watson_machine_learning.metanames import ModelDefinitionMetaNames
 from ibm_watson_machine_learning.wml_resource import WMLResource
 from ibm_watson_machine_learning.wml_client_error import WMLClientError
 import os
@@ -26,20 +25,17 @@ _DEFAULT_LIST_LENGTH = 50
 
 
 class ModelDefinition(WMLResource):
-    """
-    Store and manage your model_definitions.
-    """
+    """Store and manage your model definitions."""
 
     ConfigurationMetaNames = ModelDefinitionMetaNames()
 
-    """MetaNames for model_definition creation."""
+    """MetaNames for model definition creation."""
 
     def __init__(self, client):
         WMLResource.__init__(self, __name__, client)
         self._ICP = client.ICP
         self.default_space_id = client.default_space_id
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def _generate_model_definition_document(self, meta_props):
         if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
             doc = {
@@ -128,38 +124,33 @@ class ModelDefinition(WMLResource):
 
         return doc
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def store(self, model_definition, meta_props):
-        """
-        Create a model_definitions.\n
+        """Create a model definition.
 
-        **Parameters**
+        :param meta_props: meta data of the model definition configuration, to see available meta names use:
 
-        .. important::
+            .. code-block:: python
 
-            #. **meta_props**:  meta data of the model_definition configuration. To see available meta names use:\n
-                >>> client.model_definitions.ConfigurationMetaNames.get()
-               **type**: dict\n
+                client.model_definitions.ConfigurationMetaNames.get()
 
-            #. **model_definition**:  Path to the content file to be uploaded\n
-               **type**: str\n
+        :type meta_props: dict
 
-        **Output**
+        :param model_definition: path to the content file to be uploaded
+        :type model_definition: str
 
-        .. important::
-
-            **returns**: Metadata of the model_defintion created\n
-            **return type**: dict\n
+        :return: metadata of the model definition created
+        :rtype: dict
 
         **Example**
 
-            >>>  client.model_definitions.store(model_definition, meta_props)
+        .. code-block:: python
+
+            client.model_definitions.store(model_definition, meta_props)
         """
 
         WMLResource._chk_and_block_create_update_for_python36(self)
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
-        model_definition = str_type_conv(model_definition)
         self.ConfigurationMetaNames._validate(meta_props)
 
         if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
@@ -247,8 +238,12 @@ class ModelDefinition(WMLResource):
             model_definition_attachment_put_url = self._client.wml_credentials['url'] + model_definition_attachment_signed_url
 
             with open(model_definition, 'rb') as f:
-                put_response = requests.put(model_definition_attachment_put_url if self._ICP else model_definition_attachment_signed_url,
+                if self._ICP:
+                    put_response = requests.put(model_definition_attachment_put_url,
                                             files={'file': (model_definition, f, 'application/octet-stream')})
+                else:
+                    put_response = requests.put(model_definition_attachment_signed_url,
+                                                data=open(model_definition, 'rb').read())
 
             if put_response.status_code != 201 and put_response.status_code != 200:
                 self._handle_response(200, 'uploading a model_definition attachment file', put_response)
@@ -284,28 +279,21 @@ class ModelDefinition(WMLResource):
             finally:
                 raise e
 
-
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_details(self, model_definition_uid=None):
-        """
-           Get metadata of stored model_definition. If no model_definition_uid is passed, details for all model_definitions will be returned.
+        """Get metadata of stored model definition. If no `model_definition_uid` is passed,
+        details for all model definitions will be returned.
 
+        :param model_definition_uid: Unique Id of model definition
+        :type model_definition_uid: str, optional
 
-           **Parameters**
+        :return: metadata of model definition
+        :rtype: dict (if `model_definition_uid` is not None)
 
-           .. important::
-                #. **model_definition_uid**: Unique Id of model_definition \n
-                   **type**: str\n
+        **Example**
 
-           **Output**
+        .. code-block: python
 
-           .. important::
-                **returns**: metadata of model definition\n
-                **return type**: dict (if model_definition_uid is not None)\n
-
-           **Example**
-
-            >>> model_definition_details = client.model_definitions.get_details(model_definition_uid)
+            model_definition_details = client.model_definitions.get_details(model_definition_uid)
 
         """
         def get_required_element_from_response(response):
@@ -330,38 +318,29 @@ class ModelDefinition(WMLResource):
 
         return self._get_asset_based_resource(model_definition_uid, 'wml_model_definition', get_required_element_from_response)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def download(self, model_definition_uid, filename, rev_id=None):
-        """
-            Download the content of a script asset.
+        """Download the content of a model definition asset.
 
-            **Parameters**
+        :param model_definition_uid: the Unique Id of the model definition asset to be downloaded
+        :type model_definition_uid: str
+        :param filename: filename to be used for the downloaded file
+        :type filename: str
+        :param rev_id: revision id
+        :type rev_id: str, optional
 
-            .. important::
-                 #. **model_definition_uid**:  The Unique Id of the model_definition asset to be downloaded\n
-                    **type**: str\n
+        :return: path to the downloaded asset content
+        :rtype: str
 
-                 #. **filename**:  filename to be used for the downloaded file\n
-                    **type**: str\n
+        **Example**
 
-                 #. **rev_id**:  Revision id\n
-                    **type**: str\n
+        .. code-block:: python
 
-            **Output**
-
-            .. important::
-
-                 **returns**: Path to the downloaded asset content\n
-                 **return type**: str\n
-
-            **Example**
-
-             >>> client.model_definitions.download(model_definition_uid, "model_definition_file")
+            client.model_definitions.download(model_definition_uid, "model_definition_file")
         """
 
         self._client._check_if_either_is_set()
 
-        ModelDefinition._validate_type(model_definition_uid, u'model_definition_uid', STR_TYPE, True)
+        ModelDefinition._validate_type(model_definition_uid, u'model_definition_uid', str, True)
         params = self._client._params()
         if rev_id is not None:
             ModelDefinition._validate_type(rev_id, u'rev_id', int, False)
@@ -417,32 +396,25 @@ class ModelDefinition(WMLResource):
         else:
             raise WMLClientError("Failed while downloading the asset " + model_definition_uid)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def delete(self, model_definition_uid):
-        """
-            Delete a stored model_definition.
+        """Delete a stored model definition.
 
-            **Parameters**
+        :param model_definition_uid: Unique Id of stored model definition
+        :type model_definition_uid: str
 
-            .. important::
-                #. **model_definition_uid**: Unique Id of stored Model definition\n
-                   **type**: str\n
+        :return: status ("SUCCESS" or "FAILED")
+        :rtype: str
 
-            **Output**
+        **Example**
 
-            .. important::
-                **returns**: status ("SUCCESS" or "FAILED")\n
-                **return type**: str\n
+        .. code-block:: python
 
-            **Example**
-
-             >>> client.model_definitions.delete(model_definition_uid)
+            client.model_definitions.delete(model_definition_uid)
 
         """
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
-        model_definition_uid = str_type_conv(model_definition_uid)
-        ModelDefinition._validate_type(model_definition_uid, u'model_definition_uid', STR_TYPE, True)
+        ModelDefinition._validate_type(model_definition_uid, u'model_definition_uid', str, True)
         paramvalue = self._client._params()
 
         model_definition_endpoint = self._client.service_instance._href_definitions.get_model_definition_assets_href() + "/" + model_definition_uid
@@ -451,31 +423,21 @@ class ModelDefinition(WMLResource):
 
         return self._handle_response(204, u'Model definition deletion', response_delete, False)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def _delete(self, model_definition_uid):
-        """
-            Delete a stored model_definition.
+        """Delete a stored model definition.
 
-            **Parameters**
+        :param model_definition_uid: Unique Id of stored model definition
+        :type model_definition_uid: str
 
-            .. important::
-                #. **model_definition_uid**: Unique Id of Model definition\n
-                   **type**: str\n
+        **Example**
 
-            **Output**
+        .. code-block:: python
 
-            .. important::
-                **returns**: status ("SUCCESS" or "FAILED")\n
-                **return type**: str\n
-
-            **Example**
-
-             >>> client.model_definitions.delete(model_definition_uid)
+            client.model_definitions._delete(model_definition_uid)
 
         """
         ##For CP4D, check if either spce or project ID is set
-        model_definition_uid = str_type_conv(model_definition_uid)
-        ModelDefinition._validate_type(model_definition_uid, u'model_definition_uid', STR_TYPE, True)
+        ModelDefinition._validate_type(model_definition_uid, u'model_definition_uid', str, True)
         paramvalue = self._client._params()
         model_definition_endpoint = self._client.service_instance._href_definitions.get_model_definition_assets_href() + "/" + model_definition_uid
 
@@ -568,24 +530,17 @@ class ModelDefinition(WMLResource):
         return attachment_id
 
     def list(self, limit=None):
-        """
-           List stored model_definition assets. If limit is set to None there will be only first 50 records shown.
+        """Print stored model definition assets in a table format.
+        If limit is set to None there will be only first 50 records shown.
 
-           **Parameters**
+        :param limit: limit number of fetched records
+        :type limit: int, optional
 
-           .. important::
-                #. **limit**:  limit number of fetched records\n
-                   **type**: int\n
+        **Example**
 
-           **Output**
+        .. code-block:: python
 
-           .. important::
-                This method only prints the list of all model_definition assets in a table format.\n
-                **return type**: None\n
-
-           **Example**
-
-                     >>> client.model_definitions.list()
+            client.model_definitions.list()
 
         """
         ##For CP4D, check if either spce or project ID is set
@@ -612,55 +567,41 @@ class ModelDefinition(WMLResource):
 
         self._list(model_def_values, [u'NAME', u'ASSET_TYPE', u'GUID'], limit, _DEFAULT_LIST_LENGTH)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_id(self, model_definition_details):
-        """
-                Get Unique Id of stored model_definition asset.
+        """Get Unique Id of stored model definition asset.
 
-                **Parameters**
+        :param model_definition_details: metadata of the stored model definition asset
+        :type model_definition_details: dict
 
-                .. important::
+        :return: Unique Id of stored model definition asset
+        :rtype: str
 
-                   #. **model_definition_details**:  Metadata of the stored model_definition asset\n
-                      **type**: dict\n
+        **Example**
 
-                **Output**
+        .. code-block:: python
 
-                .. important::
-
-                    **returns**: Unique Id of stored model_definition asset\n
-                    **return type**: str\n
-
-                **Example**
-
-                     >>> asset_uid = client.model_definition.get_id(asset_details)
+            asset_uid = client.model_definition.get_id(asset_details)
 
         """
 
         return ModelDefinition.get_uid(self, model_definition_details)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_uid(self, model_definition_details):
-        """
-        Get uid of stored model. Deprecated!! Use get_id(model_definition_details) instead
+        """Get uid of stored model.
 
-        **Parameters**
+        *Deprecated:* Use ``get_id(model_definition_details)`` instead.
 
-        .. important::
+        :param model_definition_details: stored model definition details
+        :type model_definition_details: dict
 
-            #. **param model_definition_details**:  stored model_definition details\n
-               **type**: dict
-
-        **Output**
-
-        .. important::
-
-            **returns**: uid of stored model_definition\n
-            **return type**: str\n
+        :return: uid of stored model definition
+        :rtype: str
 
         **Example**
 
-            >>> model_definition_uid = client.model_definitions.get_uid(model_definition_details)
+        .. code-block:: python
+
+            model_definition_uid = client.model_definitions.get_uid(model_definition_details)
         """
         if 'asset_id' in model_definition_details['metadata']:
             return WMLResource._get_required_element_from_dict(model_definition_details, u'model_definition_details',
@@ -671,25 +612,20 @@ class ModelDefinition(WMLResource):
 
             return WMLResource._get_required_element_from_dict(model_definition_details, u'model_definition_details', [u'metadata', u'guid'])
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_href(self, model_definition_details):
-        """
-        Get href of stored model_definition.
+        """Get href of stored model definition.
 
-        **Parameters**
+        :param model_definition_details: stored model definition details
+        :type model_definition_details: dict
 
-        .. important::
-            #. **model_definition_details**: Stored model_definition details.\n
-               **type**: dict\n
-
-        **Output**
-
-        .. important::
-            **returns**: href of stored model_definition.\n
-            **return type**: str\n
+        :return: href of stored model definition
+        :rtype: str
 
         **Example**
-            >>> model_definition_uid = client.model_definitions.get_href(model_definition_details)
+
+        .. code-block:: python
+
+            model_definition_uid = client.model_definitions.get_href(model_definition_details)
         """
         if 'asset_id' in model_definition_details['metadata']:
             return WMLResource._get_required_element_from_dict(model_definition_details, u'model_definition_details', [u'metadata', u'asset_id'])
@@ -700,31 +636,24 @@ class ModelDefinition(WMLResource):
             return WMLResource._get_required_element_from_dict(model_definition_details, u'model_definition_details',
                                                                [u'metadata', u'href'])
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def update(self, model_definition_id, meta_props=None, file_path=None):
-        """
-        Update model_definition with either metadata or attachment or both.\n
+        """Update model definition with either metadata or attachment or both.
 
-        **Parameters**
+        :param model_definition_id: model definition ID
+        :type model_definition_id: str
+        :param meta_props: meta data of the model definition configuration to be updated
+        :type meta_props: dict
+        :param file_path: path to the content file to be uploaded
+        :type file_path: str, optional
 
-        .. important::
-
-            #. **model_definition_id**:  model_definition ID.\n
-               **type**: str\n
-
-            #. **file_path**: Path to the content file to be uploaded.\n
-               **type**: str\n
-
-        ** Output**
-
-        .. important::
-
-            **returns**: Updated metadata of model_definition.\n
-            **return type**: dict\n
+        :return: updated metadata of model definition
+        :rtype: dict
 
         **Example**
 
-            >>> model_definition_details = client.model_definition.update(model_definition_id, meta_props, file_path)
+        .. code-block:: python
+
+            model_definition_details = client.model_definition.update(model_definition_id, meta_props, file_path)
         """
 
         WMLResource._chk_and_block_create_update_for_python36(self)
@@ -732,10 +661,10 @@ class ModelDefinition(WMLResource):
         if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(u'Not supported in this release')
 
-        ModelDefinition._validate_type(model_definition_id, 'model_definition_id', STR_TYPE, True)
+        ModelDefinition._validate_type(model_definition_id, 'model_definition_id', str, True)
 
         if meta_props is None and file_path is None:
-            raise WMLClientError('Atleast either meta_props or file_path has to be provided')
+            raise WMLClientError('At least either meta_props or file_path has to be provided')
 
         updated_details = None
 
@@ -776,14 +705,11 @@ class ModelDefinition(WMLResource):
         # Patch meta if provided
         if meta_props is not None:
             self._validate_type(meta_props, u'meta_props', dict, True)
-            meta_props_str_conv(meta_props)
 
-            meta_patch_payload = []
-            entity_patch_payload = []
+            props_for_asset_meta_patch = {}
 
             # Since we are dealing with direct asset apis, there can be metadata or entity patch or both
             if "name" in meta_props or "description" in meta_props:
-                props_for_asset_meta_patch = {}
 
                 for key in meta_props:
                     if key == 'name' or key == 'description':
@@ -882,29 +808,21 @@ class ModelDefinition(WMLResource):
         else:
             raise WMLClientError('Unable to update attachment because of server error. Try again later')
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def create_revision(self, model_definition_uid):
-        """
-        Creates revision for the given model_definition. Revisions are immutable once created.
-        The metadata and attachment at model_definition is taken and a revision is created out of it.
+        """Creates revision for the given model definition. Revisions are immutable once created.
+        The metadata and attachment at model definition is taken and a revision is created out of it.
 
-        **Parameters**
+        :param model_definition_uid: model definition ID
+        :type model_definition_uid: str
 
-        .. important::
-
-            #. **model_definition**: model_definition ID.\n
-               **type**: str\n
-
-        **Output**
-
-        .. important::
-
-            **returns**: Stored model_definition revisions metadata.\n
-            **return type**: dict\n
+        :return: stored model definition revisions metadata
+        :rtype: dict
 
         **Example**
 
-            >>> model_definition_revision = client.model_definitions.create_revision(model_definition_id)
+        .. code-block:: python
+
+            model_definition_revision = client.model_definitions.create_revision(model_definition_id)
         """
         WMLResource._chk_and_block_create_update_for_python36(self)
 
@@ -914,8 +832,7 @@ class ModelDefinition(WMLResource):
 
         self._client._check_if_either_is_set()
 
-        model_defn_id = str_type_conv(model_definition_uid)
-        ModelDefinition._validate_type(model_defn_id, u'model_defn_id', STR_TYPE, True)
+        ModelDefinition._validate_type(model_definition_uid, u'model_definition_uid', str, True)
 
         print("Creating model_definition revision...")
 
@@ -923,7 +840,7 @@ class ModelDefinition(WMLResource):
         #     self._create_revision_artifact_for_assets(model_defn_id, 'Model definition'))
 
         response = self._get_required_element_from_response(
-            self._create_revision_artifact_for_assets(model_defn_id, 'Model definition'))
+            self._create_revision_artifact_for_assets(model_definition_uid, 'Model definition'))
 
         if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             return response
@@ -942,43 +859,32 @@ class ModelDefinition(WMLResource):
 
             return final_response
 
-
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_revision_details(self, model_definition_uid, rev_uid=None):
-        """
-        Get metadata of model_definit
+        """Get metadata of model definition.
 
-        **Parameters**
+        :param model_definition_uid: model definition ID
+        :type model_definition_uid: str
 
-        .. important::
+        :param rev_uid: revision ID, if this parameter is not provided, returns latest revision if existing else error
+        :type rev_uid: int, optional
 
-            #. **model_definition_uid**: model_definition ID.\n
-               **type**: str\n
-
-            #. **rev_uid**: Revision ID. If this parameter is not provided, returns latest revision if existing else error.\n
-               **type**: int\n
-
-        **Output**
-
-        .. important::
-
-            **returns**: Stored model definitions metadata.\n
-            **return type**: dict\n
+        :return: stored model definitions metadata
+        :rtype: dict
 
         **Example**
 
-            >>> script_details = client.model_definitions.get_revision_details(model_definition_uid, rev_uid)
+        .. code-block:: python
+
+            script_details = client.model_definitions.get_revision_details(model_definition_uid, rev_uid)
         """
 
         if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(
                 u'Revisions APIs are not supported in this release.')
         op_name = 'getting model_definition revision details'
-        modeldef_uid = str_type_conv(model_definition_uid)
-        ModelDefinition._validate_type(modeldef_uid, u'model_definition_uid', STR_TYPE, True)
-        ModelDefinition._validate_type(modeldef_uid, u'model_definition_uid', STR_TYPE, True)
+        ModelDefinition._validate_type(model_definition_uid, u'model_definition_uid', str, True)
 
-        url = self._client.service_instance._href_definitions.get_model_definition_assets_href() + u'/' + modeldef_uid
+        url = self._client.service_instance._href_definitions.get_model_definition_assets_href() + u'/' + model_definition_uid
         paramvalue = self._client._params()
 
         if rev_uid is None:
@@ -1016,29 +922,20 @@ class ModelDefinition(WMLResource):
         else:
             return self._handle_response(200, op_name, response_get)
 
-
     def list_revisions(self, model_definition_uid, limit=None):
-        """
-           List stored model_definition assets. If limit is set to None there will be only first 50 records shown.
+        """Print stored model definition assets in a table format.
+        If limit is set to None there will be only first 50 records shown.
 
-           **Parameters**
+        :param model_definition_uid: Unique id of model definition
+        :type model_definition_uid: str
+        :param limit: limit number of fetched records
+        :type limit: int, optional
 
-           .. important::
-                #. **model_definition_uid**:  Unique id of model_definition\n
-                   **type**: str\n
+        **Example**
 
-                #. **limit**:  limit number of fetched records\n
-                   **type**: int\n
+        .. code-block:: python
 
-           **Output**
-
-           .. important::
-                This method only prints the list of all model_definition revision in a table format.\n
-                **return type**: None\n
-
-           **Example**
-
-                >>> client.model_definitions.list_revisions()
+            client.model_definitions.list_revisions()
 
         """
         ##For CP4D, check if either spce or project ID is set
