@@ -14,7 +14,7 @@
 
 from __future__ import print_function
 import ibm_watson_machine_learning._wrappers.requests as requests
-from ibm_watson_machine_learning.utils import PIPELINE_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv, str_type_conv, get_file_from_cos
+from ibm_watson_machine_learning.utils import PIPELINE_DETAILS_TYPE
 from ibm_watson_machine_learning.metanames import PipelineMetanames
 from ibm_watson_machine_learning.wml_resource import WMLResource
 from ibm_watson_machine_learning.href_definitions import API_VERSION, SPACES, PIPELINES, LIBRARIES, EXPERIMENTS, RUNTIMES, DEPLOYMENTS
@@ -24,9 +24,8 @@ import json
 
 
 class Pipelines(WMLResource):
-    """
-    Store and manage your pipelines.
-    """
+    """Store and manage your pipelines."""
+
     ConfigurationMetaNames = PipelineMetanames()
     """MetaNames for pipelines creation."""
 
@@ -36,8 +35,6 @@ class Pipelines(WMLResource):
         self.WSD = client.WSD
         self._ICP = client.ICP
 
-
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def _generate_pipeline_document(self, meta_props):
         if self._client.ICP:
             doc = {
@@ -138,35 +135,49 @@ class Pipelines(WMLResource):
         else:
             return doc
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def store(self, meta_props, **kwargs):
-        """
-           Create a pipeline.\n
+        """Create a pipeline.
 
-           **Parameters**
+        :param meta_props: meta data of the pipeline configuration. To see available meta names use:
 
-           .. important::
+            .. code-block:: python
 
-                #. **meta_props**:  meta data of the pipeline configuration. To see available meta names use:\n
-                                    >>> client.pipelines.ConfigurationMetaNames.get()
+                client.pipelines.ConfigurationMetaNames.get()
 
-                   **type**: dict\n
+        :type meta_props: dict
 
-           **Output**
+        :return: stored pipeline metadata
+        :rtype: dict
 
-           .. important::
+        **Example**
 
-                **returns**: stored pipeline metadata\n
-                **return type**: dict\n
+        .. code-block:: python
 
-           **Example**
-
-            >>> metadata = {
-            >>>  client.pipelines.ConfigurationMetaNames.NAME: 'my_pipeline',
-            >>>  client.pipelines.ConfigurationMetaNames.DESCRIPTION: 'sample description'
-            >>> }
-            >>> pipeline_details = client.pipelines.store(training_definition_filepath, meta_props=metadata)
-            >>> pipeline_url = client.pipelines.get_href(pipeline_details)
+            metadata = {
+                client.pipelines.ConfigurationMetaNames.NAME: 'my_training_definition',
+                client.pipelines.ConfigurationMetaNames.DOCUMENT: {"doc_type":"pipeline",
+                                                                   "version": "2.0",
+                                                                   "primary_pipeline": "dlaas_only",
+                                                                   "pipelines": [{"id": "dlaas_only",
+                                                                                  "runtime_ref": "hybrid",
+                                                                                  "nodes": [{"id": "training",
+                                                                                             "type": "model_node",
+                                                                                             "op": "dl_train",
+                                                                                             "runtime_ref": "DL",
+                                                                                             "inputs": [],
+                                                                                             "outputs": [],
+                                                                                             "parameters": {"name": "tf-mnist",
+                                                                                                            "description": "Simple MNIST model implemented in TF",
+                                                                                                            "command": "python3 convolutional_network.py --trainImagesFile ${DATA_DIR}/train-images-idx3-ubyte.gz --trainLabelsFile ${DATA_DIR}/train-labels-idx1-ubyte.gz --testImagesFile ${DATA_DIR}/t10k-images-idx3-ubyte.gz --testLabelsFile ${DATA_DIR}/t10k-labels-idx1-ubyte.gz --learningRate 0.001 --trainingIters 6000",
+                                                                                                            "compute": {"name": "k80","nodes": 1},
+                                                                                                            "training_lib_href": "/v4/libraries/64758251-bt01-4aa5-a7ay-72639e2ff4d2/content"
+                                                                                             },
+                                                                                             "target_bucket": "wml-dev-results"
+                                                                                  }]
+                                                                   }]
+                }
+            }
+            pipeline_details = client.pipelines.store(training_definition_filepath, meta_props=metadata)
 
         """
         WMLResource._chk_and_block_create_update_for_python36(self)
@@ -301,22 +312,24 @@ class Pipelines(WMLResource):
 
         return pipeline_details
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def create_revision(self, pipeline_uid):
-        """
-            Create a new pipeline revision.
+        """Create a new pipeline revision.
 
-            :param pipeline_uid: Unique pipeline ID
-            :type pipeline_uid: {str_type}
+        :param pipeline_uid: Unique pipeline ID
+        :type pipeline_uid: str
 
-            Example:
+        :return: pipeline revision details
+        :rtype: dict
 
-            >>> client.pipelines.create_revision(pipeline_uid)
+        **Example**
+
+        .. code-block:: python
+
+            client.pipelines.create_revision(pipeline_uid)
 
         """
         WMLResource._chk_and_block_create_update_for_python36(self)
-        pipeline_uid = str_type_conv(pipeline_uid)
-        Pipelines._validate_type(pipeline_uid, u'pipeline_uid', STR_TYPE, False)
+        Pipelines._validate_type(pipeline_uid, u'pipeline_uid', str, False)
 
         if not any([self._client.ICP_30, self._client.CLOUD_PLATFORM_SPACES, self._client.ICP_35, self._client.ICP_40,
                     self._client.ICP_45, self._client.ICP_46]):
@@ -327,33 +340,25 @@ class Pipelines(WMLResource):
             #return self. _create_revision_artifact_for_assets(pipeline_uid, 'pipelines')
             return self._create_revision_artifact(url, pipeline_uid, 'pipelines')
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def update(self, pipeline_uid, changes, rev_id = None):
-        """
-                Updates existing pipeline metadata.
+        """Updates existing pipeline metadata.
 
-                **Parameters**
+        :param pipeline_uid: Unique Id of pipeline which definition should be updated
+        :type pipeline_uid: str
+        :param changes: elements which should be changed, where keys are ConfigurationMetaNames
+        :type changes: dict
 
-                .. important::
+        :return: metadata of updated pipeline
+        :rtype: dict
 
-                    #. **pipeline_uid**:  Unique Id of pipeline which definition should be updated\n
-                       **type**: str\n
-                    #. **changes**:  elements which should be changed, where keys are ConfigurationMetaNames\n
-                       **type**: dict\n
+        **Example**
 
-                **Output**
+        .. code-block:: python
 
-                .. important::
-
-                       **returns**: metadata of updated pipeline\n
-                       **return type**: dict\n
-
-                **Example**
-
-                 >>> metadata = {
-                 >>> client.pipelines.ConfigurationMetaNames.NAME:"updated_pipeline"
-                 >>> }
-                 >>> pipeline_details = client.pipelines.update(pipeline_uid, changes=metadata)
+            metadata = {
+                client.pipelines.ConfigurationMetaNames.NAME: "updated_pipeline"
+            }
+            pipeline_details = client.pipelines.update(pipeline_uid, changes=metadata)
 
         """
         WMLResource._chk_and_block_create_update_for_python36(self)
@@ -362,10 +367,8 @@ class Pipelines(WMLResource):
         if self._client.WSD:
             raise WMLClientError(" Update pipeline operation is not supported in WSD. ")
 
-        pipeline_uid = str_type_conv(pipeline_uid)
-        self._validate_type(pipeline_uid, u'pipeline_uid', STR_TYPE, True)
+        self._validate_type(pipeline_uid, u'pipeline_uid', str, True)
         self._validate_type(changes, u'changes', dict, True)
-        meta_props_str_conv(changes)
 
         details = self._client.pipelines.get_details(pipeline_uid)
 
@@ -380,85 +383,67 @@ class Pipelines(WMLResource):
 
         return updated_details
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def delete(self, pipeline_uid):
-        """
-            Delete a stored pipeline.
+        """Delete a stored pipeline.
 
-            **Parameters**
+        :param pipeline_uid: Unique Id of pipeline
+        :type pipeline_uid: str
 
-            .. important::
-                #. **pipeline_uid**: Unique Id of Pipeline\n
-                   **type**: str\n
+        :return: status ("SUCCESS" or "FAILED")
+        :rtype: str
 
-            **Output**
+        **Example**
 
-            .. important::
-                **returns**: status ("SUCCESS" or "FAILED")\n
-                **return type**: str\n
+        .. code-block:: python
 
-            **Example**
-
-             >>> client.pipelines.delete(pipeline_uid)
+            client.pipelines.delete(pipeline_uid)
 
         """
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
 
-        pipeline_uid = str_type_conv(pipeline_uid)
-        Pipelines._validate_type(pipeline_uid, u'pipeline_uid', STR_TYPE, True)
+        Pipelines._validate_type(pipeline_uid, u'pipeline_uid', str, True)
         if self._client.WSD:
             pipeline_endpoint = self._client.service_instance._href_definitions.get_model_definition_assets_href() + "/" + pipeline_uid
         else:
             pipeline_endpoint = self._client.service_instance._href_definitions.get_pipeline_href(pipeline_uid)
 
-        response_delete = requests.delete(pipeline_endpoint, params=self._client._params(),headers=self._client._get_headers())
+        response_delete = requests.delete(pipeline_endpoint, params=self._client._params(), headers=self._client._get_headers())
 
         return self._handle_response(204, u'pipeline deletion', response_delete, False)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_details(self, pipeline_uid=None, limit=None, asynchronous=False, get_all=False):
-        """
-           Get metadata of stored pipeline(s). If pipeline UID is not specified returns all pipelines metadata.
+        """Get metadata of stored pipeline(s). If pipeline UID is not specified returns all pipelines metadata.
 
-           **Parameters**
+        :param pipeline_uid: Pipeline UID
+        :type pipeline_uid: str, optional
+        :param limit: limit number of fetched records
+        :type limit: int, optional
+        :param asynchronous: if `True`, it will work as a generator
+        :type asynchronous: bool, optional
+        :param get_all: if `True`, it will get all entries in 'limited' chunks
+        :type get_all: bool, optional
 
-           .. important::
-                #. **pipeline_uid**: Pipeline UID (optional)\n
-                   **type**: str\n
-                #. **limit**:  limit number of fetched records (optional)\n
-                   **type**: int\n
-                #. **asynchronous**:  if True, it will work as a generator (optional)\n
-                   **type**: bool\n
-                #. **get_all**:  if True, it will get all entries in 'limited' chunks (optional)\n
-                   **type**: bool\n
+        :return: metadata of pipeline(s)
+        :rtype: dict (if UID is not None) or {"resources": [dict]} (if UID is None)
 
-           **Output**
+        **Example**
 
-           .. important::
-                **returns**: metadata of pipeline(s)\n
-                **return type**: dict
-                dict (if UID is not None) or {"resources": [dict]} (if UID is None)\n
+        .. code-block:: python
 
-           .. note::
-                If UID is not specified, all pipelines metadata is fetched\n
-
-           **Example**
-
-            >>> pipeline_details = client.pipelines.get_details(pipeline_uid)
-            >>> pipeline_details = client.pipelines.get_details()
-            >>> pipeline_details = client.pipelines.get_details(limit=100)
-            >>> pipeline_details = client.pipelines.get_details(limit=100, get_all=True)
-            >>> pipeline_details = []
-            >>> for entry in client.pipelines.get_details(limit=100, asynchronous=True, get_all=True):
-            >>>    pipeline_details.extend(entry)
+            pipeline_details = client.pipelines.get_details(pipeline_uid)
+            pipeline_details = client.pipelines.get_details()
+            pipeline_details = client.pipelines.get_details(limit=100)
+            pipeline_details = client.pipelines.get_details(limit=100, get_all=True)
+            pipeline_details = []
+            for entry in client.pipelines.get_details(limit=100, asynchronous=True, get_all=True):
+                pipeline_details.extend(entry)
 
         """
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
 
-        pipeline_uid = str_type_conv(pipeline_uid)
-        Pipelines._validate_type(pipeline_uid, u'pipeline_uid', STR_TYPE, False)
+        Pipelines._validate_type(pipeline_uid, u'pipeline_uid', str, False)
         Pipelines._validate_type(limit, u'limit', int, False)
         if self._client.WSD:
             url = self._client.service_instance._href_definitions.get_model_definition_assets_href()
@@ -473,28 +458,28 @@ class Pipelines(WMLResource):
         else:
             return self._get_artifact_details(url, pipeline_uid, limit, 'pipeline',summary="False")
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_revision_details(self, pipeline_uid, rev_uid):
-        """
-            Get metadata of pipeline revision.
+        """Get metadata of pipeline revision.
 
-            :param pipeline_uid:  stored pipeline UID
-            :type pipeline_uid: {str_type}
+        :param pipeline_uid:  stored pipeline UID
+        :type pipeline_uid: str
 
-            :param rev_uid:  stored pipeline revision ID
-            :type rev_uid: {str_type}
+        :param rev_uid:  stored pipeline revision ID
+        :type rev_uid: str
 
-            :returns: stored pipeline revision metadata
-            :rtype: dict
+        :return: stored pipeline revision metadata
+        :rtype: dict
 
-            **Example:**
+        **Example:**
 
-                >>> pipeline_details = client.pipelines.get_revisions_details(pipeline_uid, rev_uid)
-            .. note::
-                In cloud platform, this method returns all the revision details of given pipeline_uid. rev_uid parameter is not applicable in Cloud platform.
+        .. code-block:: python
+
+            pipeline_details = client.pipelines.get_revision_details(pipeline_uid, rev_uid)
+
+        .. note::
+            `rev_uid` parameter is not applicable in Cloud platform.
          """
-        pipeline_uid = str_type_conv(pipeline_uid)
-        Pipelines._validate_type(pipeline_uid, u'pipeline_uid', STR_TYPE, True)
+        Pipelines._validate_type(pipeline_uid, u'pipeline_uid', str, True)
         Pipelines._validate_type(rev_uid, u'rev_uid', int, True)
         if not any([self._client.ICP_30, self._client.CLOUD_PLATFORM_SPACES, self._client.ICP_35, self._client.ICP_40,
                     self._client.ICP_45, self._client.ICP_46]):
@@ -506,27 +491,21 @@ class Pipelines(WMLResource):
                                                summary=None, pre_defined=None, revision=rev_uid)
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_href(pipeline_details):
-        """
-            Get hef from pipeline details.
+        """Get href from pipeline details.
 
-            **Parameters**
+        :param pipeline_details: metadata of the stored pipeline
+        :type pipeline_details: dict
 
-            .. important::
-                #. **pipeline_details**:  Metadata of the stored pipeline\n
-                   **type**: dict\n
+        :return: pipeline href
+        :rtype: str
 
-            **Output**
+        **Example**
 
-            .. important::
-                **returns**: pipeline href\n
-                **return type**: str
+        .. code-block:: python
 
-            **Example**
-
-             >>> pipeline_details = client.pipelines.get_details(pipeline_uid)
-             >>> pipeline_href = client.pipelines.ger_href(pipeline_details)
+            pipeline_details = client.pipelines.get_details(pipeline_uid)
+            pipeline_href = client.pipelines.get_href(pipeline_details)
 
         """
         Pipelines._validate_type(pipeline_details, u'pipeline_details', object, True)
@@ -545,23 +524,19 @@ class Pipelines(WMLResource):
 
     @staticmethod
     def get_uid(pipeline_details):
-        """
-            Get pipeline_uid from pipeline details.
+        """Get pipeline_uid from pipeline details.
 
-            **Parameters**
+        :param pipeline_details: metadata of the stored pipeline
+        :type pipeline_details: dict
 
-            .. important::
-                #. **pipeline_details**:  Metadata of the stored pipeline\n
-                   **type**: dict\n
+        :return: Unique Id of pipeline
+        :rtype: str
 
-            **Output**
+        **Example**
 
-            .. important::
-                **returns**: Unique Id of pipeline\n
-                **return type**: str
+        .. code-block:: python
 
-            **Example**
-             >>> pipeline_uid = client.pipelines.get_uid(pipeline_details)
+            pipeline_uid = client.pipelines.get_uid(pipeline_details)
 
         """
         Pipelines._validate_type(pipeline_details, u'pipeline_details', object, True)
@@ -576,23 +551,19 @@ class Pipelines(WMLResource):
 
     @staticmethod
     def get_id(pipeline_details):
-        """
-            Get pipeline_uid from pipeline details.
+        """Get pipeline id from pipeline details.
 
-            **Parameters**
+        :param pipeline_details: metadata of the stored pipeline
+        :type pipeline_details: dict
 
-            .. important::
-                #. **pipeline_details**:  Metadata of the stored pipeline\n
-                   **type**: dict\n
+        :return: Unique Id of pipeline
+        :rtype: str
 
-            **Output**
+        **Example**
 
-            .. important::
-                **returns**: Unique Id of pipeline\n
-                **return type**: str
+        .. code-block:: python
 
-            **Example**
-             >>> pipeline_uid = client.pipelines.get_id(pipeline_details)
+            pipeline_uid = client.pipelines.get_id(pipeline_details)
 
         """
         Pipelines._validate_type(pipeline_details, u'pipeline_details', object, True)
@@ -607,24 +578,17 @@ class Pipelines(WMLResource):
                                                                [u'metadata', u'id'])
 
     def list(self, limit=None):
-        """
-           List stored pipelines. If limit is set to None there will be only first 50 records shown.
+        """Print stored pipelines in a table format. If limit is set to None there will be only first 50 records shown.
 
-           **Parameters**
+        :param limit: limit number of fetched records
+        :type limit: int, optional
 
-           .. important::
-                #. **limit**:  limit number of fetched records\n
-                   **type**: int\n
+        **Example**
 
-           **Output**
+        .. code-block:: python
 
-           .. important::
-                This method only prints the list of all pipelines in a table format.\n
-                **return type**: None\n
+            client.pipelines.list()
 
-           **Example**
-
-            >>> client.pipelines.list()
         """
 
         if self._client.WSD:
@@ -645,29 +609,26 @@ class Pipelines(WMLResource):
 
                 self._list(pipeline_values, [u'GUID', u'NAME', u'CREATED'], limit, _DEFAULT_LIST_LENGTH)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def list_revisions(self, pipeline_uid, limit=None):
-        """
-           List all revision for the given pipeline uid.
+        """Print all revision for the given pipeline uid in a table format.
 
-           :param pipeline_uid: Unique id of stored pipeline.
-           :type pipeline_uid: {str_type}
+        :param pipeline_uid: Unique id of stored pipeline
+        :type pipeline_uid: str
 
-           :param limit: limit number of fetched records (optional)
-           :type limit: int
+        :param limit: limit number of fetched records
+        :type limit: int, optional
 
-           :returns: stored pipeline revisions details
-           :rtype: table
+        **Example**
 
-           **Example**
-                >>> pipeline_revision_details = client.pipelines.list_revisions(pipeline_uid)
+        .. code-block:: python
+
+            client.pipelines.list_revisions(pipeline_uid)
 
         """
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
-        model_uid = str_type_conv(pipeline_uid)
 
-        Pipelines._validate_type(pipeline_uid, u'pipeline_uid', STR_TYPE, True)
+        Pipelines._validate_type(pipeline_uid, u'pipeline_uid', str, True)
 
         if not any([self._client.ICP_30, self._client.CLOUD_PLATFORM_SPACES, self._client.ICP_35, self._client.ICP_40,
                     self._client.ICP_45, self._client.ICP_46]):
@@ -683,61 +644,44 @@ class Pipelines(WMLResource):
             self._list(pipeline_values, [u'GUID', u'NAME', u'CREATED'], limit, _DEFAULT_LIST_LENGTH)
 
     def clone(self, pipeline_uid, space_id=None, action="copy", rev_id=None):
-        """
-                Creates a new pipeline identical with the given pipeline either in the same space or in a new space. All dependent assets will be cloned too.
+        """Creates a new pipeline identical with the given pipeline either in the same space or in a new space.
+        All dependent assets will be cloned too.
 
-                **Parameters**
+        :param pipeline_uid: uid of the pipeline to be cloned
+        :type pipeline_uid: str
+        :param space_id: uid of the space to which the pipeline needs to be cloned
+        :type space_id: str, optional
+        :param action: action specifying "copy" or "move"
+        :type action: str, optional
+        :param rev_id: revision ID of the pipeline
+        :type rev_id: str, optional
 
-                .. important::
-                    #. **pipeline_uid**:  Guid of the pipeline to be cloned:\n
+        :return: metadata of the pipeline cloned
+        :rtype: dict
 
-                       **type**: str\n
+        **Example**
 
-                    #. **space_id**: Guid of the space to which the pipeline needs to be cloned. (optional)
+        .. code-block:: python
 
-                       **type**: str\n
+            client.pipelines.clone(pipeline_uid=artifact_id,space_id=space_uid,action="copy")
 
-                    #. **action**: Action specifying "copy" or "move". (optional)
+        .. note::
+            * If revision id is not specified, all revisions of the artifact are cloned.
 
-                       **type**: str\n
-
-                    #. **rev_id**: Revision ID of the pipeline. (optional)
-
-                       **type**: str\n
-
-                **Output**
-
-                .. important::
-
-                        **returns**: Metadata of the pipeline cloned.\n
-                        **return type**: dict\n
-
-                **Example**
-                 >>> client.pipelines.clone(pipeline_uid=artifact_id,space_id=space_uid,action="copy")
-
-                .. note::
-                    * If revision id is not specified, all revisions of the artifact are cloned\n
-
-                    * Default value of the parameter action is copy\n
-
-                    * Space id is mandatory for move action\n
+            * Space id is mandatory for "move" action.
 
         """
         if any([self._client.WSD, self._client.CLOUD_PLATFORM_SPACES, self._client.ICP_35, self._client.ICP_40,
                 self._client.ICP_45, self._client.ICP_46]):
             raise WMLClientError(" Clone pipeline operation is not supported. ")
-        artifact = str_type_conv(pipeline_uid)
-        Pipelines._validate_type(artifact, 'exp_id', STR_TYPE, True)
-        space = str_type_conv(space_id)
-        rev = str_type_conv(rev_id)
-        action = str_type_conv(action)
+        Pipelines._validate_type(pipeline_uid, 'exp_id', str, True)
         clone_meta = {}
-        if space is not None:
-            clone_meta["space"] = {"href": API_VERSION + SPACES + "/" + space}
+        if space_id is not None:
+            clone_meta["space"] = {"href": API_VERSION + SPACES + "/" + space_id}
         if action is not None:
             clone_meta["action"] = action
-        if rev is not None:
-            clone_meta["rev"] = rev
+        if rev_id is not None:
+            clone_meta["rev"] = rev_id
 
         url = self._client.service_instance._href_definitions.get_pipeline_href(pipeline_uid)
 
