@@ -14,7 +14,7 @@
 
 from __future__ import print_function
 import ibm_watson_machine_learning._wrappers.requests as requests
-from ibm_watson_machine_learning.utils import SPACES_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, MEMBER_DETAILS_TYPE,PKG_EXTN_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv, str_type_conv, get_file_from_cos
+from ibm_watson_machine_learning.utils import PKG_EXTN_DETAILS_TYPE
 from ibm_watson_machine_learning.metanames import PkgExtnMetaNames
 from ibm_watson_machine_learning.wml_resource import WMLResource
 from ibm_watson_machine_learning.wml_client_error import WMLClientError, ApiRequestFailure
@@ -24,10 +24,8 @@ _DEFAULT_LIST_LENGTH = 50
 
 
 class PkgExtn(WMLResource):
-    """
-    Store and manage your software Packages Extension specs.
+    """Store and manage your software Packages Extension specs."""
 
-    """
     ConfigurationMetaNames = PkgExtnMetaNames()
     """MetaNames for Package Extensions creation."""
 
@@ -35,30 +33,26 @@ class PkgExtn(WMLResource):
         WMLResource.__init__(self, __name__, client)
         self._ICP = client.ICP
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
-    def get_details(self, pkg_extn_uid):
+    def get_details(self, pkg_extn_id):
+        """Get package extensions details.
+
+        :param pkg_extn_id: Unique Id of package extension
+        :type pkg_extn_id: str
+
+        :return: details of the package extensions
+        :rtype: dict
+
+        **Example**
+
+        .. code-block:: python
+
+            pkg_extn_details = client.pkg_extn.get_details(pkg_extn_id)
+
         """
-            Get package extensions details.
+        PkgExtn._validate_type(pkg_extn_id, u'pkg_extn_id', str, True)
 
-            **Parameters**
-
-            .. important::
-                #. **pkg_extn_details**:  Metadata of the package extensions\n
-                   **type**: dict\n
-
-            **Output**
-
-            .. important::
-                **returns**: pkg_extn UID\n
-                **return type**: str
-
-            **Example**
-
-             >>> pkg_extn_details = client.pkg_extn.get_details(pkg_extn_uid)
-        """
-        PkgExtn._validate_type(pkg_extn_uid, u'pkg_extn_uid', STR_TYPE, True)
-
-        response = requests.get(self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_uid), params=self._client._params(),
+        response = requests.get(self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_id),
+                                params=self._client._params(),
                                 headers=self._client._get_headers())
 
         if response.status_code == 200:
@@ -66,37 +60,34 @@ class PkgExtn(WMLResource):
         else:
             return self._handle_response(200, u'get hw spec details', response)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def store(self, meta_props, file_path):
-        """
-                Create a package extensions.
+        """Create a package extensions.
 
-                **Parameters**
+        :param meta_props: meta data of the package extension. To see available meta names use:
 
-                .. important::
-                   #. **meta_props**:  meta data of the pacakge extension. To see available meta names use:\n
-                                    >>> client.package_extensions.ConfigurationMetaNames.get()
+            .. code-block:: python
 
-                      **type**: dict\n
+                client.package_extensions.ConfigurationMetaNames.get()
 
-                **Output**
+        :type meta_props: dict
 
-                .. important::
+        :param file_path:  path to file which will be uploaded as package extension
+        :type file_path: str
 
-                    **returns**: metadata of the package extensions\n
-                    **return type**: dict\n
+        :return: metadata of the package extensions
+        :rtype: dict
 
-                **Example**
+        **Example**
 
-                 >>> meta_props = {
-                 >>>    client.package_extensions.ConfigurationMetaNames.NAME: "skl_pipeline_heart_problem_prediction",
-                 >>>    client.package_extensions.ConfigurationMetaNames.DESCRIPTION: "description scikit-learn_0.20",
-                 >>>    client.package_extensions.ConfigurationMetaNames.TYPE: "conda_yml",
-                 >>> }
+        .. code-block:: python
 
-                **Example**
+            meta_props = {
+                client.package_extensions.ConfigurationMetaNames.NAME: "skl_pipeline_heart_problem_prediction",
+                client.package_extensions.ConfigurationMetaNames.DESCRIPTION: "description scikit-learn_0.20",
+                client.package_extensions.ConfigurationMetaNames.TYPE: "conda_yml"
+            }
 
-                 >>> pkg_extn_details = client.package_extensions.store(meta_props=meta_props,file_path="/path/to/file")
+            pkg_extn_details = client.package_extensions.store(meta_props=meta_props, file_path="/path/to/file")
 
         """
         WMLResource._chk_and_block_create_update_for_python36(self)
@@ -164,11 +155,19 @@ class PkgExtn(WMLResource):
 
             href = (self._client.service_instance._wml_credentials['url'] if self._client.ICP else "") + pkg_extn_presigned_url
 
-            with open(file_path, 'rb') as f:
+
+            # if pkg_extn_details["entity"]["package_extension"]["type"] in ["conda_yml", "pip_zip"]:
+            if not self._client.ICP:
                 put_response = requests.put(
                     href,
-                    files={'file': (file_path, f.read(), 'application/octet-stream')}
+                    data=read_in_chunks()
                 )
+            else:
+                with open(file_path, 'rb') as f:
+                    put_response = requests.put(
+                        href,
+                        files={'file': (file_path, f.read(), 'application/octet-stream')}
+                    )
 
             if put_response.status_code == 201 or put_response.status_code == 200:
                 # Step3: Mark the upload complete
@@ -191,18 +190,11 @@ class PkgExtn(WMLResource):
             raise WMLClientError("Failed while creating a package extensions " + creation_response.text)
 
     def list(self):
-        """
-           List package extensions.
+        """Print package extensions in a table format.
 
-           **Output**
+        .. code-block:: python
 
-           .. important::
-                This method only prints the list of all package extensionss in a table format.\n
-                **return type**: None\n
-
-           **Example**
-
-            >>> client.package_extensions.list()
+            client.package_extensions.list()
 
         """
 
@@ -222,29 +214,22 @@ class PkgExtn(WMLResource):
         self._list(pkg_extn_values, [u'NAME', u'ASSET_ID', u'TYPE', u'CREATED_AT'], None, _DEFAULT_LIST_LENGTH)
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_uid(pkg_extn_details):
-        """
-                Get Unique Id of package extensions. Deprecated!! use get_id(pkg_extn_details) instead
+        """Get Unique Id of package extensions.
 
-                **Parameters**
+        *Deprecated:* Use ``get_id(pkg_extn_details)`` instead.
 
-                .. important::
+        :param pkg_extn_details: details of the package extensions
+        :type pkg_extn_details: dict
 
-                   #. **asset_details**:  Metadata of the package extensions \n
-                      **type**: dict\n
+        :return: Unique Id of package extension
+        :rtype: str
 
-                **Output**
+        **Example**
 
-                .. important::
+        .. code-block:: python
 
-                    **returns**: Unique Id of package extension \n
-                    **return type**: str\n
-
-                **Example**
-
-
-                 >>> asset_uid = client.package_extensions.get_uid(pkg_extn_details)
+            asset_uid = client.package_extensions.get_uid(pkg_extn_details)
 
         """
         PkgExtn._validate_type(pkg_extn_details, u'pkg_extn_details', object, True)
@@ -255,59 +240,44 @@ class PkgExtn(WMLResource):
                                                            [u'metadata', u'asset_id'])
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_id(pkg_extn_details):
-        """
-                Get Unique Id of package extensions.
+        """Get Unique Id of package extensions.
 
-                **Parameters**
+        :param pkg_extn_details: details of the package extensions
+        :type pkg_extn_details: dict
 
-                .. important::
+        :return: Unique Id of package extension
+        :rtype: str
 
-                   #. **asset_details**:  Metadata of the package extensions \n
-                      **type**: dict\n
+        **Example**
 
-                **Output**
+        .. code-block:: python
 
-                .. important::
-
-                    **returns**: Unique Id of package extension \n
-                    **return type**: str\n
-
-                **Example**
-
-
-                 >>> asset_id = client.package_extensions.get_id(pkg_extn_details)
+            asset_id = client.package_extensions.get_id(pkg_extn_details)
 
         """
 
         return PkgExtn.get_uid(pkg_extn_details)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_uid_by_name(self, pkg_extn_name):
+        """Get UID of package extensions.
+
+        *Deprecated:* Use ``get_id_by_name(pkg_extn_name)`` instead.
+
+        :param pkg_extn_name: name of the package extension
+        :type pkg_extn_name: str
+
+        :return: Unique Id of package extension
+        :rtype: str
+
+        **Example**
+
+        .. code-block:: python
+
+            asset_uid = client.package_extensions.get_uid_by_name(pkg_extn_name)
+
         """
-                Get UID of package extensions. Deprecated!! Use get_id_by_name(pkg_extn_name) instead
-
-                **Parameters**
-
-                .. important::
-
-                   #. **asset_details**:  Metadata of the package extension\n
-                      **type**: dict\n
-
-                **Output**
-
-                .. important::
-
-                    **returns**: Unique Id of package extension \n
-                    **return type**: str\n
-
-                **Example**
-
-
-                 >>> asset_uid = client.package_extensions.get_uid_by_name(pkg_extn_name)
-        """
-        PkgExtn._validate_type(pkg_extn_name, u'pkg_extn_name', STR_TYPE, True)
+        PkgExtn._validate_type(pkg_extn_name, u'pkg_extn_name', str, True)
 
 
         parameters = self._client._params()
@@ -325,56 +295,41 @@ class PkgExtn(WMLResource):
             else:
                 return "Not Found"
 
-
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_id_by_name(self, pkg_extn_name):
-        """
-                Get ID of package extensions.
+        """Get ID of package extensions.
 
-                **Parameters**
+        :param pkg_extn_name:  name of the package extension
+        :type pkg_extn_name: str
 
-                .. important::
+        :return: Unique Id of package extension
+        :rtype: str
 
-                   #. **asset_details**:  Metadata of the package extension\n
-                      **type**: dict\n
+        **Example**
 
-                **Output**
+        .. code-block:: python
 
-                .. important::
+            asset_id = client.package_extensions.get_id_by_name(pkg_extn_name)
 
-                    **returns**: Unique Id of package extension \n
-                    **return type**: str\n
-
-                **Example**
-
-
-                 >>> asset_id = client.package_extensions.get_id_by_name(pkg_extn_name)
         """
         return PkgExtn.get_uid_by_name(self, pkg_extn_name)
 
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_href(pkg_extn_details):
-        """
-            Get url of stored package extensions.
+        """Get url of stored package extensions.
 
-           **Parameters**
+        :param pkg_extn_details: details of the package extensions
+        :type pkg_extn_details: dict
 
-           .. important::
-                #. **asset_details**:  package extensions details\n
-                   **type**: dict\n
+        :return: href of package extension
+        :rtype: str
 
-           **Output**
+        **Example**
 
-           .. important::
-                **returns**: href of package extensions details\n
-                **return type**: str\n
+        .. code-block:: python
 
-           **Example**
-
-             >>> pkg_extn_details = client.package_extensions.get_details(pkg_extn_uid)
-             >>> pkg_extn_href = client.package_extensions.get_href(pkg_extn_details)
+            pkg_extn_details = client.package_extensions.get_details(pkg_extn_uid)
+            pkg_extn_href = client.package_extensions.get_href(pkg_extn_details)
 
         """
         PkgExtn._validate_type(pkg_extn_details, u'pkg_extn_details', object, True)
@@ -384,42 +339,35 @@ class PkgExtn(WMLResource):
                                                            u'pkg_extn_details',
                                                            [u'entity', u'package_extension', u'href'])
 
+    def delete(self, pkg_extn_id):
+        """Delete a package extension.
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
-    def delete(self, pkg_extn_uid):
-        """
-            Delete a package extension.
+        :param pkg_extn_id: Unique Id of package extension
+        :type pkg_extn_id: str
 
-            **Parameters**
+        :return: status ("SUCCESS" or "FAILED")
+        :rtype: str
 
-            .. important::
-                #. **pkg_extn_uid**: Unique Id of package extension\n
-                   **type**: str\n
+        **Example**
 
-            **Output**
+        .. code-block:: python
 
-            .. important::
-                **returns**: status ("SUCCESS" or "FAILED")\n
-                **return type**: str\n
-
-            **Example**
-
-             >>> client.package_extensions.delete(pkg_extn_uid)
+            client.package_extensions.delete(pkg_extn_id)
 
         """
-        PkgExtn._validate_type(pkg_extn_uid, u'pkg_extn_uid', STR_TYPE, True)
+        PkgExtn._validate_type(pkg_extn_id, u'pkg_extn_uid', str, True)
 
-        response = requests.delete(self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_uid), params=self._client._params(),
-                                headers=self._client._get_headers())
+        response = requests.delete(self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_id),
+                                   params=self._client._params(),
+                                   headers=self._client._get_headers())
 
         if response.status_code == 200:
             return self._get_required_element_from_response(response.json())
         else:
             return self._handle_response(204, u'delete pkg extn specification', response)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def _delete(self, pkg_extn_uid):
-        PkgExtn._validate_type(pkg_extn_uid, u'pkg_extn_uid', STR_TYPE, True)
+        PkgExtn._validate_type(pkg_extn_uid, u'pkg_extn_uid', str, True)
 
         response = requests.delete(self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_uid), params=self._client._params(),
                                    headers=self._client._get_headers())
@@ -471,33 +419,27 @@ class PkgExtn(WMLResource):
         except Exception as e:
             raise WMLClientError("Failed to read Response from down-stream service: " + response_data.text)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def download(self, pkg_extn_id, filename):
+        """Download a package extension.
+
+        :param pkg_extn_id: Unique Id of the package extension to be downloaded
+        :type pkg_extn_id: str
+
+        :param filename:  filename to be used for the downloaded file
+        :type filename: str
+
+        :return: path to the downloaded package extension content
+        :rtype: str
+
+        **Example**
+
+        .. code-block:: python
+
+            client.package_extensions.download(pkg_extn_id,"sample_conda.yml/custom_library.zip")
+
         """
-            Download a package extension.
 
-            **Parameters**
-
-            .. important::
-                 #. **pkg_extn_uid**:  The Unique Id of the package extension to be downloaded\n
-                    **type**: str\n
-
-                 #. **filename**:  filename to be used for the downloaded file\n
-                    **type**: str\n
-
-            **Output**
-
-            .. important::
-                 **returns**: Path to the downloaded package extension content\n
-                 **return type**: str\n
-
-            **Example**
-
-             >>> client.assets.download(asset_uid,"sample_conda.yml/custom_library.zip")
-
-         """
-
-        PkgExtn._validate_type(pkg_extn_id, u'pkg_extn_id', STR_TYPE, True)
+        PkgExtn._validate_type(pkg_extn_id, u'pkg_extn_id', str, True)
 
         if self._WSD:
             import urllib
