@@ -14,7 +14,6 @@
 
 from __future__ import print_function
 import ibm_watson_machine_learning._wrappers.requests as requests
-from ibm_watson_machine_learning.utils import STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv
 from ibm_watson_machine_learning.metanames import RemoteTrainingSystemMetaNames
 from ibm_watson_machine_learning.party_wrapper import Party
 import os
@@ -23,46 +22,42 @@ from ibm_watson_machine_learning.wml_client_error import WMLClientError, Unexpec
 from ibm_watson_machine_learning.wml_resource import WMLResource
 _DEFAULT_LIST_LENGTH = 50
 
+
 class RemoteTrainingSystem(WMLResource):
-    """ 
-    The RemoteTrainingSystem class represents a Federated Learning party and provides a list of identities
+    """The RemoteTrainingSystem class represents a Federated Learning party and provides a list of identities
     that are permitted to join training as the RemoteTrainingSystem.
     """
+
     def __init__(self, client):
         WMLResource.__init__(self, __name__, client)
 
         self._client = client
         self.ConfigurationMetaNames = RemoteTrainingSystemMetaNames()
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def store(self, meta_props):
+        """Create a remote training system. Either `space_id` or `project_id` has to be provided.
+
+        :param meta_props:  metadata, to see available meta names use
+            ``client.remote_training_systems.ConfigurationMetaNames.get()``
+        :type meta_props: dict
+
+        :return: response json
+        :rtype: dict
+
+        **Example**
+
+        .. code-block:: python
+
+            metadata = {
+                client.remote_training_systems.ConfigurationMetaNames.NAME: "my-resource",
+                client.remote_training_systems.ConfigurationMetaNames.TAGS: ["tag1", "tag2"],
+                client.remote_training_systems.ConfigurationMetaNames.ORGANIZATION: {"name": "name", "region": "EU"}
+                client.remote_training_systems.ConfigurationMetaNames.ALLOWED_IDENTITIES: [{"id": "43689024", "type": "user"}],
+                client.remote_training_systems.ConfigurationMetaNames.REMOTE_ADMIN: {"id": "43689020", "type": "user"}
+            }
+            client.set.default_space('3fc54cf1-252f-424b-b52d-5cdd9814987f')
+            details = client.remote_training_systems.store(meta_props=metadata)
         """
-            Create a remote training system. Either space_id or project_id has to be provided.
-
-           **Parameters**
-
-           .. important::
-                #. **meta_props**:  meta data. To see available meta names use **client.remote_training_systems.ConfigurationMetaNames.get()\n
-                   **type**: str or dict\n
-
-           **Output**
-
-           .. important::
-                **returns**: Response json\n
-                **return type**: dict\n
-
-           **Example**
-
-                >>> metadata = {
-                >>>    client.remote_training_systems.ConfigurationMetaNames.NAME: "my-resource",
-                >>>    client.remote_training_systems.ConfigurationMetaNames.TAGS: ["tag1", "tag2"],
-                >>>    client.remote_training_systems.ConfigurationMetaNames.ORGANIZATION: {"name": "name", "region": "EU"}
-                >>>    client.remote_training_systems.ConfigurationMetaNames.ALLOWED_IDENTITIES: [{"id": "43689024", "type": "user"}],
-                >>>    client.remote_training_systems.ConfigurationMetaNames.REMOTE_ADMIN: {"id": "43689020", "type": "user"}
-                >>> }
-                >>> client.set.default_space('3fc54cf1-252f-424b-b52d-5cdd9814987f')
-                >>> details = client.remote_training_systems.store(meta_props=metadata)
-            """
 
         WMLResource._chk_and_block_create_update_for_python36(self)
         if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
@@ -110,33 +105,26 @@ class RemoteTrainingSystem(WMLResource):
                                  "client.remote_training_systems.ConfigurationMetaNames.ORGANIZATION: "
                                  "{'name': 'org'} ")
 
-
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def delete(self, remote_training_systems_id):
-        """
-            Deletes the given remote_training_systems_id definition. 'space_id' or 'project_id' has to be provided
+        """Deletes the given `remote_training_systems_id` definition. `space_id` or `project_id` has to be provided.
 
-            **Parameters**
+        :param remote_training_systems_id: remote training system identifier
+        :type remote_training_systems_id: str
 
-            .. important::
-                #. **remote_training_systems_id**:  Remote Training System identifier\n
-                   **type**: str\n
+        :return: status ("SUCCESS" or "FAILED")
+        :rtype: str
 
-            **Output**
+        **Example**
 
-            .. important::
-                **returns**: status ("SUCCESS" or "FAILED")\n
-                **return type**: str\n
+        .. code-block:: python
 
-            **Example**
-
-             >>> client.remote_training_systems.delete(remote_training_systems_id='6213cf1-252f-424b-b52d-5cdd9814956c')
+            client.remote_training_systems.delete(remote_training_systems_id='6213cf1-252f-424b-b52d-5cdd9814956c')
         """
         if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError("Not supported in this release")
 
         self._client._check_if_either_is_set()
-        RemoteTrainingSystem._validate_type(remote_training_systems_id, u'remote_training_systems_id', STR_TYPE, True)
+        RemoteTrainingSystem._validate_type(remote_training_systems_id, u'remote_training_systems_id', str, True)
 
         href = self._client.service_instance._href_definitions.remote_training_system_href(remote_training_systems_id)
 
@@ -151,48 +139,41 @@ class RemoteTrainingSystem(WMLResource):
         if "SUCCESS" == details:
             print("Remote training system deleted")
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_details(self, remote_training_system_id=None, limit=None, asynchronous=False, get_all=False):
+        """Get metadata of the given remote training system. If `remote_training_system_id` is not specified,
+            metadata is returned for all remote training systems.
+
+        :param remote_training_system_id: remote training system identifier
+        :type remote_training_system_id: str, optional
+        :param limit: limit number of fetched records
+        :type limit: int, optional
+        :param asynchronous: if `True`, it will work as a generator
+        :type asynchronous: bool, optional
+        :param get_all: if `True`, it will get all entries in 'limited' chunks
+        :type get_all: bool, optional
+
+        :return: remote training system(s) metadata
+        :rtype: dict (if remote_training_systems_id is not None) or {"resources": [dict]} (if remote_training_systems_id is None)
+
+
+        **Examples**
+
+        .. code-block:: python
+
+            details = client.remote_training_systems.get_details(remote_training_systems_id)
+            details = client.remote_training_systems.get_details()
+            details = client.remote_training_systems.get_details(limit=100)
+            details = client.remote_training_systems.get_details(limit=100, get_all=True)
+            details = []
+            for entry in client.remote_training_systems.get_details(limit=100, asynchronous=True, get_all=True):
+                details.extend(entry)
         """
-            Get metadata of the given Remote Training System. If remote_training_system_id is not specified,
-            metadata is returned for all Remote Training Systems.
-
-           **Parameters**
-
-           .. important::
-                #. **remote_training_system_id**: remote training system identifier (optional)\n
-                   **type**: str\n
-                #. **limit**:  limit number of fetched records (optional)\n
-                   **type**: int\n
-                #. **asynchronous**:  if True, it will work as a generator (optional)\n
-                   **type**: bool\n
-                #. **get_all**:  if True, it will get all entries in 'limited' chunks (optional)\n
-                   **type**: bool\n
-
-           **Output**
-
-           .. important::
-                **returns**: remote training system(s) metadata\n
-                **return type**: dict\n
-                dict (if remote_training_systems_id is not None) or {"resources": [dict]} (if remote_training_systems_id is None)\n
-
-
-           **Example**
-
-             >>> details = client.remote_training_systems.get_details(remote_training_systems_id)
-             >>> details = client.remote_training_systems.get_details()
-             >>> details = client.remote_training_systems.get_details(limit=100)
-             >>> details = client.remote_training_systems.get_details(limit=100, get_all=True)
-             >>> details = []
-             >>> for entry in client.remote_training_systems.get_details(limit=100, asynchronous=True, get_all=True):
-             >>>    details.extend(entry)
-         """
         if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError("Not supported in this release")
 
         self._client._check_if_either_is_set()
 
-        RemoteTrainingSystem._validate_type(remote_training_system_id, u'remote_training_systems_id', STR_TYPE, False)
+        RemoteTrainingSystem._validate_type(remote_training_system_id, u'remote_training_systems_id', str, False)
         RemoteTrainingSystem._validate_type(limit, u'limit', int, False)
 
         href = self._client.service_instance._href_definitions.remote_training_systems_href()
@@ -204,24 +185,17 @@ class RemoteTrainingSystem(WMLResource):
             return self._get_artifact_details(href, remote_training_system_id, limit, 'remote_training_systems')
 
     def list(self, limit=None):
-        """
-            List stored remote training systems. If limit is set to None, only the first 50 records are shown.
+        """Print stored remote training systems in a table format.
+        If limit is set to None, only the first 50 records are shown.
 
-           **Parameters**
+        :param limit: limit number of fetched records
+        :type limit: int
 
-           .. important::
-                #. **limit**:  limit number of fetched records\n
-                   **type**: int\n
+        **Example**
 
-           **Output**
+        .. code-block:: python
 
-           .. important::
-                This method only prints the list of all remote training systems in a table format.\n
-                **return type**: None\n
-
-           **Example**
-
-            >>> client.remote_training_systems.list()
+            client.remote_training_systems.list()
         """
         if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError("Not supported in this release")
@@ -237,29 +211,21 @@ class RemoteTrainingSystem(WMLResource):
         self._list(values, [u'ID', u'NAME', u'CREATED'], limit, _DEFAULT_LIST_LENGTH)
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_id(remote_training_system_details):
-        """
-                Get ID of remote_training_system
+        """Get ID of remote training system.
 
-                **Parameters**
+        :param remote_training_system_details: metadata of the stored remote training system
+        :type remote_training_system_details: dict
 
-                .. important::
+        :return: ID of stored remote training system
+        :rtype: str
 
-                   #. **remote_training_system_details**:  Metadata of the stored remote training system\n
-                      **type**: dict\n
+        **Example**
 
-                **Output**
+        .. code-block:: python
 
-                .. important::
-
-                    **returns**: ID of stored remote training system\n
-                    **return type**: str\n
-
-                **Example**
-
-                 >>> details = client.remote_training_systems.get_details(remote_training_system_id)
-                 >>> id = client.remote_training_systems.get_id(details)
+            details = client.remote_training_systems.get_details(remote_training_system_id)
+            id = client.remote_training_systems.get_id(details)
         """
         RemoteTrainingSystem._validate_type(remote_training_system_details, u'remote_training_system_details', object, True)
 
@@ -268,22 +234,24 @@ class RemoteTrainingSystem(WMLResource):
                                                            [u'metadata', u'id'])
 
     def update(self, remote_training_system_id, changes):
-        """
-        Updates existing remote training system metadata.
+        """Updates existing remote training system metadata.
 
-        **Parameters**
+        :param remote_training_system_id: remote training system identifier
+        :type remote_training_system_id: str
+        :param changes: elements which should be changed, where keys are ConfigurationMetaNames
+        :type changes: dict
 
-        .. important::
-           #. **remote_training_system_id**:  remote training system identifier\n
-              **type**: str\n
-           #. **changes**:  elements which should be changed, where keys are ConfigurationMetaNames\n
-              **type**: dict\n
+        :return: updated remote training system details
+        :rtype: dict
 
         **Example**
-         >>> metadata = {
-         >>> client.remote_training_systems.ConfigurationMetaNames.NAME:"updated_remote_training_system"
-         >>> }
-         >>> details = client.remote_training_systems.update(remote_training_system_id, changes=metadata)
+
+        .. code-block:: python
+
+            metadata = {
+                client.remote_training_systems.ConfigurationMetaNames.NAME:"updated_remote_training_system"
+            }
+            details = client.remote_training_systems.update(remote_training_system_id, changes=metadata)
 
         """
         WMLResource._chk_and_block_create_update_for_python36(self)
@@ -292,9 +260,8 @@ class RemoteTrainingSystem(WMLResource):
 
         self._client._check_if_either_is_set()
 
-        self._validate_type(remote_training_system_id, u'remote_training_system_id', STR_TYPE, True)
+        self._validate_type(remote_training_system_id, u'remote_training_system_id', str, True)
         self._validate_type(changes, u'changes', dict, True)
-        meta_props_str_conv(changes)
 
         details = self.get_details(remote_training_system_id)
 
@@ -312,77 +279,80 @@ class RemoteTrainingSystem(WMLResource):
 
         return updated_details
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def create_revision(self, remote_training_system_id):
-        """
-            Create a new remote training system revision.
+        """Create a new remote training system revision.
 
-            :param remote_training_system_id: Unique remote training system ID
-            :type remote_training_system_id: {str_type}
+        :param remote_training_system_id: Unique remote training system ID
+        :type remote_training_system_id: str
 
-            Example:
+        :return: remote training system details
+        :rtype: dict
 
-            >>> client.remote_training_systems.create_revision(remote_training_system_id)
+        **Example**
+
+        .. code_block:: python
+
+            client.remote_training_systems.create_revision(remote_training_system_id)
         """
         if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError("Not supported in this release")
 
-        RemoteTrainingSystem._validate_type(remote_training_system_id, u'remote_training_system_id', STR_TYPE, False)
+        RemoteTrainingSystem._validate_type(remote_training_system_id, u'remote_training_system_id', str, False)
 
         href = self._client.service_instance._href_definitions.remote_training_systems_href()
         return self._create_revision_artifact(href, remote_training_system_id, 'remote training system')
 
     def get_revision_details(self, remote_training_system_id, rev_id):
-        """
-           Get metadata from the specific revision of a stored remote system
+        """Get metadata from the specific revision of a stored remote system.
 
-           :param remote_training_system_id: stored functions, definition
-           :type remote_training_system_id: {str_type}
+        :param remote_training_system_id: UID of remote training system
+        :type remote_training_system_id: str
 
-           :param rev_id: Unique id of the remote system revision.
-           :type rev_id : int
+        :param rev_id: Unique id of the remote system revision
+        :type rev_id : int
 
-           :returns: stored remote system revision metadata
-           :rtype: dict
+        :return: stored remote system revision metadata
+        :rtype: dict
 
-           Example:
+        Example:
 
-           >>> details = client.remote_training_systems.get_details(remote_training_system_id, rev_id)
+        .. code-block:: python
+
+            details = client.remote_training_systems.get_details(remote_training_system_id, rev_id)
         """
         if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError("Not supported in this release")
 
         self._client._check_if_either_is_set()
 
-        RemoteTrainingSystem._validate_type(remote_training_system_id, u'remote_training_system_id', STR_TYPE, True)
+        RemoteTrainingSystem._validate_type(remote_training_system_id, u'remote_training_system_id', str, True)
         RemoteTrainingSystem._validate_type(rev_id, u'rev_id', int, True)
 
         href = self._client.service_instance._href_definitions.remote_training_system_href(remote_training_system_id)
         return self._get_with_or_without_limit(href, limit=None, op_name="remote_training_system_id",
                                                summary=None, pre_defined=None, revision=rev_id)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def list_revisions(self, remote_training_system_id, limit=None):
-        """
-           List all revisions for the given remote_training_system_id
+        """Print all revisions for the given remote_training_system_id in a table format.
 
-           :param remote_training_system_id: Unique id of stored remote system
-           :type remote_training_system_id: {str_type}
+        :param remote_training_system_id: Unique id of stored remote system
+        :type remote_training_system_id: str
 
-           :param limit: limit number of fetched records (optional)
-           :type limit: int
+        :param limit: limit number of fetched records
+        :type limit: int, optional
 
-           :returns: Summary list of all remote systems revisions
-           :rtype: table
+        **Example**
 
-           >>> details = client.remote_training_systems.list_revisions(remote_training_system_id)
+        .. code-block:: python
+
+            client.remote_training_systems.list_revisions(remote_training_system_id)
         """
         if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError("Not supported in this release")
 
         self._client._check_if_either_is_set()
 
-        RemoteTrainingSystem._validate_type(remote_training_system_id, u'remote_training_system_id', STR_TYPE, True)
+        RemoteTrainingSystem._validate_type(remote_training_system_id, u'remote_training_system_id', str, True)
 
         href = self._client.service_instance._href_definitions.get_function_href(remote_training_system_id)
 
@@ -404,59 +374,54 @@ class RemoteTrainingSystem(WMLResource):
             raise WMLClientError("Its mandatory to provide 'DATA_HANDLER' in meta_props. Example: "
                                  "client.remote_training_systems.ConfigurationMetaNames.DATA_HANDLER")
 
-
-
     def create_party(self, remote_training_system_id, party_metadata):
-        """
-        Creates a party object using the specified remote training system id and the party metadata.
+        """Creates a party object using the specified remote training system id and the party metadata.
 
-        **Parameters**
+        :param remote_training_system_id: remote training system identifier
+        :type remote_training_system_id: str
+        :param party_metadata: the party configuration
+        :type party_metadata: dict
 
-        .. important::
-           #. **remote_training_system_id**:  remote training system identifier\n
-              **type**: str\n
-           #. **party_metadata**:  the party configuration\n
-              **type**: dict\n
-
-        **Output**
-
-        .. important::
-
-            **returns**: A party object with the specified rts_id and configuration\n
-            **return type**: Party\n
+        :return: a party object with the specified rts_id and configuration
+        :rtype: Party
 
         **Examples**
-         >>> party_metadata = {
-         >>>     wml_client.remote_training_systems.ConfigurationMetaNames.DATA_HANDLER: {
-         >>>        "info": {
-         >>>            "npz_file": "./data_party0.npz"
-         >>>        },
-         >>>        "name": "MnistTFDataHandler",
-         >>>        "path": "./mnist_keras_data_handler.py"
-         >>>     },
-         >>>     wml_client.remote_training_systems.ConfigurationMetaNames.LOCAL_TRAINING: {
-         >>>        "name": "LocalTrainingHandler",
-         >>>        "path": "ibmfl.party.training.local_training_handler"
-         >>>     },
-         >>>     wml_client.remote_training_systems.ConfigurationMetaNames.HYPERPARAMS: {
-         >>>        "epochs": 3
-         >>>     },
-         >>> }
-         >>> party = client.remote_training_systems.create_party(remote_training_system_id, party_metadata)
-         >>> 
-         >>> party_metadata = {
-         >>>     wml_client.remote_training_systems.ConfigurationMetaNames.DATA_HANDLER: {
-         >>>        "info": {
-         >>>            "npz_file": "./data_party0.npz"
-         >>>        },
-         >>>        "class": MnistTFDataHandler
-         >>>     }
-         >>> }
-         >>> party = client.remote_training_systems.create_party(remote_training_system_id, party_metadata)
+
+        .. code-block:: python
+
+            party_metadata = {
+                wml_client.remote_training_systems.ConfigurationMetaNames.DATA_HANDLER: {
+                    "info": {
+                        "npz_file": "./data_party0.npz"
+                    },
+                    "name": "MnistTFDataHandler",
+                    "path": "./mnist_keras_data_handler.py"
+                },
+                wml_client.remote_training_systems.ConfigurationMetaNames.LOCAL_TRAINING: {
+                    "name": "LocalTrainingHandler",
+                    "path": "ibmfl.party.training.local_training_handler"
+                },
+                wml_client.remote_training_systems.ConfigurationMetaNames.HYPERPARAMS: {
+                    "epochs": 3
+                },
+            }
+            party = client.remote_training_systems.create_party(remote_training_system_id, party_metadata)
+
+        .. code-block:: python
+
+            party_metadata = {
+                wml_client.remote_training_systems.ConfigurationMetaNames.DATA_HANDLER: {
+                    "info": {
+                        "npz_file": "./data_party0.npz"
+                    },
+                    "class": MnistTFDataHandler
+                }
+            }
+            party = client.remote_training_systems.create_party(remote_training_system_id, party_metadata)
 
         """
 
-        RemoteTrainingSystem._validate_type(remote_training_system_id, u'remote_training_system_id', STR_TYPE, True)
+        RemoteTrainingSystem._validate_type(remote_training_system_id, u'remote_training_system_id', str, True)
         RemoteTrainingSystem._validate_type(party_metadata, u'party_metadata', dict, True)
         self._validate_party_input(party_metadata)
 
