@@ -17,7 +17,7 @@ import ibm_watson_machine_learning._wrappers.requests as requests
 requests.packages.urllib3.disable_warnings()
 import json
 import os
-from ibm_watson_machine_learning.utils import INSTANCE_DETAILS_TYPE, RUNTIME_SPEC_DETAILS_TYPE, MODEL_DETAILS_TYPE, LIBRARY_DETAILS_TYPE, FUNCTION_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, get_type_of_details, docstring_parameter, str_type_conv, print_text_header_h2, meta_props_str_conv
+from ibm_watson_machine_learning.utils import INSTANCE_DETAILS_TYPE, RUNTIME_SPEC_DETAILS_TYPE, MODEL_DETAILS_TYPE, LIBRARY_DETAILS_TYPE, FUNCTION_DETAILS_TYPE, get_type_of_details
 from ibm_watson_machine_learning.wml_client_error import WMLClientError
 from ibm_watson_machine_learning.href_definitions import is_uid
 from ibm_watson_machine_learning.wml_resource import WMLResource
@@ -27,18 +27,17 @@ from ibm_watson_machine_learning.libs.repo.mlrepository import MetaProps, MetaNa
 from ibm_watson_machine_learning.href_definitions import API_VERSION, SPACES,PIPELINES, LIBRARIES, EXPERIMENTS, RUNTIMES, DEPLOYMENTS
 
 
-
 def LibraryDefinition(name, version, filepath, description=None, platform=None, model_definition=None, custom=None, command=None, tags=None, space_uid=None):
-    WMLResource._validate_type(name, 'name', STR_TYPE, True)
-    WMLResource._validate_type(version, 'version', STR_TYPE, True)
+    WMLResource._validate_type(name, 'name', str, True)
+    WMLResource._validate_type(version, 'version', str, True)
     WMLResource._validate_type(platform, 'platform', dict, False)
-    WMLResource._validate_type(description, 'description', STR_TYPE, False)
-    WMLResource._validate_type(filepath, 'filepath', STR_TYPE, True)
+    WMLResource._validate_type(description, 'description', str, False)
+    WMLResource._validate_type(filepath, 'filepath', str, True)
     WMLResource._validate_type(model_definition, 'model_definition', bool, False)
     WMLResource._validate_type(custom, 'custom', dict, False)
-    WMLResource._validate_type(command, 'command', STR_TYPE, False)
+    WMLResource._validate_type(command, 'command', str, False)
     WMLResource._validate_type(tags, 'tags', dict, False)
-    WMLResource._validate_type(space_uid, 'space_uid', STR_TYPE, False)
+    WMLResource._validate_type(space_uid, 'space_uid', str, False)
 
     definition = {
         'name': name,
@@ -82,16 +81,16 @@ class Runtimes(WMLResource):
         self._ICP = client.ICP
 
     def _create_library_from_definition(self, definition, runtime_definition):
-        self._validate_meta_prop(definition, 'name', STR_TYPE, True)
-        self._validate_meta_prop(definition, 'version', STR_TYPE, True)
+        self._validate_meta_prop(definition, 'name', str, True)
+        self._validate_meta_prop(definition, 'version', str, True)
         self._validate_meta_prop(definition, 'platform', dict, False)
-        self._validate_meta_prop(definition, 'description', STR_TYPE, False)
-        self._validate_meta_prop(definition, 'filepath', STR_TYPE, True)
+        self._validate_meta_prop(definition, 'description', str, False)
+        self._validate_meta_prop(definition, 'filepath', str, True)
         self._validate_meta_prop(definition, 'model_defintion', bool, False)
         self._validate_meta_prop(definition, 'custom', dict, False)
-        self._validate_meta_prop(definition, 'command', STR_TYPE, False)
+        self._validate_meta_prop(definition, 'command', str, False)
         self._validate_meta_prop(definition, 'tags', dict, False)
-        self._validate_meta_prop(definition, 'space_uid', STR_TYPE, False)
+        self._validate_meta_prop(definition, 'space_uid', str, False)
 
         lib_metadata = {
             self.LibraryMetaNames.NAME: definition['name'],
@@ -250,8 +249,6 @@ class Runtimes(WMLResource):
             raise WMLClientError('Failure during creation of runtime.', e)
         return details['metadata']['guid']
 
-
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def store(self, meta_props):
         """
                Create a runtime.\n
@@ -322,7 +319,6 @@ class Runtimes(WMLResource):
 
         return self.get_details(runtime_uid)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_details(self, runtime_uid=None,pre_defined=False, limit=None):
         """
            Get metadata of stored runtime(s). If runtime UID is not specified returns all runtimes metadata.
@@ -357,8 +353,7 @@ class Runtimes(WMLResource):
         if self._client.ICP_30:
             print("WARNING!! 'runtimes' is DEPRECATED. Use 'software_specifications' instead to create and manage runtimes/specifications" )
 
-        runtime_uid = str_type_conv(runtime_uid)
-        Runtimes._validate_type(runtime_uid, u'runtime_uid', STR_TYPE, False)
+        Runtimes._validate_type(runtime_uid, u'runtime_uid', str, False)
 
         # if runtime_uid is not None and not is_uid(runtime_uid):
         #     raise WMLClientError(u'\'runtime_uid\' is not an uid: \'{}\''.format(runtime_uid))
@@ -403,8 +398,7 @@ class Runtimes(WMLResource):
         if self._client.ICP_30:
             print("WARNING!! 'runtimes' is DEPRECATED. Use 'software_specifications' instead to create and manage runtimes/specifications" )
 
-        library_uid = str_type_conv(library_uid)
-        Runtimes._validate_type(library_uid, u'library_uid', STR_TYPE, False)
+        Runtimes._validate_type(library_uid, u'library_uid', str, False)
 
         if library_uid is not None and not is_uid(library_uid):
             raise WMLClientError(u'\'library_uid\' is not an uid: \'{}\''.format(library_uid))
@@ -415,7 +409,6 @@ class Runtimes(WMLResource):
         return self._get_artifact_details(url, library_uid, limit, 'libraries')
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_href(details):
         """
             Get runtime_href from runtime details.
@@ -453,7 +446,6 @@ class Runtimes(WMLResource):
             raise WMLClientError('Unexpected details type: {}'.format(details_type))
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_uid(details):
         """
             Get runtime_uid from runtime details.
@@ -491,7 +483,6 @@ class Runtimes(WMLResource):
             raise WMLClientError('Unexpected details type: {}'.format(details_type))
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_library_href(library_details):
         """
             Get library_href from library details.
@@ -520,7 +511,6 @@ class Runtimes(WMLResource):
         return Runtimes._get_required_element_from_dict(library_details, 'library_details', ['metadata', 'href'])
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_library_uid(library_details):
         """
             Get library_uid from library details.
@@ -566,7 +556,6 @@ class Runtimes(WMLResource):
             )
         ))
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def delete(self, runtime_uid, with_libraries=False):
         """
             Delete a runtime.
@@ -594,8 +583,7 @@ class Runtimes(WMLResource):
         if self._client.ICP_30:
             print("WARNING!! 'runtimes' is DEPRECATED. Use 'software_specifications' instead to create and manage runtimes/specifications" )
 
-        runtime_uid = str_type_conv(runtime_uid)
-        Runtimes._validate_type(runtime_uid, u'runtime_uid', STR_TYPE, True)
+        Runtimes._validate_type(runtime_uid, u'runtime_uid', str, True)
         Runtimes._validate_type(with_libraries, u'autoremove', bool, True)
 
         if runtime_uid is not None and not is_uid(runtime_uid):
@@ -626,8 +614,6 @@ class Runtimes(WMLResource):
                     print(delete_status)
         return self._handle_response(204, u'runtime deletion', response_delete, False)
 
-
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def _delete_orphaned_libraries(self):
         """
             Delete all custom libraries without runtime.
@@ -651,8 +637,6 @@ class Runtimes(WMLResource):
                 except:
                     pass
 
-
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def delete_library(self, library_uid):
         """
             Delete a library.
@@ -677,7 +661,7 @@ class Runtimes(WMLResource):
         if self._client.ICP_30:
             print("WARNING!! 'runtimes' is DEPRECATED. Use 'software_specifications' instead to create and manage runtimes/specifications" )
 
-        Runtimes._validate_type(library_uid, u'library_uid', STR_TYPE, True)
+        Runtimes._validate_type(library_uid, u'library_uid', str, True)
         library_endpoint = self._client.service_instance._href_definitions.get_custom_library_href(library_uid)
 
         response_delete = requests.delete(library_endpoint, headers=self._client._get_headers())
@@ -771,8 +755,7 @@ class Runtimes(WMLResource):
         if self._client.ICP_30:
             print("WARNING!! 'runtimes' is DEPRECATED. Use 'software_specifications' instead to create and manage runtimes/specifications" )
 
-        runtime_uid = str_type_conv(runtime_uid)
-        Runtimes._validate_type(runtime_uid, u'runtime_uid', STR_TYPE, False)
+        Runtimes._validate_type(runtime_uid, u'runtime_uid', str, False)
 
         if runtime_uid is None:
             details = self.get_library_details()
@@ -835,8 +818,7 @@ class Runtimes(WMLResource):
         if self._client.ICP_30:
             print("WARNING!! 'runtimes' is DEPRECATED. Use 'software_specifications' instead to create and manage runtimes/specifications" )
 
-        runtime_uid = str_type_conv(runtime_uid)
-        Runtimes._validate_type(runtime_uid, u'runtime_uid', STR_TYPE, True)
+        Runtimes._validate_type(runtime_uid, u'runtime_uid', str, True)
 
         if not is_uid(runtime_uid):
             raise WMLClientError(u'\'runtime_uid\' is not an uid: \'{}\''.format(runtime_uid))
@@ -897,8 +879,7 @@ class Runtimes(WMLResource):
         if self._client.ICP_30:
             print("WARNING!! 'runtimes' is DEPRECATED. Use 'software_specifications' instead to create and manage runtimes/specifications" )
 
-        library_uid = str_type_conv(library_uid)
-        Runtimes._validate_type(library_uid, u'library_uid', STR_TYPE, True)
+        Runtimes._validate_type(library_uid, u'library_uid', str, True)
 
         if not is_uid(library_uid):
             raise WMLClientError(u'\'library_uid\' is not an uid: \'{}\''.format(library_uid))
@@ -953,10 +934,8 @@ class Runtimes(WMLResource):
         if self._client.ICP_30:
             print("WARNING!! 'runtimes' is DEPRECATED. Use 'software_specifications' instead to create and manage runtimes/specifications" )
 
-        library_uid = str_type_conv(library_uid)
-        self._validate_type(library_uid, u'library_uid', STR_TYPE, True)
+        self._validate_type(library_uid, u'library_uid', str, True)
         self._validate_type(changes, u'changes', dict, True)
-        meta_props_str_conv(changes)
 
         details = self.get_library_details(library_uid)
 
@@ -1000,10 +979,8 @@ class Runtimes(WMLResource):
         if self._client.ICP_30:
             print("WARNING!! 'runtimes' is DEPRECATED. Use 'software_specifications' instead to create and manage runtimes/specifications" )
 
-        library_uid = str_type_conv(runtime_uid)
-        self._validate_type(library_uid, u'runtime_uid', STR_TYPE, True)
+        self._validate_type(runtime_uid, u'runtime_uid', str, True)
         self._validate_type(changes, u'changes', dict, True)
-        meta_props_str_conv(changes)
 
         details = self.get_details(runtime_uid)
 
@@ -1061,18 +1038,14 @@ class Runtimes(WMLResource):
         if self._client.ICP_30:
             print("WARNING!! 'runtimes' is DEPRECATED. Use 'software_specifications' instead to create and manage runtimes/specifications" )
 
-        artifact = str_type_conv(runtime_uid)
-        Runtimes._validate_type(artifact, 'runtime_uid', STR_TYPE, True)
-        space = str_type_conv(space_id)
-        rev = str_type_conv(rev_id)
-        action = str_type_conv(action)
+        Runtimes._validate_type(runtime_uid, 'runtime_uid', str, True)
         clone_meta = {}
-        if space is not None:
-            clone_meta["space"] = {"href": API_VERSION + SPACES + "/" + space}
+        if space_id is not None:
+            clone_meta["space"] = {"href": API_VERSION + SPACES + "/" + space_id}
         if action is not None:
             clone_meta["action"] = action
-        if rev is not None:
-            clone_meta["rev"] = rev
+        if rev_id is not None:
+            clone_meta["rev"] = rev_id
 
         url = self._client.service_instance._href_definitions.get_runtime_href(runtime_uid)
 
@@ -1083,6 +1056,7 @@ class Runtimes(WMLResource):
                                             response=response_post)
 
         return details
+
     def clone_library(self, library_uid, space_id=None, action="copy", rev_id=None):
         """
                 Creates a new function library with the given library either in the same space or in a new space. All dependent assets will be cloned too.
@@ -1127,18 +1101,14 @@ class Runtimes(WMLResource):
         if self._client.ICP_30:
             print("WARNING!! 'runtimes' is DEPRECATED. Use 'software_specifications' instead to create and manage runtimes/specifications" )
 
-        artifact = str_type_conv(library_uid)
-        Runtimes._validate_type(artifact, 'library_uid', STR_TYPE, True)
-        space = str_type_conv(space_id)
-        rev = str_type_conv(rev_id)
-        action = str_type_conv(action)
+        Runtimes._validate_type(library_uid, 'library_uid', str, True)
         clone_meta = {}
-        if space is not None:
-            clone_meta["space"] = {"href": API_VERSION + SPACES + "/" + space}
+        if space_id is not None:
+            clone_meta["space"] = {"href": API_VERSION + SPACES + "/" + space_id}
         if action is not None:
             clone_meta["action"] = action
-        if rev is not None:
-            clone_meta["rev"] = rev
+        if rev_id is not None:
+            clone_meta["rev"] = rev_id
 
         url = self._client.service_instance._href_definitions.get_custom_library_href(library_uid)
 
