@@ -14,7 +14,7 @@
 
 from __future__ import print_function
 import ibm_watson_machine_learning._wrappers.requests as requests
-from ibm_watson_machine_learning.utils import SPACES_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, MEMBER_DETAILS_TYPE,DATA_ASSETS_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv, str_type_conv, get_file_from_cos, modify_details_for_script_and_shiny
+from ibm_watson_machine_learning.utils import DATA_ASSETS_DETAILS_TYPE, modify_details_for_script_and_shiny
 from ibm_watson_machine_learning.metanames import ScriptMetaNames
 from ibm_watson_machine_learning.wml_resource import WMLResource
 from ibm_watson_machine_learning.wml_client_error import WMLClientError, ApiRequestFailure, ForbiddenActionForGitBasedProject
@@ -36,7 +36,6 @@ class Script(WMLResource):
         WMLResource.__init__(self, __name__, client)
         self._ICP = client.ICP
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_details(self, script_uid=None):
         """
             Get script asset details. If no script_uid is passed, details for all script assets will be returned.
@@ -79,7 +78,6 @@ class Script(WMLResource):
 
         return self._get_asset_based_resource(script_uid, 'script', get_required_elements)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def store(self, meta_props, file_path):
         """
                 Creates a Scripts asset and uploads content to it.
@@ -481,7 +479,6 @@ class Script(WMLResource):
 
         self._list(space_values, [u'NAME', u'ASSET_TYPE', u'ASSET_ID'], None, _DEFAULT_LIST_LENGTH)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def download(self, asset_uid, filename, rev_uid=None):
         """
             Download the content of a script asset.
@@ -513,7 +510,7 @@ class Script(WMLResource):
         if rev_uid is not None and self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(u'Not applicable for this release')
 
-        Script._validate_type(asset_uid, u'asset_uid', STR_TYPE, True)
+        Script._validate_type(asset_uid, u'asset_uid', str, True)
         Script._validate_type(rev_uid, u'rev_uid', int, False)
 
         params = self._client._params()
@@ -580,7 +577,6 @@ class Script(WMLResource):
                 raise WMLClientError("Failed while downloading the asset " + asset_uid)
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_id(asset_details):
         """
                 Get Unique Id of stored script asset.
@@ -607,7 +603,6 @@ class Script(WMLResource):
         return Script.get_uid(asset_details)
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_uid(asset_details):
         """
                 Get Unique Id  of stored script asset. This method is deprecated. Use 'get_id(asset_details)' instead
@@ -638,7 +633,6 @@ class Script(WMLResource):
 
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_href(asset_details):
         """
             Get url of stored scripts asset.
@@ -666,7 +660,6 @@ class Script(WMLResource):
 
         return WMLResource._get_required_element_from_dict(asset_details, u'asset_details', [u'metadata', u'href'])
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def update(self, script_uid, meta_props=None, file_path=None):
         """
         Update script with either metadata or attachment or both.
@@ -694,7 +687,7 @@ class Script(WMLResource):
         if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(u'Not supported in this release')
 
-        Script._validate_type(script_uid, 'script_uid', STR_TYPE, True)
+        Script._validate_type(script_uid, 'script_uid', str, True)
 
         if meta_props is None and file_path is None:
             raise WMLClientError('Atleast either meta_props or file_path has to be provided')
@@ -739,7 +732,6 @@ class Script(WMLResource):
         # Patch meta if provided
         if meta_props is not None:
             self._validate_type(meta_props, u'meta_props', dict, True)
-            meta_props_str_conv(meta_props)
 
             meta_patch_payload = []
             entity_patch_payload = []
@@ -847,7 +839,6 @@ class Script(WMLResource):
         else:
             raise WMLClientError('Unable to update attachment because of server error. Try again later')
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def delete(self, asset_uid):
         """
             Delete a stored script asset.
@@ -869,7 +860,7 @@ class Script(WMLResource):
              >>> client.script.delete(asset_uid)
 
         """
-        Script._validate_type(asset_uid, u'asset_uid', STR_TYPE, True)
+        Script._validate_type(asset_uid, u'asset_uid', str, True)
         if (self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES) and \
                 self._if_deployment_exist_for_asset(asset_uid):
             raise WMLClientError(
@@ -883,8 +874,6 @@ class Script(WMLResource):
         else:
             return self._handle_response(204, u'delete assets', response)
 
-
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def create_revision(self, script_uid):
         """
         Creates revision for the given script. Revisions are immutable once created.
@@ -914,8 +903,7 @@ class Script(WMLResource):
 
         ##For CP4D, check if either space or project ID is set
         self._client._check_if_either_is_set()
-        script_uid = str_type_conv(script_uid)
-        Script._validate_type(script_uid, u'script_uid', STR_TYPE, True)
+        Script._validate_type(script_uid, u'script_uid', str, True)
 
         print("Creating script revision...")
 
@@ -942,7 +930,6 @@ class Script(WMLResource):
 
             return final_response
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def list_revisions(self, script_uid, limit=None):
         """
         List all revisions for the given script uid.
@@ -973,8 +960,7 @@ class Script(WMLResource):
         ##For CP4D, check if either space or project ID is set
         self._client._check_if_either_is_set()
 
-        script_uid = str_type_conv(script_uid)
-        Script._validate_type(script_uid, u'script_uid', STR_TYPE, True)
+        Script._validate_type(script_uid, u'script_uid', str, True)
 
         url = self._client.service_instance._href_definitions.get_asset_href(script_uid) + "/revisions"
         # /v2/assets/{asset_id}/revisions returns 'results' object
@@ -992,7 +978,6 @@ class Script(WMLResource):
 
         self._list(script_values, [u'GUID', u'REVISION_ID', u'NAME', u'REVISION_COMMIT'], limit, _DEFAULT_LIST_LENGTH)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_revision_details(self, script_uid=None, rev_uid=None):
         """
         Get metadata of script_uid revision.
@@ -1024,8 +1009,7 @@ class Script(WMLResource):
         ##For CP4D, check if either space or project ID is set
         self._client._check_if_either_is_set()
 
-        script_uid = str_type_conv(script_uid)
-        Script._validate_type(script_uid, u'script_uid', STR_TYPE, True)
+        Script._validate_type(script_uid, u'script_uid', str, True)
         Script._validate_type(rev_uid, u'rev_uid', int, False)
 
         if rev_uid is None:
@@ -1065,9 +1049,8 @@ class Script(WMLResource):
 
             return final_responses
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def _delete(self, asset_uid):
-        Script._validate_type(asset_uid, u'asset_uid', STR_TYPE, True)
+        Script._validate_type(asset_uid, u'asset_uid', str, True)
 
         response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
                                    headers=self._client._get_headers())
