@@ -14,7 +14,7 @@
 
 from __future__ import print_function
 import ibm_watson_machine_learning._wrappers.requests as requests
-from ibm_watson_machine_learning.utils import SPACES_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, MEMBER_DETAILS_TYPE,DATA_ASSETS_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv, str_type_conv, get_file_from_cos, modify_details_for_script_and_shiny
+from ibm_watson_machine_learning.utils import DATA_ASSETS_DETAILS_TYPE, modify_details_for_script_and_shiny
 from ibm_watson_machine_learning.metanames import ShinyMetaNames
 from ibm_watson_machine_learning.wml_resource import WMLResource
 from ibm_watson_machine_learning.wml_client_error import WMLClientError, ApiRequestFailure, ForbiddenActionForGitBasedProject
@@ -36,7 +36,6 @@ class Shiny(WMLResource):
         WMLResource.__init__(self, __name__, client)
         self._ICP = client.ICP
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_details(self, shiny_uid=None):
         """
             Get shiny asset details. If no shiny_uid is passed, details for all shiny assets will be returned.
@@ -72,7 +71,6 @@ class Shiny(WMLResource):
 
         return self._get_asset_based_resource(shiny_uid, 'shiny_asset', get_required_elements)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def store(self, meta_props, file_path):
         """
                 Creates a shiny asset and uploads content to it.
@@ -350,7 +348,6 @@ class Shiny(WMLResource):
 
         self._list(space_values, [u'NAME', u'ASSET_TYPE', u'ASSET_ID'], None, _DEFAULT_LIST_LENGTH)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def download(self, shiny_uid, filename, rev_uid=None):
         """
             Download the content of a shiny asset.
@@ -379,7 +376,7 @@ class Shiny(WMLResource):
         if rev_uid is not None and self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(u'Not applicable for this release')
 
-        Shiny._validate_type(shiny_uid, u'shiny_uid', STR_TYPE, True)
+        Shiny._validate_type(shiny_uid, u'shiny_uid', str, True)
         Shiny._validate_type(rev_uid, u'rev_uid', int, False)
 
         params = self._client._params()
@@ -440,7 +437,6 @@ class Shiny(WMLResource):
                 raise WMLClientError("Failed while downloading the shiny asset " + shiny_uid)
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_id(shiny_details):
         """
                 Get Unique Id of stored shiny asset.
@@ -469,7 +465,6 @@ class Shiny(WMLResource):
         return Shiny.get_uid(shiny_details)
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_uid(shiny_details):
         """
                 Get Unique Id  of stored shiny asset. This method is deprecated. Use 'get_id(shiny_details)' instead
@@ -502,7 +497,6 @@ class Shiny(WMLResource):
 
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_href(shiny_details):
         """
             Get url of stored shiny asset.
@@ -547,7 +541,7 @@ class Shiny(WMLResource):
         if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(u'Not supported in this release')
 
-        Shiny._validate_type(shiny_uid, 'shiny_uid', STR_TYPE, True)
+        Shiny._validate_type(shiny_uid, 'shiny_uid', str, True)
 
         if meta_props is None and file_path is None:
             raise WMLClientError('Atleast either meta_props or file_path has to be provided')
@@ -591,7 +585,6 @@ class Shiny(WMLResource):
         # Patch meta if provided
         if meta_props is not None:
             self._validate_type(meta_props, u'meta_props', dict, True)
-            meta_props_str_conv(meta_props)
 
             meta_patch_payload = []
 
@@ -670,8 +663,6 @@ class Shiny(WMLResource):
         else:
             raise WMLClientError('Unable to update attachment because of server error. Try again later')
 
-
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def delete(self, shiny_uid):
         """
             Delete a stored shiny asset.
@@ -693,7 +684,7 @@ class Shiny(WMLResource):
              >>> client.shiny.delete(shiny_uid)
 
         """
-        Shiny._validate_type(shiny_uid, u'shiny_uid', STR_TYPE, True)
+        Shiny._validate_type(shiny_uid, u'shiny_uid', str, True)
         if (self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES) and \
                 self._if_deployment_exist_for_asset(shiny_uid):
             raise WMLClientError(
@@ -707,14 +698,13 @@ class Shiny(WMLResource):
         else:
             return self._handle_response(204, u'delete assets', response)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def create_revision(self, shiny_uid):
         """
            Creates revision for the given Shiny asset. Revisions are immutable once created.
            The metadata and attachment at script_uid is taken and a revision is created out of it
 
            :param shiny_uid: Shiny asset ID. Mandatory
-           :type shiny_uid: {str_type}
+           :type shiny_uid: str
 
            :returns: stored shiny asset revisions metadata
            :rtype: dict
@@ -728,8 +718,7 @@ class Shiny(WMLResource):
         ##For CP4D, check if either space or project ID is set
         self._client._check_if_either_is_set()
 
-        shiny_uid = str_type_conv(shiny_uid)
-        Shiny._validate_type(shiny_uid, u'shiny_uid', STR_TYPE, True)
+        Shiny._validate_type(shiny_uid, u'shiny_uid', str, True)
 
         print("Creating shiny revision...")
         #
@@ -749,13 +738,12 @@ class Shiny(WMLResource):
 
             return final_response
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def list_revisions(self, shiny_uid, limit=None):
         """
            List all revisions for the given shiny asset uid.
 
            :param shiny_uid: Stored shiny asset ID.
-           :type shiny_uid: {str_type}
+           :type shiny_uid: str
 
            :param limit: limit number of fetched records (optional)
            :type limit: int
@@ -772,8 +760,7 @@ class Shiny(WMLResource):
         ##For CP4D, check if either space or project ID is set
         self._client._check_if_either_is_set()
 
-        shiny_uid = str_type_conv(shiny_uid)
-        Shiny._validate_type(shiny_uid, u'shiny_uid', STR_TYPE, True)
+        Shiny._validate_type(shiny_uid, u'shiny_uid', str, True)
 
         url = self._client.service_instance._href_definitions.get_asset_href(shiny_uid) + "/revisions"
         # /v2/assets/{asset_id}/revisions returns 'results' object
@@ -796,7 +783,7 @@ class Shiny(WMLResource):
            Get metadata of shiny_uid revision.
 
            :param script_uid: Shiny asset ID. Mandatory
-           :type script_uid: {str_type}
+           :type script_uid: str
 
            :param rev_uid: Revision ID. If this parameter is not provided, returns latest revision if existing else error
            :type rev_uid: int
@@ -814,8 +801,7 @@ class Shiny(WMLResource):
         ##For CP4D, check if either space or project ID is set
         self._client._check_if_either_is_set()
 
-        shiny_uid = str_type_conv(shiny_uid)
-        Shiny._validate_type(shiny_uid, u'shiny_uid', STR_TYPE, True)
+        Shiny._validate_type(shiny_uid, u'shiny_uid', str, True)
         Shiny._validate_type(rev_uid, u'rev_uid', int, False)
 
         if rev_uid is None:
@@ -846,15 +832,12 @@ class Shiny(WMLResource):
 
             return final_responses
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def _delete(self, shiny_uid):
-        Shiny._validate_type(shiny_uid, u'shiny_uid', STR_TYPE, True)
+        Shiny._validate_type(shiny_uid, u'shiny_uid', str, True)
 
         response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(shiny_uid), params=self._client._params(),
                                    headers=self._client._get_headers())
 
-
-    # @docstring_parameter({'str_type': STR_TYPE_NAME})
     # def get_href(self, shiny_uid):
     #     """
     #        Get metadata of stored space(s). If space UID is not specified, it returns all the spaces metadata.
@@ -884,7 +867,7 @@ class Shiny(WMLResource):
     #     """
     #
     #
-    #     Assets._validate_type(shiny_uid, u'shiny_uid', STR_TYPE, True)
+    #     Assets._validate_type(shiny_uid, u'shiny_uid', str, True)
     #
     #     response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(shiny_uid), params=self._client._params(),
     #                             headers=self._client._get_headers())
