@@ -14,7 +14,7 @@
 
 from __future__ import print_function
 import ibm_watson_machine_learning._wrappers.requests as requests
-from ibm_watson_machine_learning.utils import SPACES_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, MEMBER_DETAILS_TYPE,SW_SPEC_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv, str_type_conv, get_file_from_cos
+from ibm_watson_machine_learning.utils import SW_SPEC_DETAILS_TYPE
 from ibm_watson_machine_learning.metanames import SwSpecMetaNames
 from ibm_watson_machine_learning.wml_resource import WMLResource
 from ibm_watson_machine_learning.wml_client_error import WMLClientError, ApiRequestFailure
@@ -68,7 +68,6 @@ class SwSpec(WMLResource):
                                 "do_12.10":  "9100fd72-8159-4eb9-8a0b-a87e12eefa36",
                                 "hybrid_0.2":  "9b3f9040-9cee-4ead-8d7a-780600f542f7"}
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_details(self,sw_spec_uid=None):
         """
             Get software specification details. If no sw_spec_id is passed, details for all software specifications will be returned.
@@ -93,7 +92,7 @@ class SwSpec(WMLResource):
         if self._client.WSD_20:
             raise WMLClientError(u'get_details API is not supported in Watson Studio Desktop.')
 
-        SwSpec._validate_type(sw_spec_uid, u'sw_spec_uid', STR_TYPE, False)
+        SwSpec._validate_type(sw_spec_uid, u'sw_spec_uid', str, False)
 
         if sw_spec_uid:
             if not self._ICP or self._client.ICP_PLATFORM_SPACES:
@@ -128,7 +127,6 @@ class SwSpec(WMLResource):
             else:
                 return self._handle_response(200, u'get sw specs details', response)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def store(self, meta_props):
         """
                 Create a software specification.
@@ -217,9 +215,7 @@ class SwSpec(WMLResource):
             header = [u'NAME', u'ASSET_ID', u'TYPE']
             print(tabulate(self.software_spec_list.items(), headers=header))
 
-
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_id(sw_spec_details):
         """
                 Get Unique Id of software specification.
@@ -248,7 +244,6 @@ class SwSpec(WMLResource):
         return SwSpec.get_uid(sw_spec_details)
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_uid(sw_spec_details):
         """
                 Get Unique Id of software specification. Deprecated!! Use get_id(sw_spec_details) instead
@@ -279,7 +274,6 @@ class SwSpec(WMLResource):
         return WMLResource._get_required_element_from_dict(sw_spec_details, u'sw_spec_details',
                                                            [u'metadata', u'asset_id'])
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_id_by_name(self, sw_spec_name):
         """
                 Get Unique Id of software specification.
@@ -307,7 +301,6 @@ class SwSpec(WMLResource):
 
         return SwSpec.get_uid_by_name(self, sw_spec_name)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_uid_by_name(self, sw_spec_name):
         """
                 Get Unique Id of software specification. Deprecated!! Use get_id_by_name(self, sw_spec_name) instead
@@ -333,7 +326,7 @@ class SwSpec(WMLResource):
 
         """
 
-        SwSpec._validate_type(sw_spec_name, u'sw_spec_uid', STR_TYPE, True)
+        SwSpec._validate_type(sw_spec_name, u'sw_spec_uid', str, True)
         if not self._client.WSD_20:
             parameters = self._client._params(skip_space_project_chk=True)
             parameters.update(name=sw_spec_name)
@@ -351,9 +344,7 @@ class SwSpec(WMLResource):
         else:
             return self.software_spec_list.get(sw_spec_name)
 
-
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_href(sw_spec_details):
         """
             Get url of software specification.
@@ -381,8 +372,6 @@ class SwSpec(WMLResource):
 
         return WMLResource._get_required_element_from_dict(sw_spec_details, u'sw_spec_details', [u'metadata', u'href'])
 
-
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def delete(self, sw_spec_uid):
         """
             Delete a software specification.
@@ -407,7 +396,7 @@ class SwSpec(WMLResource):
         if self._client.WSD_20:
             raise WMLClientError(u'delete API is not supported in Watson Studio Desktop.')
 
-        SwSpec._validate_type(sw_spec_uid, u'sw_spec_uid', STR_TYPE, True)
+        SwSpec._validate_type(sw_spec_uid, u'sw_spec_uid', str, True)
 
         response = requests.delete(self._client.service_instance._href_definitions.get_sw_spec_href(sw_spec_uid), params=self._client._params(),
                                 headers=self._client._get_headers())
@@ -417,8 +406,6 @@ class SwSpec(WMLResource):
         else:
             return self._handle_response(204, u'delete software specification', response)
 
-
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def add_package_extension(self, sw_spec_uid, pkg_extn_id):
         """
                 Add a package extension to software specifications existing metadata.
@@ -444,9 +431,8 @@ class SwSpec(WMLResource):
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
 
-        sw_spec_uid = str_type_conv(sw_spec_uid)
-        self._validate_type(sw_spec_uid, u'sw_spec_uid', STR_TYPE, True)
-        self._validate_type(pkg_extn_id, u'pkg_extn_id', STR_TYPE, True)
+        self._validate_type(sw_spec_uid, u'sw_spec_uid', str, True)
+        self._validate_type(pkg_extn_id, u'pkg_extn_id', str, True)
 
         url = self._client.service_instance._href_definitions.get_sw_spec_href(sw_spec_uid)
 
@@ -460,7 +446,6 @@ class SwSpec(WMLResource):
         else:
             return self._handle_response(204, u'pkg spec add', response, False)
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def delete_package_extension(self, sw_spec_uid, pkg_extn_id):
         """
                 Delete a package extension from software specifications existing metadata.
@@ -485,9 +470,8 @@ class SwSpec(WMLResource):
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
 
-        sw_spec_uid = str_type_conv(sw_spec_uid)
-        self._validate_type(sw_spec_uid, u'sw_spec_uid', STR_TYPE, True)
-        self._validate_type(pkg_extn_id, u'pkg_extn_id', STR_TYPE, True)
+        self._validate_type(sw_spec_uid, u'sw_spec_uid', str, True)
+        self._validate_type(pkg_extn_id, u'pkg_extn_id', str, True)
 
         url = self._client.service_instance._href_definitions.get_sw_spec_href(sw_spec_uid)
 
