@@ -18,7 +18,7 @@ import json
 import re
 import logging
 from lomond import WebSocket
-from ibm_watson_machine_learning.utils import print_text_header_h1, print_text_header_h2, TRAINING_RUN_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, str_type_conv, meta_props_str_conv, group_metrics, StatusLogger
+from ibm_watson_machine_learning.utils import print_text_header_h1, print_text_header_h2, TRAINING_RUN_DETAILS_TYPE, group_metrics, StatusLogger
 import time
 from ibm_watson_machine_learning.metanames import TrainingConfigurationMetaNames, TrainingConfigurationMetaNamesCp4d30
 from ibm_watson_machine_learning.wml_client_error import WMLClientError, ApiRequestFailure
@@ -58,7 +58,6 @@ class Training(WMLResource):
         res = re.match('\/v2\/assets\/p\-[a-zA-Z0-9\-\_]+', s)
         return res is not None
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_status(self, training_uid):
         """
                 Get the status of a training created.
@@ -79,9 +78,7 @@ class Training(WMLResource):
 
                  >>> training_status = client.training.get_status(training_uid)
         """
-
-        training_uid = str_type_conv(training_uid)
-        Training._validate_type(training_uid, 'training_uid', STR_TYPE, True)
+        Training._validate_type(training_uid, 'training_uid', str, True)
 
         details = self.get_details(training_uid, _internal=True)
 
@@ -90,7 +87,6 @@ class Training(WMLResource):
         else:
             raise WMLClientError(u'Getting trained model status failed. Unable to get model details for training_uid: \'{}\'.'.format(training_uid))
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_details(self, training_uid=None, limit=None, asynchronous=False, get_all=False, training_type=None,
                     state=None, tag_value=None, training_definition_id=None, _internal=False):
         """
@@ -142,8 +138,7 @@ class Training(WMLResource):
         """
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
-        training_uid = str_type_conv(training_uid)
-        Training._validate_type(training_uid, 'training_uid', STR_TYPE, False)
+        Training._validate_type(training_uid, 'training_uid', str, False)
 
         url = self._client.service_instance._href_definitions.get_trainings_href()
 
@@ -176,7 +171,6 @@ class Training(WMLResource):
             return details
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_href(training_details):
         """
             Get training_href from training details.
@@ -209,7 +203,6 @@ class Training(WMLResource):
             return WMLResource._get_required_element_from_dict(training_details, u'training_details', [u'metadata', u'href'])
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_uid(training_details):
         """
             This method is deprecated, please use get_id() instead."
@@ -225,7 +218,6 @@ class Training(WMLResource):
             return Training.get_id(training_details)
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_id(training_details):
         """
             Get training_id from training details.
@@ -253,7 +245,6 @@ class Training(WMLResource):
         return WMLResource._get_required_element_from_dict(training_details, u'training_details',
                                                            [u'metadata', u'id'])
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def run(self, meta_props, asynchronous=True):
         """
         Create a new Machine Learning training.
@@ -417,7 +408,6 @@ class Training(WMLResource):
         Training._validate_type(meta_props, 'meta_props', object, True)
         Training._validate_type(asynchronous, 'asynchronous', bool, True)
 
-        meta_props_str_conv(meta_props)
         self.ConfigurationMetaNames._validate(meta_props)
         training_configuration_metadata = {
             u'training_data_references': meta_props[self.ConfigurationMetaNames.TRAINING_DATA_REFERENCES],
@@ -747,7 +737,6 @@ class Training(WMLResource):
         else:
             self._logger.debug("state is not completed")
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def cancel(self, training_uid, hard_delete=False):
         """
         Cancel a training which is currently running and remove it. This method is also be used to delete metadata
@@ -776,8 +765,7 @@ class Training(WMLResource):
         """
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
-        training_uid = str_type_conv(training_uid)
-        Training._validate_type(training_uid, u'training_uid', STR_TYPE, True)
+        Training._validate_type(training_uid, u'training_uid', str, True)
         if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
             params = self._client._params()
         else:
@@ -922,7 +910,6 @@ class Training(WMLResource):
                 print(ex)
                 print("ERROR - Cannot get the location of evaluation-metrics.txt details in the bucket")
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def monitor_logs(self, training_uid):
         """
             Monitor the logs of a training created.
@@ -954,8 +941,7 @@ class Training(WMLResource):
         if self._client.ICP_30 or self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError("Metrics logs are not supported. This method is not supported for IBM Cloud Pak® for Data. ")
 
-        training_uid = str_type_conv(training_uid)
-        Training._validate_type(training_uid, u'training_uid', STR_TYPE, True)
+        Training._validate_type(training_uid, u'training_uid', str, True)
 
         self._simple_monitor_logs(training_uid, lambda: print_text_header_h1(u'Log monitor started for training run: ' + str(training_uid)))
 
@@ -1015,7 +1001,6 @@ class Training(WMLResource):
 
             websocket.close()
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def monitor_metrics(self, training_uid):
         """
             Monitor the metrics of a training created.
@@ -1045,8 +1030,7 @@ class Training(WMLResource):
         if self._client.ICP_30 or self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError("Metrics monitoring is not supported for IBM Cloud Pak® for Data")
 
-        training_uid = str_type_conv(training_uid)
-        Training._validate_type(training_uid, u'training_uid', STR_TYPE, True)
+        Training._validate_type(training_uid, u'training_uid', str, True)
         try:
             run_details = self.get_details(training_uid, _internal=True)
         except ApiRequestFailure as ex:
@@ -1103,7 +1087,6 @@ class Training(WMLResource):
 
             print_text_header_h2('Metric monitor done.')
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_metrics(self, training_uid):
         """
                 Get metrics.
@@ -1125,9 +1108,7 @@ class Training(WMLResource):
                  >>> training_status = client.training.get_metrics(training_uid)
 
         """
-
-        training_uid = str_type_conv(training_uid)
-        Training._validate_type(training_uid, u'training_uid', STR_TYPE, True)
+        Training._validate_type(training_uid, u'training_uid', str, True)
         status = self.get_status(training_uid)
         if 'metrics' in status:
             return status['metrics']
@@ -1138,7 +1119,6 @@ class Training(WMLResource):
             else:
                 raise WMLClientError("No metrics details are available for the given training_uid")
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def _get_latest_metrics(self, training_uid):
         """
              Get latest metrics values.
@@ -1153,8 +1133,7 @@ class Training(WMLResource):
 
              >>> client.training.get_latest_metrics(training_uid)
          """
-        training_uid = str_type_conv(training_uid)
-        Training._validate_type(training_uid, u'training_uid', STR_TYPE, True)
+        Training._validate_type(training_uid, u'training_uid', str, True)
 
         status = self.get_status(training_uid)
         metrics = status.get('metrics', [])
