@@ -60,27 +60,11 @@ XGBOOST_FRAMEWORK = u'xgboost'
 SCIKIT_LEARN_FRAMEWORK = u'scikit-learn'
 PMML_FRAMEWORK = u'pmml'
 
-STR_TYPE = type(u'string or unicode')
-STR_TYPE_NAME = STR_TYPE.__name__
-
 
 def is_python_2():
     return sys.version_info[0] == 2
 
 
-def str_type_conv(string):
-    if is_python_2() and type(string) is str:
-        return unicode(string)
-    else:
-        return string
-
-
-def meta_props_str_conv(meta_props):
-    for key in meta_props:
-        if is_python_2() and type(meta_props[key]) is str:
-            meta_props[key] = unicode(meta_props[key])
-
-
 def get_url(url, headers, params=None, isIcp=False):
     import ibm_watson_machine_learning._wrappers.requests as requests
 
@@ -91,14 +75,12 @@ def get_url(url, headers, params=None, isIcp=False):
 
 
 def print_text_header_h1(title):
-    title = str_type_conv(title)
     print(u'\n\n' + (u'#' * len(title)) + u'\n')
     print(title)
     print(u'\n' + (u'#' * len(title)) + u'\n\n')
 
 
 def print_text_header_h2(title):
-    title = str_type_conv(title)
     print(u'\n\n' + (u'-' * len(title)))
     print(title)
     print((u'-' * len(title)) + u'\n\n')
@@ -226,14 +208,6 @@ def get_type_of_details(details):
         return UNKNOWN_TYPE
 
 
-def pack(directory_path):
-    pass
-
-
-def unpack(filename):
-    pass
-
-
 def load_model_from_directory(framework, directory_path):
     if "mllib" in framework:
      from pyspark.ml import PipelineModel
@@ -281,11 +255,6 @@ def load_model_from_directory(framework, directory_path):
 #         raise WMLClientError('Invalid framework specified: \'{}\'.'.format(framework))
 
 
-def load_model_from_package(framework, directory):
-    unpack(directory)
-    load_model_from_directory(framework, directory)
-
-
 def save_model_to_file(model, framework, base_path, filename):
     if filename.find('.') != -1:
         base_name = filename[:filename.find('.') + 1]
@@ -333,9 +302,42 @@ def format_metrics(latest_metrics_list):
     return formatted_metrics
 
 
-def docstring_parameter(args):
+def inherited_docstring(f, mapping={}):
     def dec(obj):
-        #obj.__doc__ = obj.__doc__.format(**args)
+        if not obj.__doc__:
+            possible_types = {'model': 'model',
+                              'function': 'function',
+                              'space': 'space',
+                              'pipeline': 'pipeline',
+                              'experiment': 'experiment',
+                              'member': 'space'}
+
+            available_metanames = {'model': 'ModelMetaNames',
+                                   'experiment': 'ExperimentMetaNames',
+                                   'function': 'FunctionMetaNames',
+                                   'pipeline': 'PipelineMetaNames'}
+
+            actual_type = None
+
+            for t in possible_types:
+                if t in obj.__name__:
+                    actual_type = possible_types[t]
+
+            docs = f.__doc__
+
+            if actual_type:
+                docs = docs.replace(f'client.{actual_type}s.{f.__name__}', 'client.repository.' + obj.__name__)
+                docs = docs.replace(f'client._{actual_type}s.{f.__name__}', 'client.repository.' + obj.__name__)
+
+                if actual_type in available_metanames:
+                    repository_meta_names = available_metanames[actual_type]
+                    docs = docs.replace(f'_{actual_type}s.ConfigurationMetaNames', f'repository.{repository_meta_names}')
+                    docs = docs.replace(f'{actual_type}s.ConfigurationMetaNames', f'repository.{repository_meta_names}')
+                    docs = docs.replace('ConfigurationMetaNames', repository_meta_names)
+
+                for k in mapping:
+                    docs = docs.replace(k, mapping[k])
+            obj.__doc__ = docs
         return obj
     return dec
 
@@ -559,9 +561,6 @@ class NextResourceGenerator:
         self.all = _all
 
     def __iter__(self):
-        return self
-
-    def __next__(self):
         if self.next_href is not None:
             response = requests.get(
                 url=f"{self.url}/{self.next_href}",
@@ -585,7 +584,7 @@ class NextResourceGenerator:
             else:
                 resources = details_json.get('results', [])
 
-            return resources
+            yield {'resources': resources}
 
         else:
             raise StopIteration
