@@ -14,7 +14,6 @@
 
 from __future__ import print_function
 import ibm_watson_machine_learning._wrappers.requests as requests
-from ibm_watson_machine_learning.utils import SPACES_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, MEMBER_DETAILS_TYPE,DATA_ASSETS_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv, str_type_conv, get_file_from_cos
 from ibm_watson_machine_learning.metanames import VolumeMetaNames
 from ibm_watson_machine_learning.wml_resource import WMLResource
 from ibm_watson_machine_learning.wml_client_error import WMLClientError, ApiRequestFailure
@@ -36,7 +35,6 @@ class Volume(WMLResource):
         WMLResource.__init__(self, __name__, client)
         self._ICP = client.ICP
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_details(self, volume_id):
         """
             Get Volume  details.
@@ -58,7 +56,7 @@ class Volume(WMLResource):
              >>> volume_details = client.volumes.get_details(volume_id)
 
         """
-        Volume._validate_type(volume_id, u'volume_id', STR_TYPE, True)
+        Volume._validate_type(volume_id, u'volume_id', str, True)
 
         params = {'addon_type': 'volumes',
                   'include_service_status':True
@@ -73,8 +71,6 @@ class Volume(WMLResource):
             print(response.status_code, response.text)
             raise WMLClientError("Failed to Get the volume details. Try again.")
 
-
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def create(self, meta_props):
         """
                 Creates a Volume asset.
@@ -336,7 +332,6 @@ class Volume(WMLResource):
         self._list(volume_values, [u'NAME', u'ID', u'PROVISION_STATUS'], None, _DEFAULT_LIST_LENGTH)
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_id(volume_details):
         """
                 Get Unique Id of stored volume details.
@@ -371,7 +366,6 @@ class Volume(WMLResource):
                                                            [u'id'])
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_name(volume_details):
         """
                 Get Unique name  of stored volume asset.
@@ -404,7 +398,6 @@ class Volume(WMLResource):
             return WMLResource._get_required_element_from_dict(volume_details, u'volume_assets_details',
                                                            [u'display_name'])
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def delete(self, volume_id):
         """
             Delete a volume.
@@ -426,7 +419,7 @@ class Volume(WMLResource):
              >>> client.volumes.delete(volume_id)
 
         """
-        Volume._validate_type(volume_id, u'asset_uid', STR_TYPE, True)
+        Volume._validate_type(volume_id, u'asset_uid', str, True)
         if (not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES):
             raise WMLClientError(u'Volume API is not supported.')
 
@@ -441,7 +434,6 @@ class Volume(WMLResource):
             print(response.status_code, response.text)
             return "FAILED"
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def stop(self, volume_name):
         """
             Stop the  volume service.
@@ -463,7 +455,7 @@ class Volume(WMLResource):
              >>> client.volumes.stop(volume_name)
 
         """
-        Volume._validate_type(volume_name, u'asset_uid', STR_TYPE, True)
+        Volume._validate_type(volume_name, u'asset_uid', str, True)
         if (not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES):
             raise WMLClientError(u'Volume API is not supported.')
 
