@@ -16,7 +16,7 @@ import ibm_watson_machine_learning._wrappers.requests as requests
 import logging
 from ibm_watson_machine_learning.wml_client_error import MissingValue, WMLClientError, NoWMLCredentialsProvided, ApiRequestFailure, UnexpectedType, MissingMetaProp
 from ibm_watson_machine_learning.href_definitions import HrefDefinitions
-from ibm_watson_machine_learning.utils import get_type_of_details, STR_TYPE, str_type_conv, NextResourceGenerator
+from ibm_watson_machine_learning.utils import get_type_of_details, NextResourceGenerator
 import urllib.parse
 import os
 import sys
@@ -31,8 +31,7 @@ class WMLResource:
             raise NoWMLCredentialsProvided
         WMLResource._validate_type(client.wml_credentials, u'wml_credentials', dict, True)
         if not client.WSD and not client.ICP:
-            wml_token = str_type_conv(client.wml_token)
-            WMLResource._validate_type(wml_token, u'wml_token', STR_TYPE, True)
+            WMLResource._validate_type(client.wml_token, u'wml_token', str, True)
         self._client = client
         self._ICP = client.ICP
         self._WSD = client.WSD
@@ -75,7 +74,7 @@ class WMLResource:
     @staticmethod
     def _get_required_element_from_dict(el, root_path, path):
         WMLResource._validate_type(el, root_path, dict)
-        WMLResource._validate_type(root_path, u'root_path', STR_TYPE)
+        WMLResource._validate_type(root_path, u'root_path', str)
         WMLResource._validate_type(path, u'path', list)
 
         if path.__len__() < 1:
@@ -96,7 +95,7 @@ class WMLResource:
             return new_el
 
     def _get_asset_based_resource(self, asset_id, asset_type, get_required_element_from_response):
-        WMLResource._validate_type(asset_id, f'{asset_type}_id', STR_TYPE, False)
+        WMLResource._validate_type(asset_id, f'{asset_type}_id', str, False)
 
         if asset_id:
             response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_id),
@@ -126,9 +125,8 @@ class WMLResource:
         if el_name is None:
             raise MissingValue(u'el_name')
 
-        el_name = str_type_conv(el_name)
-        if type(el_name) is not STR_TYPE:
-            raise UnexpectedType(u'el_name', STR_TYPE, type(el_name))
+        if type(el_name) is not str:
+            raise UnexpectedType(u'el_name', str, type(el_name))
 
         if expected_type is None:
             raise MissingValue(u'expected_type')
@@ -262,12 +260,12 @@ class WMLResource:
         resource_generator = NextResourceGenerator(self._client, url_2, href, params, _all)
 
         if _async:
-            return ({"resources": entry} for entry in resource_generator)
+            return resource_generator
 
         else:
             if _all:
                 for entry in resource_generator:
-                    resources.extend(entry)
+                    resources.extend(entry['resources'])
                 return {
                     "resources": resources
                 }
@@ -514,7 +512,7 @@ class WMLResource:
             if create_response.status_code == 201:
                 asset_uid = create_response.json()["metadata"]["asset_id"]
 
-                if type(path_to_archive) is STR_TYPE:
+                if type(path_to_archive) is str:
                     file_name_to_attach = path_to_archive.rsplit("/")[-1]
                 else:
                     file_name_to_attach = 'function_attachment'
@@ -526,7 +524,7 @@ class WMLResource:
                                      urllib.parse.quote(asset_type + "/" + asset_uid + "/" + file_name_to_attach, safe='')
                 attach_url = self._client.service_instance._href_definitions.get_model_definition_assets_href() + "/" + \
                              urllib.parse.quote(asset_uid + "/attachments")
-                if type(path_to_archive) is STR_TYPE:
+                if type(path_to_archive) is str:
                     with open(path_to_archive, 'rb') as f:
                         fdata = f.read()
                 else:
@@ -571,7 +569,7 @@ class WMLResource:
                     if attach_response.status_code == 201:
                         # remove the tmp file create for content upload
                         if asset_type != 'data_asset':
-                            if type(path_to_archive) is STR_TYPE and os.path.isfile(path_to_archive) \
+                            if type(path_to_archive) is str and os.path.isfile(path_to_archive) \
                                     and user_archive_file is False:
                                 os.remove(path_to_archive)
                             return self._wsd_get_required_element_from_response(asset_details)
@@ -589,8 +587,7 @@ class WMLResource:
             raise e
 
     def _wsd_delete_asset(self, asset_type, asset_id):
-        asset_uid = str_type_conv(asset_id)
-        delete_endpoint = self._client.service_instance._href_definitions.get_model_definition_assets_href() + "/" + asset_uid
+        delete_endpoint = self._client.service_instance._href_definitions.get_model_definition_assets_href() + "/" + asset_id
         self._logger.debug(u'Deletion artifact {} endpoint: {}'.format(asset_type, delete_endpoint))
         response_delete = requests.delete(delete_endpoint, params=self._client._params(),
                                               headers=self._client._get_headers())
